<?php
/**
 * Content with Features
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Content with Features', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'columns' ),
	'content'    => '<!-- wp:themeisle-blocks/patterns-upsell /--><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-335a2f03","columns":1,"layout":"equal","padding":{"top":"80px","bottom":"80px","left":"20px","right":"20px"},"paddingTablet":{"top":"40px","bottom":"40px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px"},"marginTablet":{"top":"0px","bottom":"0px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1170,"horizontalAlign":"center","verticalAlign":"flex-start","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"columnsHTMLTag":"section","align":"full","hasCustomCSS":true,"otterConditions":[]} --><section id="wp-block-themeisle-blocks-advanced-columns-335a2f03" class="wp-block-themeisle-blocks-advanced-columns alignfull has-1-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-equal-layout has-vertical-flex-start"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-5d90343f","padding":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"paddingTablet":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"100","otterConditions":[]} --><div id="wp-block-themeisle-blocks-advanced-column-5d90343f" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-b2ead1d6","columns":2,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"paddingTablet":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px"},"marginTablet":{"top":"0px","bottom":"0px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1170,"horizontalAlign":"center","verticalAlign":"center","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"columnsHTMLTag":"section","otterConditions":[]} --><section id="wp-block-themeisle-blocks-advanced-columns-b2ead1d6" class="wp-block-themeisle-blocks-advanced-columns has-2-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-center"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-7c705a1c","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","otterConditions":[]} --><div id="wp-block-themeisle-blocks-advanced-column-7c705a1c" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-ea5e7576","tag":"div","align":"left","fontSize":12,"fontSizeTablet":12,"fontSizeMobile":12,"textTransform":"uppercase","marginType":"linked"} --><div id="wp-block-themeisle-blocks-advanced-heading-ea5e7576" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-ea5e7576"><strong>This is an overline</strong></div><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:heading --><h2>This is Heading two</h2><!-- /wp:heading --><!-- wp:paragraph --><p>Capitalize on low hanging fruit to identify a ballpark value added activity to beta test. Override the digital divide with additional clickthroughs from DevOps. Nanotechnology immersion along the information highway will close the loop on focusing solely on the bottom line.</p><!-- /wp:paragraph --><!-- wp:buttons --><div class="wp-block-buttons"><!-- wp:button {"className":"is-style-primary"} --><div class="wp-block-button is-style-primary"><a class="wp-block-button__link">Learn More</a></div><!-- /wp:button --></div><!-- /wp:buttons --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-5f9a9ec0","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":null,"bottom":null,"left":null,"right":null},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","otterConditions":[]} --><div id="wp-block-themeisle-blocks-advanced-column-5f9a9ec0" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:image {"id":308,"sizeSlug":"full","linkDestination":"none"} --><figure class="wp-block-image size-full"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/otter-demo-04.png" alt="" class="wp-image-308"/></figure><!-- /wp:image --></div><!-- /wp:themeisle-blocks/advanced-column --></div></section><!-- /wp:themeisle-blocks/advanced-columns --><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-8e7cc7ae","columns":3,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"paddingTablet":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px"},"marginTablet":{"top":"0px","bottom":"0px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1170,"horizontalAlign":"center","verticalAlign":"flex-start","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"columnsHTMLTag":"section","otterConditions":[]} --><section id="wp-block-themeisle-blocks-advanced-columns-8e7cc7ae" class="wp-block-themeisle-blocks-advanced-columns has-3-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-flex-start"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-725f10a7","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"33.33","otterConditions":[]} --><div id="wp-block-themeisle-blocks-advanced-column-725f10a7" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:heading {"textAlign":"left","level":3} --><h3 class="has-text-align-left">Service title</h3><!-- /wp:heading --><!-- wp:paragraph {"align":"left"} --><p class="has-text-align-left">Synergestic actionables. Organic growth deep dive but circle back or but what\'s the real problem we\'re trying to solve here?</p><!-- /wp:paragraph --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-3c67f726","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"33.33","otterConditions":[]} --><div id="wp-block-themeisle-blocks-advanced-column-3c67f726" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:heading {"textAlign":"left","level":3} --><h3 class="has-text-align-left">Service title</h3><!-- /wp:heading --><!-- wp:paragraph {"align":"left"} --><p class="has-text-align-left">Synergestic actionables. Organic growth deep dive but circle back or but what\'s the real problem we\'re trying to solve here?</p><!-- /wp:paragraph --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-4956dbc0","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"33.33","otterConditions":[]} --><div id="wp-block-themeisle-blocks-advanced-column-4956dbc0" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:heading {"textAlign":"left","level":3} --><h3 class="has-text-align-left">Service title</h3><!-- /wp:heading --><!-- wp:paragraph {"align":"left"} --><p class="has-text-align-left">Synergestic actionables. Organic growth deep dive but circle back or but what\'s the real problem we\'re trying to solve here?</p><!-- /wp:paragraph --></div><!-- /wp:themeisle-blocks/advanced-column --></div></section><!-- /wp:themeisle-blocks/advanced-columns --></div><!-- /wp:themeisle-blocks/advanced-column --></div></section><!-- /wp:themeisle-blocks/advanced-columns -->',
);
