input[type=button],span[lang|=en-],div[class~=-hey]{color:#fff}input[type=-_2test],input[TYPE$=_2tEst_],a[alt],span[lang^=PT],a[href*=example2-test-]{color:#fff}a[aria-hidden=false],[data-toggle=buttons]{color:blue}input[type=""],input[type="-"],input[type="--test"],input[type="-2test"],input[type="2test"],a[href ^="http:"],a[href $='#'],img[src^="http://"]{color:#000}a[href*='a%a'],a[href *='b/b'],a[href*="asd$sdd!"]{color:#000}