#wpcontent{padding-left:0!important}.ob-overflow-off{overflow:hidden!important}#wpbody-content,body{background-color:var(--chakra-colors-bg-muted)!important}#wpbody-content>.notice{display:none}.obfx-settings-social-sharing .chakra-stack .chakra-switch__root{margin-right:auto;min-width:150px}.obfx-settings-social-sharing .chakra-stack .chakra-switch__root~.chakra-checkbox__root{opacity:0;transition:opacity .2s ease-in-out}.obfx-settings-social-sharing .chakra-stack .chakra-switch__root[data-state=checked]~.chakra-checkbox__root{opacity:1}.obfx-module-settings-wrap select{max-width:unset!important}.obfx-banner .notice{border-radius:5px!important;margin:0!important}
