<?php return array(
    'root' => array(
        'name' => 'codeinwp/optimole-wp',
        'pretty_version' => '1.1.2',
        'version' => '1.1.2.0',
        'reference' => null,
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'codeinwp/optimole-sdk' => array(
            'pretty_version' => 'v1.2.2',
            'version' => '1.2.2.0',
            'reference' => '567557f1067c934a564154dd292a3f343749b538',
            'type' => 'library',
            'install_path' => __DIR__ . '/../codeinwp/optimole-sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/optimole-wp' => array(
            'pretty_version' => '1.1.2',
            'version' => '1.1.2.0',
            'reference' => null,
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/themeisle-sdk' => array(
            'pretty_version' => '3.3.48',
            'version' => '3.3.48.0',
            'reference' => '0727d2cf2fc9bfb81b42968aeaf2bf4e340f021e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../codeinwp/themeisle-sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'enshrined/svg-sanitize' => array(
            'pretty_version' => '0.21.0',
            'version' => '0.21.0.0',
            'reference' => '5e477468fac5c5ce933dce53af3e8e4e58dcccc9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../enshrined/svg-sanitize',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.30.0',
            'version' => '1.30.0.0',
            'reference' => '77fa7995ac1b21ab60769b7323d600a991a90433',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
