@keyframes elementor-animation-pulse {
	25% {
		transform: scale(1.1);
	}
	75% {
		transform: scale(0.9);
	}
}
.elementor-animation-pulse:active,
.elementor-animation-pulse:focus,
.elementor-animation-pulse:hover {
	animation-name: elementor-animation-pulse;
	animation-duration: 1s;
	animation-timing-function: linear;
	animation-iteration-count: infinite;
}
