.mystock-img-container .error-messaging {
    display: none;
}

.mystock-img-container .error-messaging.active {
    padding: 17px 17px 17px 57px;
    -webkit-border-radius: 3px;
    background: #df3333;
    color: #fff;
    font-size: 13px;
    margin-bottom: 25px;
    display: block;
    position: relative;
}

.mystock-img-container .error-messaging.active:before {
    font-family: 'dashicons';
    content: '\f534';
    display: block;
    left: 17px;
    top: 50%;
    -webkit-transform: translateY(-50%);
    -ms-transform: translateY(-50%);
    transform: translateY(-50%);
    position: absolute;
    font-size: 30px;
    opacity: 0.75;
}

.mystock-img-container .load-more-wrap {
    margin: 1% 0 0;
    padding: 25px 0;
    text-align: center;
    border-top: 1px solid #efefef;
}

#msp-photos .photo {
    padding: 0 5px 10px;
}

#msp-photos .photo .photo-options {
    width: 100%;
    display: inline-block;
    float: none;
    max-width: 100%;
}

#msp-photos .photo.in-progress .photo-options,
#msp-photos .photo.uploaded .photo-options {
    opacity: 0;
    visibility: hidden;
}

#msp-photos .photo .img-wrap {

    overflow: hidden;
    position: relative;
}

#msp-photos .photo:focus a.upload img {
    opacity: 0.6;
}

#msp-photos .photo:focus .user-controls {
    opacity: 1;
    visibility: visible;
}

#msp-photos .photo a.upload {
    display: block;
    background-color: #222;
}

#msp-photos .photo a.upload img {
    -webkit-transition: all 0.5s ease;
    -o-transition: all 0.5s ease;
    transition: all 0.5s ease;
}

#msp-photos .photo a.upload .status {
    visibility: hidden;
    opacity: 0;
    -webkit-transition: all 0.2575s ease-in-out;
    -o-transition: all 0.2575s ease-in-out;
    transition: all 0.2575s ease-in-out;
    width: 60px;
    height: 60px;
    line-height: 60px;
    -webkit-border-radius: 100%;
    border-radius: 100%;
    position: absolute;
    left: 50%;
    top: 50%;
    z-index: 5;
    -webkit-transform: translate(-50%, -50%) scale(1.5);
    -ms-transform: translate(-50%, -50%) scale(1.5);
    transform: translate(-50%, -50%) scale(1.5);
    -webkit-box-shadow: 0 0 4px rgba(0, 0, 0, 0.15);
    box-shadow: 0 0 4px rgba(0, 0, 0, 0.15);
}

#msp-photos .photo a.upload .status:before {
    font-family: 'dashicons';
    display: block;
    color: #fff;
    font-size: 22px;
    opacity: 0.8;
}

#msp-photos .photo a.upload .status a {
    color: #fff;
}

#msp-photos .photo a.upload.uploading .status,
#msp-photos .photo a.upload.success .status,
#msp-photos .photo a.upload.errors .status {
    text-align: center;
    left: 50%;
    top: 50%;
    -webkit-transform: translate(-50%, -50%) scale(1);
    -ms-transform: translate(-50%, -50%) scale(1);
    transform: translate(-50%, -50%) scale(1);
}

#msp-photos .photo a.upload.uploading {
    cursor: default;
}

#msp-photos .photo a.upload.uploading .status {
    visibility: visible;
    opacity: 1;
    background-color: #5d72c3;
}

#msp-photos .photo a.upload.uploading .status:before {
    content: '\f316';
}

#msp-photos .photo a.upload.success {
    cursor: default !important;
}

#msp-photos .photo a.upload.success .status {
    visibility: visible;
    opacity: 1;
    width: 70px;
    height: 70px;
    line-height: 70px;
    background-color: #63d875;
    -webkit-border-radius: 100%;
    border-radius: 100%;
}

#msp-photos .photo a.upload.success .status:before {
    content: '\f147';
    color: #fff;
}

#msp-photos .photo a.upload.success img {
    -webkit-transform: scale(1) !important;
    -ms-transform: scale(1) !important;
    transform: scale(1) !important;
}

#msp-photos .photo a.upload.errors {
    cursor: help !important;
}

#msp-photos .photo a.upload.errors .status {
    visibility: visible;
    opacity: 1;
    width: 60px;
    height: 60px;
    line-height: 60px;
    background-color: #df3333;
    -webkit-border-radius: 100%;
    border-radius: 100%;
}

#msp-photos .photo a.upload.errors .status:before {
    content: '';
    color: #fff;
    opacity: 0.8;
}

#msp-photos .photo.uploaded a.upload img {
    opacity: 0.25 !important;
}

#msp-photos .photo:hover a.upload img,
#msp-photos .photo.in-progress a.upload img {
    opacity: 0.6;
    -webkit-transform: scale(1.075);
    -ms-transform: scale(1.075);
    transform: scale(1.075);
}

#msp-photos .photo:hover .options,
#msp-photos .photo.in-progress .options {
    opacity: 1;
    visibility: visible;
}

#msp-photos .photo:hover .user-controls:not(.disabled),
#msp-photos .photo.in-progress .user-controls {
    opacity: 1;
    visibility: visible;
}

#msp-photos .photo.in-progress .notice-msg {
    top: 0;
    opacity: 1;
}

#msp-photos .photo.uploaded .user-controls,
#msp-photos .photo.in-progress .user-controls {
    opacity: 0;
}

#msp-photos .photo .user-controls {
    text-align: center;
    position: absolute;
    z-index: 6;
    width: 100%;
    top: 50%;
    transform: translateY(-50%);
    left: 0;
    padding: 0;
    opacity: 0;
    visibility: hidden;
    -webkit-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    transition: all 0.3s ease;
}

#msp-photos .photo .fade {
    color: #fff;
    background: transparent;
    -webkit-border-radius: 1px;
    border-radius: 1px;
    height: 34px;
    line-height: 34px;
    font-size: 17px;
    z-index: 6;
    margin: 1px 1px 1px 0;
    padding: 0;
    color: rgba(255, 255, 255, 0.75);
}

#msp-photos .photo .fade.set-featured{
    background-color: #eeb845;
}

#msp-photos .photo .fade.set-featured:hover,
#msp-photos .photo .fade.set-featured:focus{
    background-color: #eeac30;
}

#msp-photos .photo .fade.insert {
    background-color: #7eb4cd;
}
#msp-photos .photo .fade.insert:hover,
#msp-photos .photo .fade.insert:focus{
    background-color: #499bcd;
}
#msp-photos .photo .fade.download {
    background-color: #f3753b;
}
#msp-photos .photo .fade.download:hover,
#msp-photos .photo .fade.download:focus{
    background-color: #f36424;
}

#msp-photos .photo.done .fade.download,
#msp-photos .photo.done .fade.download:hover{
    opacity: 0.5;
    cursor: not-allowed;
}

#msp-photos .photo .fade.set-featured:hover,
#msp-photos .photo .fade.set-featured:focus,
#msp-photos .photo .fade.insert:hover,
#msp-photos .photo .fade.insert:focus,
#msp-photos .photo .fade.download:hover,
#msp-photos .photo .fade.download:focus {
    color: #fff;
}

#msp-photos .photo .fade.set-featured,
#msp-photos .photo .fade.insert,
#msp-photos .photo .fade.download {
    display: inline-block;
    text-align: center;
    vertical-align: middle;
    margin: 10px;
    border-radius: 50%;
    width: 50px;
    height: 50px;
}

#msp-photos .photo .fade.set-featured span,
#msp-photos .photo .fade.insert span,
#msp-photos .photo .fade.download span {
    text-decoration: none;
    line-height: 50px;
    margin: 0;
    padding: 0;
    transition: none;
}



#msp-photos .photo .fade.set-featured span {
    top: 0;
    left: 0;
}

#msp-photos .photo .notice-msg {
    position: absolute;
    top: -40px;
    left: 0;
    height: 40px;
    line-height: 40px;
    width: 100%;
    background: rgba(0, 0, 0, 0.6);
    text-align: center;
    color: #e0e4f5;
    font-size: 13px;
    margin: 0;
    padding: 0;
    -webkit-transition: all 0.25s ease-in-out;
    -o-transition: all 0.25s ease-in-out;
    transition: all 0.25s ease-in-out;
    opacity: 0;
    z-index: 9999;
}

.mystock-img-container .search-field {
    padding: 10px;
}

.mystock-img-container .search-field form {
    position: relative;
}

.mystock-img-container .search-field #photo-search-submit,
.mystock-img-container .search-field #clear-search {
    position: absolute;
    top: 0;
    width: 36px;
    height: 36px;
    z-index: 1;
    border: none;
    background: transparent;
    cursor: pointer;
    color: #666;
    -webkit-transition: all 0.25s ease;
    -o-transition: all 0.25s ease;
    transition: all 0.25s ease;
    opacity: 0.5;
    margin: 0;
}
.mystock-img-container .search-field #photo-search-submit{
    left: 0;
}
.mystock-img-container .search-field #clear-search{
    right: 0;
}
.mystock-img-container .search-field input{
    width: 100%;
    background-color: #f7f7f7;
    -webkit-transition: padding 0.15s ease;
    -o-transition: padding 0.15s ease;
    transition: padding 0.15s ease;
    line-height: 36px;
    height: 36px;
    padding-right: 8px;
    padding-left: 30px;
    border-color: #e2e4e7;
    font-size: 13px;
    -webkit-border-radius: 3px;
    border-radius: 3px;
}

.no-results {
    display: none;
    padding: 150px 0;
    text-align: center;
}

.no-results.show {
    display: block;
}

.no-results h3 {
    font-size: 24px;
    line-height: 29px;
    margin: 0 0 10px;
}

.no-results p {
    font-size: 16px;
    margin: 0;
}

.loading-wrap {
    text-align: center;
    padding: 10px 0;
}

.is-sidebar-opened .block-editor-editor-skeleton__sidebar{
    z-index: 100001;
}
