.wp-block-themeisle-blocks-plugin-cards{padding:20px 0}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-wrapper{background:#fff;border:1px #eaeaea solid;display:inline-block;width:100%;max-width:350px;font-family:"PT Serif Caption"}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-wrapper a{color:#000;text-decoration:none}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-header{background:#fff;text-align:center;padding:25px}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-logo{padding:10px}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-logo img{width:128px;height:128px;display:inline-block}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-info{padding:10px}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-info h4{font-size:24px;margin:0}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-info h5{font-size:16px;margin:0}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-ratings{font-family:"Font Awesome 5 Free"}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-ratings .star-full:before{content:"";font-weight:900}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-ratings .star-half:before{content:"";font-weight:900}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-ratings .star-empty:before{content:""}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-details{background:#fcfcfc;border-top:1px #eaeaea solid;padding:20px;font-size:12px;text-align:center}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-description{color:#707070;font-size:12px;text-align:center}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-stats{padding:25px 0 0 0;text-align:justify}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-stats h5{color:#707070;border-bottom:1px #d8d8d8 solid;font-size:14px;margin:0}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-stats-list{display:flex}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-stat{flex:auto;padding-top:10px;text-align:center}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-text-large{color:#4550ae;font-size:24px;display:block}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-download{background:#4551af;text-align:center}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-download:hover,.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-download:active{background:#202b82}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-download a{color:#fff;text-decoration:none;display:block;padding:20px}@media(max-width: 415px){.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-wrapper{width:auto}.wp-block-themeisle-blocks-plugin-cards .o-plugin-cards-stats-list{display:block}}/*# sourceMappingURL=style.css.map */
