.foo{margin-right:calc(-.375em - 1px);width:calc(100%/3 - 2*1em - 2*1px + 10 mod 2);margin:calc(1rem - 2px) calc(1rem + 1px)}.bar{margin:calc(5*calc(10px + 2em)) calc(10 + (5px + 10px - (10em - 3em)));padding-top:calc(5*(2em + -1px))}input{width:calc(100% - (1em*1.5))}p{font-size:-webkit-calc(20px + 1vw);font-size:-moz-calc(20px + 1vw);font-size:calc(20px + 1vw)}