.test\:-300ms,
.test-200ms {
    transition: box-shadow 200ms ease-out;
    transition-duration: 10s, 30s, 230MS;
    foo: 100.50ms;
    bar: +1500ms;
    baz: -350ms;
}
.foo {
    transition-duration: 500mS;
    animation-delay: 50ms;
}