#elem{width:100px;voice-family:"\"}\"";voice-family:inherit;width:200px}html>body #elem{width:200px}#sel-o{content:"on\"ce upon \
a time";content:'once upon \
a ti\'me'}.sele{content:"\"keep  \"    me";something:'\\\' .     . ';else:'empty{}';content:"/* test */"}