.a{filter:progid:DXImageTransform.Microsoft.Matrix(M11=0.9914448613738104, M12=-0.13052619222005157, M21=0.13052619222005157, M22=0.9914448613738104, sizingMethod='auto expand')}.b{display:none;filter:progid:DXImageTransform.Microsoft.Matrix(M11=0.9914448613738104, M12=-0.13052619222005157, M21=0.13052619222005157, M22=0.9914448613738104, sizingMethod='auto expand');vertical-align:bottom}.shadow{-ms-filter:"progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=0, Color='#DDDDDD')progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=90, Color='#DDDDDD')progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=180, Color='#DDDDDD')progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=270, Color='#DDDDDD')"}pre{border:solid red;opacity:.8;-ms-filter:"alpha(opacity=80)";filter:alpha(opacity=80);zoom:1}code{-ms-filter:"alpha(opacity=80)";filter:alpha(opacity=80)}