@charset "utf-8";@import url("fineprint.css") print;@import url("bluish.css") projection,tv;@import 'custom.css';@import url("chrome://communicator/skin/");@import "common.css" screen,projection;@import url('landscape.css') screen and (orientation:landscape);@import url(//example.org/foo.css?a;b;c;d) screen,projection;@import url(//example.org/foo.css?a;b;c;d);@import url(//example.org/bar.css);@namespace svg url(http://www.w3.org/2000/svg);@namespace url(http://www.w3.org/1999/xhtml);@document url(http://www.w3.org/),url-prefix(http://www.w3.org/Style/),domain(mozilla.org),regexp("https:.*"){body{color:purple;background:#ff0}}@media all,BRAILLE{body{background-color:gold}}@page :first{margin-left:50%;margin-top:50%}@viewport{min-width:640px;max-width:800px}#foo{border-width:1px}@keyframes identifier{0%{top:0;left:0}30%{top:50px}68%,72%{left:50px}100%{top:100px;left:100%}}@media print{#navigation{display:none}@media (max-width:12cm){.note,a[type="{{}{}{"]{float:none}@media (min-height:2px){.bar{width:10px}}.foo{align-content:center}}}@supports (box-shadow:0 0 2px black inset) or (-moz-box-shadow:0 0 2px black inset) or (-webkit-box-shadow:0 0 2px black inset) or (-o-box-shadow:0 0 2px black inset){.noticebox{-moz-box-shadow:0 0 2px #000 inset;-webkit-box-shadow:0 0 2px #000 inset;-o-box-shadow:0 0 2px #000 inset;box-shadow:0 0 2px #000 inset;border:none;padding:2px}}@supports NOT (display:flex){body{width:100%;height:100%;background:#fff;color:#000}#navigation{width:25%}#article{width:75%}}@font-face{font-family:'gzipper';src:url(yanone.eot);src:local('gzipper'),url(yanone.ttf) format('truetype')}#bar{border-width:10px}@viewport{zoom:.75;min-zoom:.5;max-zoom:.9}@viewport{orientation:landscape}@page :left{margin:2in 3in}@media (min-width:700px) and (orientation:landscape){a{color:red}}@supports not ((text-align-last:justify) or (-moz-text-align-last:justify)){p{text-align:justify}}@media only all and (max-width:50em),only all and (max-device-width:800px),only all and (max-width:780px){a{height:1px}}@media screen AND (-webkit-min-device-pixel-ratio:0){div,p{margin:2px}}@media only screen and (-webkit-min-device-pixel-ratio:1.5),only screen and (-o-min-device-pixel-ratio:3/2),only screen and (min--moz-device-pixel-ratio:1.5),only screen and (min-device-pixel-ratio:1.5){a{width:100px}}@media not all and (monochrome){a{border:none}}@media not screen and (color),print and (color){a{display:block}}@media (-webkit-min-device-pixel-ratio:0){a{border:none}}@media handheld and (grid) and (max-width:15em){a{border-width:4px}}@media screen and (min-aspect-ratio:1/1){a{border:none}}.something{top:0}@keyframes anim{0%{opacity:0}100%{opacity:1}}@-o-keyframes anim{0%{opacity:0}100%{opacity:1}}@keyframes test{0%,100%{opacity:0}}@keyframes test2{0%,100%{opacity:0}}@keyframes test3{50%{opacity:50}100%,0%{opacity:0}}@-webkit-keyframes test4{0%{transform:rotate3d(0,0,1,30deg)}100%{transform:rotate3d(0,0,1,10deg)}}