<?php
/**
 * Gallery
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Gallery', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'featured', 'gallery' ),
	'content'    => '<!-- wp:themeisle-blocks/patterns-upsell /--><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-1d2926d6","columns":2,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"64px","right":"24px","bottom":"64px","left":"24px"},"paddingTablet":{"top":"64px","right":"24px","bottom":"64px","left":"24px"},"paddingMobile":{"top":"40px","bottom":"40px"},"margin":{"top":"0px","bottom":"0px"},"columnsWidth":1140,"horizontalAlign":"center","verticalAlign":"center","reverseColumnsMobile":true,"align":"full","className":"ticss-c00aadba","hasCustomCSS":true,"customCSS":""} --><div id="wp-block-themeisle-blocks-advanced-columns-1d2926d6" class="wp-block-themeisle-blocks-advanced-columns alignfull has-2-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-reverse-columns-mobile has-vertical-center ticss-c00aadba"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-e32f0cfa","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"paddingMobile":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"margin":{"top":"0px","right":"12px","bottom":"0px","left":"12px"},"marginMobile":{"right":"0px","left":"0px"},"columnWidth":"70.00"} --><div id="wp-block-themeisle-blocks-advanced-column-e32f0cfa" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:gallery {"columns":2,"linkTo":"none","otterConditions":[],"isMasonry":true} --><figure class="wp-block-gallery has-nested-images columns-2 is-cropped"><!-- wp:image {"id":310,"sizeSlug":"large","linkDestination":"none"} --><figure class="wp-block-image size-large"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/otter-demo-02.png" alt="" class="wp-image-310"/></figure><!-- /wp:image --><!-- wp:image {"id":245,"sizeSlug":"large","linkDestination":"none"} --><figure class="wp-block-image size-large"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/image-from-rawpixel-id-1054569-jpeg-1.png" alt="" class="wp-image-245"/></figure><!-- /wp:image --><!-- wp:image {"id":261,"sizeSlug":"large","linkDestination":"none"} --><figure class="wp-block-image size-large"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/image-from-rawpixel-id-1054551-jpeg-1024x715.jpg" alt="" class="wp-image-261"/></figure><!-- /wp:image --><!-- wp:image {"id":309,"sizeSlug":"large","linkDestination":"none"} --><figure class="wp-block-image size-large"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/otter-demo-03.png" alt="" class="wp-image-309"/></figure><!-- /wp:image --></figure><!-- /wp:gallery --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-631489be","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"paddingMobile":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"margin":{"top":"0px","right":"12px","bottom":"0px","left":"12px"},"marginMobile":{"right":"0px","bottom":"24px","left":"0px"},"border":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"columnWidth":"30.00"} --><div id="wp-block-themeisle-blocks-advanced-column-631489be" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-1d40683c","tag":"p","fontSize":12,"fontSizeTablet":12,"fontSizeMobile":12,"textTransform":"uppercase"} --><p id="wp-block-themeisle-blocks-advanced-heading-1d40683c" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-1d40683c"><strong>Gallery section</strong></p><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-0af3bf17"} --><h2 id="wp-block-themeisle-blocks-advanced-heading-0af3bf17" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-0af3bf17">A gallery with a text column and some text</h2><!-- /wp:themeisle-blocks/advanced-heading --></div><!-- /wp:themeisle-blocks/advanced-column --></div></div><!-- /wp:themeisle-blocks/advanced-columns -->',
);
