#yoast-configuration .yst-input{border-radius:.375rem!important;border-width:1px!important;--tw-bg-opacity:1!important;background-color:rgb(255 255 255/var(--tw-bg-opacity,1))!important;font-size:.8125rem!important;padding:.5rem .75rem!important;--tw-shadow:0 1px 2px 0 #0000000d!important;--tw-shadow-colored:0 1px 2px 0 var(--tw-shadow-color)!important;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)!important}#yoast-configuration .yst-radio{align-items:center!important;display:flex!important}#yoast-configuration .yst-radio__input{appearance:none!important;border-radius:9999px!important;border-width:1px!important;height:1rem!important;margin:0!important;width:1rem!important;--tw-border-opacity:1!important;border-color:rgb(209 213 219/var(--tw-border-opacity,1))!important;--tw-text-opacity:1!important;color:rgb(166 30 105/var(--tw-text-opacity,1))!important;--tw-shadow:0 0 #0000!important;--tw-shadow-colored:0 0 #0000!important;box-shadow:var(--tw-ring-offset-shadow,0 0 #0000),var(--tw-ring-shadow,0 0 #0000),var(--tw-shadow)!important;transition-property:none!important}#yoast-configuration .yst-radio__input:before{content:var(--tw-content)!important;display:none!important}#yoast-configuration .yst-radio__input:checked{border-width:5px!important;--tw-border-opacity:1!important;border-color:rgb(166 30 105/var(--tw-border-opacity,1))!important}#yoast-configuration .yst-radio__input:focus{outline:2px solid #0000!important;outline-offset:2px!important;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color)!important;--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color)!important;box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow,0 0 #0000)!important;--tw-ring-opacity:1!important;--tw-ring-color:rgb(166 30 105/var(--tw-ring-opacity,1))!important;--tw-ring-offset-width:2px!important;--tw-ring-offset-color:#fff!important}#yoast-configuration .yst-radio__label{font-weight:500!important;margin-right:.75rem!important;--tw-text-opacity:1!important;color:rgb(55 65 81/var(--tw-text-opacity,1))!important}#yoast-configuration .yst-radio-group__label{margin-bottom:.25rem!important}#yoast-configuration .yst-radio-group__options{display:flex!important;flex-direction:column!important;gap:.5rem!important}#yoast-configuration .yst-radio-group__description{margin-bottom:1rem!important}#yoast-configuration .yst-checkbox__input:before{--tw-content:none!important;content:var(--tw-content)!important}