/*! dont delete me */
.foo{  /* ha */}
@import "another.css";
/* I'm empty - delete me */
empty { ;}
.test{color:red}
@media (-o-device-pixel-ratio:  1/10) {


    }
a[href$="/test/"] span.test{}
#foo{ }
:after{  ;}
@media print {
    /* empty */
    body{

    }
}

@media screen {
    /* this rule should be removed, not simply minified.*/
    .breakme {}
    .printonly { display: none; }
}

@media print {
    /* empty */
    @media (min-aspect-ratio: 1/1) {
        /* empty */
        a {
            /* empty */
        }
    }
    /*! imp: weird but it may happen */
    b{
        
    }
}