<?php
/**
 * Content with Progress Bars
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Content with Progress Bars', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'columns' ),
	'content'    => '<!-- wp:themeisle-blocks/patterns-upsell /--><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-35825447","columns":2,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"64px","right":"24px","bottom":"64px","left":"24px"},"paddingTablet":{"top":"64px","right":"24px","bottom":"64px","left":"24px"},"paddingMobile":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"margin":{"top":"0px","bottom":"0px"},"columnsWidth":1140,"horizontalAlign":"center","verticalAlign":"center","align":"full","className":"ticss-c00aadba","hasCustomCSS":true,"customCSS":""} --><div id="wp-block-themeisle-blocks-advanced-columns-35825447" class="wp-block-themeisle-blocks-advanced-columns alignfull has-2-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-center ticss-c00aadba"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-fedc9d47","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"paddingMobile":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"columnWidth":"50"} --><div id="wp-block-themeisle-blocks-advanced-column-fedc9d47" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:image {"id":247,"sizeSlug":"full","linkDestination":"none"} --><figure class="wp-block-image size-full"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/image-from-rawpixel-id-1054555-jpeg-1.png" alt="" class="wp-image-247"/></figure><!-- /wp:image --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-ed1b12ac","padding":{"top":"24px","right":"24px","bottom":"24px","left":"24px"},"columnWidth":"50"} --><div id="wp-block-themeisle-blocks-advanced-column-ed1b12ac" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-8f3ca166"} --><h2 id="wp-block-themeisle-blocks-advanced-heading-8f3ca166" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-8f3ca166">Skills</h2><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:paragraph --><p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta.</p><!-- /wp:paragraph --><!-- wp:themeisle-blocks/progress-bar {"id":"wp-block-themeisle-blocks-progress-bar-b4d63408","title":"Statistic","percentagePosition":"append","borderRadius":35,"backgroundColor":"#ffffff","barBackgroundColor":"#0c0c0c"} --><div id="wp-block-themeisle-blocks-progress-bar-b4d63408" class="wp-block-themeisle-blocks-progress-bar" data-percent="50" data-duration="2"><div class="wp-block-themeisle-blocks-progress-bar__area"><div class="wp-block-themeisle-blocks-progress-bar__area__title"><span>Statistic</span></div><div class="wp-block-themeisle-blocks-progress-bar__area__bar"><div class="wp-block-themeisle-blocks-progress-bar__progress__append wp-block-themeisle-blocks-progress-bar__number">50</div></div></div></div><!-- /wp:themeisle-blocks/progress-bar --><!-- wp:spacer {"height":10} --><div style="height:10px" aria-hidden="true" class="wp-block-spacer"></div><!-- /wp:spacer --><!-- wp:themeisle-blocks/progress-bar {"id":"wp-block-themeisle-blocks-progress-bar-d620fe76","title":"Statistic","percentage":82,"percentagePosition":"append","borderRadius":35,"backgroundColor":"#ffffff","barBackgroundColor":"#0c0c0c"} --><div id="wp-block-themeisle-blocks-progress-bar-d620fe76" class="wp-block-themeisle-blocks-progress-bar" data-percent="82" data-duration="2"><div class="wp-block-themeisle-blocks-progress-bar__area"><div class="wp-block-themeisle-blocks-progress-bar__area__title"><span>Statistic</span></div><div class="wp-block-themeisle-blocks-progress-bar__area__bar"><div class="wp-block-themeisle-blocks-progress-bar__progress__append wp-block-themeisle-blocks-progress-bar__number">82</div></div></div></div><!-- /wp:themeisle-blocks/progress-bar --></div><!-- /wp:themeisle-blocks/advanced-column --></div></div><!-- /wp:themeisle-blocks/advanced-columns -->',
);
