.wp-block-themeisle-blocks-font-awesome-icons{--align: center;--align-tablet: var(--align);--align-mobile: var(--align-tablet);--border-color: inherit;--border-size: unset;--border-radius: 0%;--margin: 5px;--padding: 5px;--font-size: 16px;display:flex;justify-content:var(--align);margin:0}.wp-block-themeisle-blocks-font-awesome-icons .wp-block-themeisle-blocks-font-awesome-icons-container{display:inline-flex;justify-content:center;border:var(--border-size) solid;border-color:var(--border-color);border-radius:var(--border-radius);margin:var(--margin);font-size:var(--font-size);text-align:center;align-items:center;box-sizing:content-box}.wp-block-themeisle-blocks-font-awesome-icons .wp-block-themeisle-blocks-font-awesome-icons-container:not(.nan-padding){width:calc(var(--font-size)*1.5 + var(--padding));height:calc(var(--font-size)*1.5 + var(--padding))}.wp-block-themeisle-blocks-font-awesome-icons .wp-block-themeisle-blocks-font-awesome-icons-container:not(.nan-padding) i{font-size:var(--font-size)}.wp-block-themeisle-blocks-font-awesome-icons .wp-block-themeisle-blocks-font-awesome-icons-container.nan-padding{padding:var(--padding);aspect-ratio:1}.wp-block-themeisle-blocks-font-awesome-icons .wp-block-themeisle-blocks-font-awesome-icons-container.nan-padding i{font-size:calc(var(--font-size)/1.25);width:var(--font-size)}.wp-block-themeisle-blocks-font-awesome-icons .wp-block-themeisle-blocks-font-awesome-icons-container svg{width:var(--font-size);height:var(--font-size);fill:currentColor}@media(max-width: 960px){.wp-block-themeisle-blocks-font-awesome-icons{justify-content:var(--align-tablet)}}@media(max-width: 600px){.wp-block-themeisle-blocks-font-awesome-icons{justify-content:var(--align-mobile)}}/*# sourceMappingURL=style.css.map */
