.hestia-wizard-wrap * {
  box-sizing: border-box;
  margin: 0;
  padding: 0;
}

.hestia-wizard-wrap img {
  max-width: 100%;
  display: block;
}

.h1 {
  font-size: 45px;
  line-height: 54px;
  font-weight: 700;
  color: #393939;
}

.h2 {
  font-size: 32px;
  line-height: 38px;
  font-weight: 700;
  color: #393939;
}

.h3 {
  font-size: 24px;
  line-height: 28px;
  font-weight: 600;
  color: #393939;
}

.h4 {
  font-size: 20px;
  line-height: 24px;
  font-weight: 600;
  color: #393939;
}

.p {
  font-size: 16px;
  line-height: 24px;
}
.p a {
  text-decoration: none;
  color: #2B9AF3;
}

.p-8 {
  padding: 8px;
}

.pt-8 {
  padding-top: 8px;
}

.pb-8 {
  padding-bottom: 8px;
}

.pb-4 {
  padding-bottom: 4px;
}

.pb-0 {
  padding-bottom: 0 !important;
}

.pt-12 {
  padding-top: 12px;
}

.pb-16 {
  padding-bottom: 16px;
}

.pl-16 {
  padding-left: 16px;
}

.pb-32 {
  padding-bottom: 32px;
}

.pt-32 {
  padding-top: 32px;
}

.mb-20 {
  margin-bottom: 20px;
}

.mb-30 {
  margin-bottom: 30px;
}

.mb-24 {
  margin-bottom: 24px;
}

a:focus {
  box-shadow: none;
  outline: 0;
}

.hestia-btn {
  padding: 14px 32px;
  font-size: 16px;
  line-height: 19px;
  font-weight: 500;
  border-radius: 0;
  border: 1px solid #000;
  display: inline-flex;
  align-items: center;
  outline: 0;
  cursor: pointer;
  text-decoration: none;
  text-transform: capitalize;
  transition: all 0.3s ease-in-out;
}
.hestia-btn .dashicons {
  transition: initial;
}
.hestia-btn .icon-right {
  margin-left: 16px;
}
.hestia-btn .icon-left {
  margin-right: 16px;
}

.hestia-btn.btn-icon {
  width: 48px;
  height: 48px;
  padding: 0;
  display: flex;
  align-items: center;
  justify-content: center;
}

.hestia-btn.btn-primary {
  background: #EB3B71;
  border-color: #EB3B71;
  color: #ffffff;
}

.hestia-btn.btn-primary:hover,
.hestia-btn.btn-primary:focus,
.hestia-btn.btn-primary:active {
  background: #FB155B;
  border-color: #FB155B;
}

.hestia-btn.btn-primary.disabled {
  color: #ffffff;
  border-color: rgba(235, 59, 113, 0.6);
  background: rgba(235, 59, 113, 0.6);
  pointer-events: none;
  cursor: auto;
}

.hestia-btn.btn-outline-primary {
  background: transparent;
  border-color: #EB3B71;
  color: #EB3B71;
}

.hestia-btn.btn-outline-primary:hover,
.hestia-btn.btn-outline-primary:focus,
.hestia-btn.btn-outline-primary:active {
  background: #EB3B71;
  border-color: #EB3B71;
  color: #ffffff;
}

.hestia-btn.btn-outline-primary.disabled {
  color: #ffffff;
  border-color: rgba(235, 59, 113, 0.6);
  background: rgba(235, 59, 113, 0.6);
  pointer-events: none;
  cursor: auto;
}

.hestia-btn.btn-link {
  background: transparent;
  border: 0;
  padding: 0;
  color: #EB3B71;
}

.hestia-btn.btn-link:hover,
.hestia-btn.btn-link:focus,
.hestia-btn.btn-link:active {
  color: #FB155B;
}

.hestia-btn.btn-flate {
  background: transparent;
  border: 0;
  color: #393939;
}

.hestia-btn.btn-flate:hover,
.hestia-btn.btn-flate:focus,
.hestia-btn.btn-flate:active {
  background: transparent;
  color: #EB3B71;
}

.hestia-btn.btn-flate.disabled {
  color: #393939;
  background: rgba(57, 57, 57, 0.2);
  pointer-events: none;
  cursor: auto;
}

.hestia-wizard-fullscreen #adminmenumain, .hestia-wizard-fullscreen #wpadminbar, .hestia-wizard-fullscreen .error:not(#message), .hestia-wizard-fullscreen .updated, .hestia-wizard-fullscreen #wpfooter {
  display: none !important;
}
.hestia-wizard-fullscreen #wpwrap, .hestia-wizard-fullscreen #wp-content, .hestia-wizard-fullscreen #wpbody, .hestia-wizard-fullscreen #wpbody-content {
  padding-top: 0 !important;
  height: 100%;
}
.hestia-wizard-fullscreen #wpbody-content {
  padding: 0;
}
.hestia-wizard-fullscreen #wpcontent, .hestia-wizard-fullscreen #wpfooter {
  margin-left: 0;
  padding-left: 0;
}

html.wp-toolbar {
  padding-top: 0;
}
html.wp-toolbar .hestia-wizard-fullscreen {
  margin-top: 0;
}

.hestia-wizard-wrap {
  display: flex;
  flex-direction: column;
  height: 100%;
  background-color: #E4E4E6;
}

.hestia-header {
  height: 70px;
  background: #ffffff;
  display: flex;
  justify-content: space-between;
}
.hestia-header .hestia-logo {
  border-right: 2px solid #E4E4E6;
  width: 72px;
  padding: 20px;
}
.hestia-header .hestia-dashboard-link {
  border-left: 2px solid #E4E4E6;
  width: 72px;
}
.hestia-header .hestia-dashboard-link a {
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  text-decoration: none;
  color: #D9D9D9;
  transition: all 0.3s ease-in-out;
}
.hestia-header .hestia-dashboard-link a:hover {
  color: #EB3B71;
}
.hestia-header .hestia-dashboard-link a .dashicons {
  font-size: 30px;
  width: 30px;
  height: 30px;
  display: block;
}

.hestia-wizard {
  height: calc(100% - 70px);
}
.hestia-wizard .sw {
  border: 0;
  height: 100%;
}
.hestia-wizard .sw .tab-content {
  height: 100%;
}
.hestia-wizard .sw .tab-content .tab-pane {
  padding: 0;
  height: 100%;
}
.hestia-wizard .sw .toolbar {
  display: none;
}
.hestia-wizard .sw .nav {
  display: none;
}
.hestia-wizard__content {
  height: 100%;
  display: flex;
  flex-direction: column;
  position: relative;
}
.hestia-wizard__body {
  height: 100%;
  overflow: auto;
  padding: 48px 16px;
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
}
.hestia-wizard__body .hestia-card-box {
  max-width: 800px;
  width: 100%;
  margin: 0 auto;
  padding: 32px 32px 48px;
  background: #ffffff;
  color: #1F1D1D;
  font-size: 16px;
  line-height: 24px;
}
.hestia-wizard__body .hestia-card-box .title-wrap {
  padding-bottom: 32px;
}
.hestia-wizard__body .hestia-card-box .title-wrap .h2 {
  padding-bottom: 8px;
}
.hestia-wizard__body .hestia-card-box .title-wrap .title-content-img {
  display: flex;
}
.hestia-wizard__body .hestia-card-box .title-wrap .title-content-img .img {
  flex-shrink: 0;
  margin-left: 32px;
  padding-right: 36px;
}
.hestia-wizard__body .hestia-card-box span.spinner {
  margin-bottom: 8px;
  float: revert;
}
.hestia-wizard__body .hestia-card-box span.hestia-field-error {
  color: #F00;
}
.hestia-wizard__footer {
  height: 70px;
  background: #ffffff;
  flex-shrink: 0;
  display: flex;
  justify-content: space-between;
}
.hestia-wizard__footer .hestia-btn {
  height: 100%;
}
.hestia-wizard__footer .left {
  border-right: 2px solid #E4E4E6;
}
.hestia-wizard__footer .left.disabled {
  opacity: 0.5;
  pointer-events: none;
}
.hestia-wizard__footer .right {
  border-left: 2px solid #E4E4E6;
}
.hestia-wizard__footer .right.disabled {
  opacity: 0.5;
  pointer-events: none;
}

.welcom-card {
  text-align: center;
  padding-top: 16px;
  max-width: 570px;
  margin: 0 auto;
}
.welcom-card .logo {
  display: flex;
  text-align: center;
  justify-content: center;
  padding-bottom: 33px;
}
.welcom-card .logo a {
  display: flex;
  align-items: center;
  font-size: 48px;
  line-height: 58px;
  color: #393939;
  font-weight: 700;
  text-decoration: none;
}
.welcom-card .logo a img {
  width: 71px;
  flex-shrink: 0;
  margin-right: 11px;
}
.welcom-card .h1 {
  padding-bottom: 16px;
}
.welcom-card p {
  font-size: 16px;
  line-height: 24px;
}
.welcom-card .cta {
  padding-top: 32px;
}
.welcom-card .cta > div {
  padding-top: 16px;
}

.step-progress-bar {
  padding-bottom: 48px;
}
.step-progress-bar ul {
  display: flex;
  align-items: center;
  justify-content: center;
  pointer-events: none;
}
.step-progress-bar ul li {
  position: relative;
  padding: 0 4px;
  display: flex;
  align-items: center;
}
.step-progress-bar ul li:not(:last-child):after {
  content: "";
  width: 72px;
  height: 2px;
  background: #C6C6C6;
  display: block;
  margin-left: 8px;
  flex-shrink: 0;
}
.step-progress-bar ul li .circle {
  width: 24px;
  height: 24px;
  border: 2px solid #C6C6C6;
  border-radius: 100%;
  flex-shrink: 0;
  margin-right: 8px;
  display: grid;
  place-items: center;
  transition: all 0.3s ease-in-out;
}
.step-progress-bar ul li .circle:after {
  content: "";
  position: absolute;
  width: 10px;
  height: 10px;
  background: #757575;
  border-radius: 100%;
  transform: scale(0);
  transition: all 0.3s ease-in-out;
}
.step-progress-bar ul li .step-name {
  font-size: 14px;
  color: #C6C6C6;
  transition: all 0.3s ease-in-out;
}
.step-progress-bar ul li.active .circle, .step-progress-bar ul li.done .circle {
  border-color: #757575;
}
.step-progress-bar ul li.active .circle:after, .step-progress-bar ul li.done .circle:after {
  transform: scale(1);
}
.step-progress-bar ul li.active .step-name, .step-progress-bar ul li.done .step-name {
  color: #757575;
}
.step-progress-bar ul li.done:after {
  background: #757575;
}

.hestia-form-wrap.recommendations-wrap {
  width: 100%;
}
.hestia-form-wrap .form-label {
  display: block;
}
.hestia-form-wrap .form-control {
  display: block;
  width: 100%;
  height: 48px;
  padding: 0px 16px;
  border: 1px solid #D9D9D9;
  border-radius: 0px;
  color: #393939;
  background-color: #fff;
  box-shadow: none;
  font-size: 16px;
  line-height: 24px;
  -webkit-transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
  -webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
}
.hestia-form-wrap .form-control:focus {
  border-color: #EB3B71;
  outline: 0;
  box-shadow: none;
}
.hestia-form-wrap .form-control::-moz-placeholder {
  opacity: 1;
  color: #838383;
}
.hestia-form-wrap .form-control:-ms-input-placeholder {
  color: #838383;
}
.hestia-form-wrap .form-control::-webkit-input-placeholder {
  color: #838383;
}
.hestia-form-wrap .form-control.form-control-sm {
  height: 30px;
}
.hestia-form-wrap .wp-picker-container .wp-color-result.button {
  padding-left: 35px;
}
.hestia-form-wrap .wp-picker-container .wp-color-result .wp-color-result-text {
  padding: 0 8px;
  font-size: 14px;
}
.hestia-form-wrap .hestia-upload-ui .attachment-media-view {
  max-width: 360px;
}
.hestia-form-wrap .hestia-upload-ui .attachment-media-view .thumbnail-image {
  max-width: 150px;
  max-height: 100px;
}
.hestia-form-wrap .drag-drop .hestia-drag-drop-area {
  border: 2px dashed #64666A !important;
  height: auto !important;
  margin-bottom: 15px;
}
.hestia-form-wrap .drag-drop .hestia-drag-drop-area .drag-drop-inside {
  margin: 0 auto;
  width: 100%;
  height: 100%;
  text-align: center;
  padding: 13px;
  color: #64666A;
}
.hestia-form-wrap .drag-drop .hestia-drag-drop-area .drag-drop-inside a {
  text-decoration: none;
}

.help-text {
  font-size: 14px;
  line-height: 17px;
  font-weight: 400;
  color: #51575D;
}

.help-text a {
  display: inline-block;
  text-decoration: none;
  color: #2F5AAE;
  font-weight: 400;
}

.hestia-radio {
  position: relative;
  display: flex;
  align-items: center;
}
.hestia-radio label {
  color: #050505;
  font-size: 16px;
  line-height: 20px;
  margin-left: 10px;
}

input[type=radio].hestia-radio-btn {
  position: relative;
  width: 20px;
  height: 20px;
  border: 1px solid #050505;
  flex-shrink: 0;
  margin: 0;
  outline: 0;
  box-shadow: none;
  transition: all 0.3s ease-in-out;
}
input[type=radio].hestia-radio-btn:focus {
  border-color: #4268CF;
}
input[type=radio].hestia-radio-btn:checked {
  background: #4268CF;
  border-color: #4268CF;
}
input[type=radio].hestia-radio-btn:checked:before {
  width: 8px;
  height: 8px;
  margin: 5px;
  background: #ffffff;
}

input[type=checkbox].hestia-checkbox-btn {
  position: relative;
  width: 20px;
  height: 20px;
  border: 1px solid #1E1E1E;
  flex-shrink: 0;
  border-radius: 2px;
  margin: 0;
  outline: 0;
  box-shadow: none;
  transition: all 0.3s ease-in-out;
}
input[type=checkbox].hestia-checkbox-btn:focus {
  border-color: #4268CF;
}
input[type=checkbox].hestia-checkbox-btn:before {
  display: none;
}
input[type=checkbox].hestia-checkbox-btn:checked {
  background: #4268CF;
  border-color: #4268CF;
}
input[type=checkbox].hestia-checkbox-btn:checked:after {
  content: "\f15e";
  font-family: dashicons;
  width: 16px;
  height: 16px;
  font-size: 16px;
  line-height: 1;
  color: #ffffff;
  position: absolute;
  inset: 0;
  margin: auto;
}

input[type=checkbox].hestia-switch-btn {
  width: 36px;
  height: 18px;
  color: #1E1E1E;
  background: #ffffff;
  border: 1px solid #1E1E1E;
  border-radius: 20px;
  margin-top: 0;
  box-shadow: none;
  position: relative;
  outline: 0;
  outline-offset: 0;
  transition: all 0.3s ease-in-out;
}
input[type=checkbox].hestia-switch-btn:before {
  content: "";
  width: 12px;
  height: 12px;
  position: absolute;
  top: 2px;
  left: 3px;
  background: currentColor;
  border-radius: 20px;
  transition: all 0.3s ease-in-out;
}
input[type=checkbox].hestia-switch-btn:focus {
  outline: 1px solid #4268CF;
  outline-offset: 3px;
}
input[type=checkbox].hestia-switch-btn:checked {
  background: #4268CF;
  border-color: #4268CF;
  color: #ffffff;
}
input[type=checkbox].hestia-switch-btn:checked:before {
  left: 19px;
  margin: 0;
}

.finish-box {
  text-align: center;
  padding-top: 16px;
}
.finish-box .video-box {
  max-width: 619px;
  margin: 0 auto;
  padding-top: 16px;
}
.finish-box .video-box iframe {
  width: 100%;
  height: 348px;
  margin-bottom: 16px;
}
.finish-box .cta {
  padding-top: 32px;
}

/* hestia accordion style start */
.hestia-accordion-item {
  background: #ffffff;
  border: 1px solid #D9D9D9;
}
.hestia-accordion-item__title {
  position: relative;
}
.hestia-accordion-item__button {
  width: 100%;
  position: relative;
  text-align: left;
  border: 0;
  background: transparent;
  outline: 0;
  padding: 30px 90px 30px 30px;
  cursor: pointer;
  transition: all 0.3s ease-in-out;
}
.hestia-accordion-item__content {
  font-size: 16px;
  line-height: 24px;
  color: #000000;
  padding: 0 30px 6px;
  position: relative;
}
.hestia-accordion-item__content.border-top > div {
  border-top: 1px solid #D9D9D9;
}
.hestia-accordion-item.hestia-features-accordion .hestia-accordion-item__content {
  padding-left: 20px;
  padding-right: 20px;
}

.hestia-accordion__step-number {
  padding-bottom: 10px;
  padding-bottom: 0;
  height: 0;
  opacity: 0;
  transition: all 0.3s ease-in-out;
}
.hestia-accordion__step-title {
  color: #050505;
}
.hestia-accordion__icon {
  position: absolute;
  right: 30px;
  top: 50%;
  margin-top: -24px;
  width: 48px;
  height: 48px;
  background: transparent;
  border-radius: 24px;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 20px;
  line-height: 1;
  color: #1E1E1E;
  transition: all 0.3s ease-in-out;
}
.hestia-accordion__icon--success {
  width: 24px;
  height: 24px;
  margin-top: -12px;
  background: #4268CF !important;
  color: #ffffff;
}
.hestia-accordion__icon:hover {
  background: #E4E6E8;
}
.hestia-accordion .hestia-accordion-item {
  margin-bottom: 30px;
}
.hestia-accordion .hestia-accordion-item.hestia-features-accordion:first-child {
  border-radius: 8px 8px 0 0;
}
.hestia-accordion .hestia-accordion-item.hestia-features-accordion:last-child {
  border-radius: 0 0 8px 8px;
}
.hestia-accordion .hestia-accordion-item.hestia-features-accordion:only-child {
  border-radius: 8px;
}
.hestia-accordion .hestia-accordion-item.hestia-features-accordion + .hestia-features-accordion {
  border-top: 0;
}
.hestia-accordion .hestia-accordion-item.mb-0 {
  margin-bottom: 0;
}
.hestia-accordion .hestia-accordion-item .hestia-accordion-item__content {
  display: none;
  background: rgba(217, 217, 217, 0.2);
}
.hestia-accordion .hestia-accordion-item .hestia-accordion-item__content.is-active {
  display: block;
}
.hestia-accordion .hestia-accordion-item .hestia-accordion-checkbox__title .hestia-accordion-item__button {
  padding-left: 80px;
  padding-top: 16px;
  padding-bottom: 16px;
}
.hestia-accordion .hestia-accordion-item .hestia-accordion-checkbox__title .hestia-checkbox {
  position: absolute;
  left: 30px;
  top: 50%;
  margin-top: -10px;
  width: 20px;
  height: 20px;
  z-index: 12;
}
.hestia-accordion .hestia-accordion-item .hestia-accordion-checkbox__title .hestia-checkbox input[type=checkbox].hestia-checkbox-btn {
  display: block;
}
.hestia-accordion .hestia-accordion-item .is-active .hestia-accordion-item__button {
  background: rgba(217, 217, 217, 0.2);
}
.hestia-accordion .hestia-accordion-item .is-active .hestia-accordion__step-number {
  opacity: 1;
  height: 27px;
  padding-bottom: 5px;
}
.hestia-accordion .hestia-accordion-item .is-active .hestia-accordion__icon {
  color: #050505;
  transform: rotate(180deg);
}

.hestia-features-list ul li {
  padding: 16px 0;
  display: flex;
  align-items: center;
}
.hestia-features-list ul li .icon {
  width: 35px;
  height: 35px;
  flex-shrink: 0;
  margin-right: 25px;
  background: rgba(217, 217, 217, 0.4);
  border-radius: 6px;
  display: flex;
  align-items: center;
  justify-content: center;
}
.hestia-features-list ul li .txt {
  width: 100%;
}

.pro-label {
  background: #007CBA;
  border-radius: 6px;
  color: #ffffff;
  text-transform: uppercase;
  font-size: 16px;
  line-height: 19px;
  padding: 2px 9px 4px;
}

.pro-label.free-label {
  background: #BDE6EB;
  border-radius: 6px;
  color: #39C3D2;
  text-transform: none;
  font-size: 16px;
  line-height: 19px;
  padding: 2px 9px 4px;
}

/* hestia accordion style End */
.select-page-option:not(.hidden) {
  display: flex;
}
.select-page-option .label {
  flex-shrink: 0;
  margin-right: 16px;
}
.select-page-option .select-option-box {
  width: 100%;
  max-width: 325px;
}
.select-page-option .select-option-box .add-new-option-box:not(.hidden) {
  padding-top: 8px;
  display: flex;
}
.select-page-option .select-option-box .add-new-option-box > div {
  width: 100%;
}
.select-page-option .select-option-box .add-new-option-box .add-btn {
  flex-shrink: 0;
  padding: 4px 18px 5px;
  border: 1px solid #047ABA;
  border-radius: 2px;
  color: #047ABA;
  font-size: 14px;
  background: #F0F0F1;
  font-weight: 500;
  margin-left: 12px;
}
.select-page-option .select-option-box .add-new-page {
  padding-top: 8px;
}
.select-page-option .select-option-box .add-new-page button, .select-page-option .select-option-box .add-new-page a {
  display: inline-block;
  background: transparent;
  border: 0;
  font-size: 14px;
  color: #4268CF;
  font-weight: 500;
  text-decoration: underline;
  cursor: pointer;
}
.select-page-option .select-option-box .add-new.disabled {
  opacity: 0.5;
  pointer-events: none;
}
.select-page-option .select-option-box .add-btn {
  cursor: pointer;
}
.select-page-option .select-option-box .add-btn.disabled {
  opacity: 0.5;
}

.title-content-img img {
  max-width: 100%;
}
.title-content-img .app-icon-preview {
  margin-top: 9px;
  background-color: transparent;
}
.title-content-img .favicon-preview {
  float: left;
  margin-right: 12px;
  margin-bottom: 0;
}
.title-content-img .site-icon-preview .browser-title {
  font-size: 13px;
  line-height: 1.4em;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.gif-animation {
  pointer-events: none;
}
.gif-animation:not(.show) {
  display: none;
}
.gif-animation.show {
  position: absolute;
  bottom: 70px;
  left: 0;
  width: 100%;
  height: calc(100% - 70px);
  display: flex;
  align-items: flex-end;
  justify-content: center;
}