/* Named */
#\:white a[black=":white;"] {
    background-image: url(assets/images/white.png);
    color: white;
    white-space: normal;
    color: whitesmoke;
    background: white;
    background: border-box fuchsia;
    background: linear-gradient( to left top, black, #ffc0cb 60%, blueviolet);
    background-color: black;
    text-shadow: 1px 1px 2px black;
    text-shadow: white 2px 5px;
    box-shadow: 3px 3px yellow, -1em 0 0.4em fuchsia;
    outline: 1px solid white;
    outline-color: yellow;
    box: black white, yellow;
    utline-color: black white, yellow;
    border: 1px dotted rebeccapurple; /* Big hug to Eric Meyer */
    border-color: yellowgreen;
    border-bottom: 3px solid lightyellow;
    border-right-color: ghostwhite;
}

/* HEX */
b {
    color: #fffff0;
    color: #f00;
}
.color {
    impressed: #FfEedD;
    again: #ABCDEF;
    andagain:#aa66cc;
    background-color:#aa66ccc;
    filter: chroma(color="#FFFFFF");
    color:#1122aa
}
.foo, #AABBCC {
    background-color:#aabbcc;
    border-color:#Ee66aA #ABCDEF #FeAb2C;
    filter:chroma(color = #FFFFFF );
    filter:chroma(color="#AABBCC");
    filter:chroma(color='#BBDDEE');
    color:#112233
}
#AABBCC, #ffffff, #f0f0f0, #f00 {
    background-color:#ffee11;
    filter: chroma(color = #FFFFFF );
    color:#441122;
    foo:#00fF11 #ABC #AABbCc #123344;
    border-color:#aa66ccC
}

.foo #AABBCC {
    background-color:#fFEe11;
    color:#441122;
    border-color:#AbC;
    filter: chroma(color= #FFFFFF)
}

.bar, #AABBCC {
    background-color:#FFee11;
    border-color:#00fF11 #ABCDEF;
    filter: chroma(color=#11FFFFFF);
    color:#441122;
}

.foo, #AABBCC.foobar {
    background-color:#ffee11;
    border-color:#00fF11 #ABCDEF #AABbCc;
    color:#441122;
}

@media screen {
    .bar, #AABBCC {
        background-color:#ffEE11;
        color:#441122
    }
}


/* RGB */
a{
    background: none repeat scroll 0 0 rgb(255, 0,0 );
    alpha: rgba(1, 2, 3, 4);
    background-image: linear-gradient(to bottom, rgb(210,180,140)10%, rgb(255,0,0)90%);
    background-image: linear-gradient(to bottom, rgb(255, 0,  0) 10%, rgb(255  ,0,0) 90%);
    background: linear-gradient(to bottom, rgb(100%, 0%,  0%), rgb(100%  ,0%,0%));
    color: rgb( 90%, 80.1%, 76.4% );
    color: rgb(256,-1,0);
    color: rgb( 101%,-1%,0%);
    test-overflow: rgb(1000, 500, 300);
}

/* RGBA */
d {
    alpha: rgba(1, 2, 3, 4);
    border-color: RGBA(1,2,3,4); /* tests uppercase RGBA() */
}

/* HSL */
* {
    color: hsl(0, 100%, 50%); /* red */
    color: hsl( 120, 100%, 50.5% ); /* #03FF03 */
    color:hsl(240,13.4%,12.6%); /* #1C1C24 */
    color:  hsl(-120, 33%, 92%  ); /* #E4E4F1 */
    color:hsl( 480, -56%, 13%); /* #212121 */
}