<?php
/**
 * Fitness - Contact
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Fitness - Contact', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'pages', 'fitness-pack' ),
	'content'    => '<!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-ceb6a764","columns":1,"layout":"equal","padding":{"top":"80px","bottom":"80px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"40px","bottom":"40px","left":"40px","right":"40px"},"margin":{"top":"0px","bottom":"0px"},"marginTablet":{"top":null,"bottom":null},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1100,"horizontalAlign":"center","columnsHeight":"custom","columnsHeightCustom":390,"columnsHeightCustomTablet":240,"columnsHeightCustomMobile":160,"verticalAlign":"center","backgroundType":"image","backgroundImage":{"id":101,"url":"https://api.themeisle.com/templates-data/2020/11/ebf0233ced7259cf0838b7ba6d3aee07nk7yyl7xh3kqb2op4lu3/images/neve-gym-demo-12.jpg"},"backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundRepeat":"no-repeat","backgroundSize":"cover","backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"align":"full","className":""} --><div id="wp-block-themeisle-blocks-advanced-columns-ceb6a764" class="wp-block-themeisle-blocks-advanced-columns alignfull has-1-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-equal-layout has-vertical-center"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-b70c29e7","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginTablet":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"100","className":""} --><div id="wp-block-themeisle-blocks-advanced-column-b70c29e7" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-4b74ca17","tag":"h1","align":"center","headingColor":"#ffffff","fontSize":"70px","paddingTablet":0,"paddingMobile":0,"paddingTopTablet":0,"paddingTopMobile":0,"paddingRightTablet":0,"paddingRightMobile":0,"paddingBottomTablet":0,"paddingBottomMobile":0,"paddingLeftTablet":0,"paddingLeftMobile":0,"marginTablet":0,"marginMobile":0,"marginTopTablet":0,"marginTopMobile":0,"marginBottomTablet":25,"marginBottomMobile":20,"className":""} --><h1 id="wp-block-themeisle-blocks-advanced-heading-4b74ca17" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-4b74ca17">Contact us </h1><!-- /wp:themeisle-blocks/advanced-heading --></div><!-- /wp:themeisle-blocks/advanced-column --></div></div><!-- /wp:themeisle-blocks/advanced-columns --><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-ebcaae2c","columns":2,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"45px","bottom":"25px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"margin":{"top":"20px","bottom":"20px"},"marginTablet":{"top":"20px","bottom":"20px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1100,"horizontalAlign":"center","backgroundColor":"#ffffff","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"align":"full","className":"has-light-bg"} --><div id="wp-block-themeisle-blocks-advanced-columns-ebcaae2c" class="wp-block-themeisle-blocks-advanced-columns alignfull has-2-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-unset has-light-bg"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-02d86bdf","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":null,"bottom":null,"left":null,"right":null},"margin":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginTablet":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginMobile":{"top":"20px","bottom":"0px","left":"0px","right":"0px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","className":""} --><div id="wp-block-themeisle-blocks-advanced-column-02d86bdf" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-fd37afff","tag":"span","headingColor":"#d7393e","fontSize":14,"paddingTablet":0,"paddingMobile":0,"paddingTopTablet":0,"paddingTopMobile":0,"paddingRightTablet":0,"paddingRightMobile":0,"paddingBottomTablet":0,"paddingBottomMobile":0,"paddingLeftTablet":0,"paddingLeftMobile":0,"marginTablet":0,"marginMobile":0,"marginTopTablet":0,"marginTopMobile":0,"marginBottom":10,"marginBottomTablet":10,"marginBottomMobile":0,"className":""} --><span id="wp-block-themeisle-blocks-advanced-heading-fd37afff" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-fd37afff"><strong>LET\'S MEET EACH OTHER</strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:heading {"className":"wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-dbe2f686","style":{"elements":{"link":{"color":{"text":"var:preset|color|neve-text-color"}}},"typography":{"fontSize":"40px"},"spacing":{"margin":{"top":"0px"}}},"textColor":"neve-text-color"} --><h2 class="wp-block-heading wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-dbe2f686 has-neve-text-color-color has-text-color has-link-color" id="wp-block-themeisle-blocks-advanced-heading-dbe2f686" style="margin-top:0px;font-size:40px">Send us a message!</h2><!-- /wp:heading --><!-- wp:paragraph {"style":{"color":{"text":"#1f2025"},"elements":{"link":{"color":{"text":"#1f2025"}}}}} --><p class="has-text-color has-link-color" style="color:#1f2025">Kale chips knausgaard mustache blog fashion axe selfies salvia. Gluten-free post-ironic deep v typewriter. Cloud bread flannel poke, flexitarian vinyl iPhone church-key shaman williamsburg kitsch beard.</p><!-- /wp:paragraph --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-3414b024","tag":"span","headingColor":"#1f2025","fontSize":14,"marginBottomMobile":0,"className":""} --><span id="wp-block-themeisle-blocks-advanced-heading-3414b024" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-3414b024"><strong>0032-773 88291</strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-9a412ac0","tag":"span","headingColor":"#1f2025","fontSize":14,"marginBottom":20,"marginBottomMobile":3,"className":""} --><span id="wp-block-themeisle-blocks-advanced-heading-9a412ac0" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-9a412ac0"><strong>HELLO@NEVEFIT.COM</strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-7c3c22c3","tag":"span","headingColor":"#1f2025","fontSize":14,"marginBottom":19,"className":""} --><span id="wp-block-themeisle-blocks-advanced-heading-7c3c22c3" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-7c3c22c3"><strong>21 JUMP STREET, SAN FRANCISCO</strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:social-links --><ul class="wp-block-social-links"><!-- wp:social-link {"url":"aaexample@example.com","service":"facebook"} /--><!-- wp:social-link {"url":"aaexample@example.com","service":"twitter"} /--><!-- wp:social-link {"url":"aaexample@example.com","service":"google"} /--><!-- wp:social-link {"url":"aaexample@example.com","service":"pinterest"} /--><!-- wp:social-link {"url":"aaexample@example.com","service":"instagram"} /--></ul><!-- /wp:social-links --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-99e1169d","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginTablet":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginMobile":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","className":""} --><div id="wp-block-themeisle-blocks-advanced-column-99e1169d" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/form {"id":"wp-block-themeisle-blocks-form-4460aba6","optionName":"bf9b28ff82ce323187abc5d0feb0d8f07ecd8436_4460aba6","labelColor":"#1f2025","inputRequiredColor":"#ff0000","inputBorderColor":"#1f2025","submitMessageColor":"#08b304","submitMessageErrorColor":"#d7393e","submitBackgroundColor":"#d7393e","submitBackgroundColorHover":"#ffb546","submitColor":"#ffffff","submitColorHover":"#070731","inputColor":"#1f2025","inputBackgroundColor":"#ffffff"} --><div id="wp-block-themeisle-blocks-form-4460aba6" class="wp-block-themeisle-blocks-form" data-option-name="bf9b28ff82ce323187abc5d0feb0d8f07ecd8436_4460aba6"><form class="otter-form__container"><!-- wp:themeisle-blocks/form-input {"id":"wp-block-themeisle-blocks-form-input-1fa5a8b7","label":"Name","placeholder":"Your name","isRequired":true,"labelColor":"#1f2025"} --><div id="wp-block-themeisle-blocks-form-input-1fa5a8b7" class="wp-block-themeisle-blocks-form-input"><label for="wp-block-themeisle-blocks-form-input-1fa5a8b7-input" class="otter-form-input-label"><span class="otter-form-input-label__label">Name</span><span class="required">*</span></label><input type="text" id="wp-block-themeisle-blocks-form-input-1fa5a8b7-input" required placeholder="Your name" class="otter-form-input"/></div><!-- /wp:themeisle-blocks/form-input --><!-- wp:themeisle-blocks/form-input {"id":"wp-block-themeisle-blocks-form-input-9a639ae0","type":"email","label":"Email","placeholder":"Email address","isRequired":true,"labelColor":"#1f2025"} --><div id="wp-block-themeisle-blocks-form-input-9a639ae0" class="wp-block-themeisle-blocks-form-input"><label for="wp-block-themeisle-blocks-form-input-9a639ae0-input" class="otter-form-input-label"><span class="otter-form-input-label__label">Email</span><span class="required">*</span></label><input type="email" id="wp-block-themeisle-blocks-form-input-9a639ae0-input" required placeholder="Email address" class="otter-form-input"/></div><!-- /wp:themeisle-blocks/form-input --><!-- wp:themeisle-blocks/form-input {"id":"wp-block-themeisle-blocks-form-input-63399cc3","type":"number","label":"Phone","placeholder":"Phone Nr","isRequired":true,"labelColor":"#1f2025"} --><div id="wp-block-themeisle-blocks-form-input-63399cc3" class="wp-block-themeisle-blocks-form-input"><label for="wp-block-themeisle-blocks-form-input-63399cc3-input" class="otter-form-input-label"><span class="otter-form-input-label__label">Phone</span><span class="required">*</span></label><input type="number" id="wp-block-themeisle-blocks-form-input-63399cc3-input" required placeholder="Phone Nr" class="otter-form-input"/></div><!-- /wp:themeisle-blocks/form-input --><!-- wp:themeisle-blocks/form-textarea {"id":"wp-block-themeisle-blocks-form-textarea-7209dff5","label":"Message","placeholder":"Your message","isRequired":true} --><div id="wp-block-themeisle-blocks-form-textarea-7209dff5" class="wp-block-themeisle-blocks-form-textarea"><label for="wp-block-themeisle-blocks-form-textarea-7209dff5-input" class="otter-form-textarea-label"><span class="otter-form-textarea-label__label">Message</span><span class="required">*</span></label><textarea id="wp-block-themeisle-blocks-form-textarea-7209dff5-input" required placeholder="Your message" rows="10" class="otter-form-textarea-input"></textarea></div><!-- /wp:themeisle-blocks/form-textarea --><!-- wp:themeisle-blocks/form-nonce {"formId":"wp-block-themeisle-blocks-form-4460aba6"} /--><div class="wp-block-button"><button class="wp-block-button__link" type="submit">Submit</button></div></form></div><!-- /wp:themeisle-blocks/form --></div><!-- /wp:themeisle-blocks/advanced-column --></div></div><!-- /wp:themeisle-blocks/advanced-columns --><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-30e8a6e3","columns":1,"layout":"equal","padding":{"top":"150px","bottom":"150px","left":"20px","right":"20px"},"paddingTablet":{"top":null,"bottom":null,"left":null,"right":null},"paddingMobile":{"top":null,"bottom":null,"left":null,"right":null},"margin":{"top":"20px","bottom":"0px"},"marginTablet":{"top":null,"bottom":null},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1100,"horizontalAlign":"center","backgroundType":"image","backgroundImage":{"id":126,"url":"https://api.themeisle.com/templates-data/2020/11/ebf0233ced7259cf0838b7ba6d3aee07nk7yyl7xh3kqb2op4lu3/images/neve-gym-demo-37.jpg"},"backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundSize":"cover","backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"align":"full","className":""} --><div id="wp-block-themeisle-blocks-advanced-columns-30e8a6e3" class="wp-block-themeisle-blocks-advanced-columns alignfull has-1-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-equal-layout has-vertical-unset"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-ea4f23f9","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginTablet":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"marginMobile":{"top":"20px","bottom":"20px","left":"0px","right":"0px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"100","className":""} --><div id="wp-block-themeisle-blocks-advanced-column-ea4f23f9" class="wp-block-themeisle-blocks-advanced-column"></div><!-- /wp:themeisle-blocks/advanced-column --></div></div><!-- /wp:themeisle-blocks/advanced-columns -->', // phpcs:ignore WordPressVIPMinimum.Security.Mustache.OutputNotation
);
