.wp-block-themeisle-blocks-sharing-icons{width:100%}.wp-block-themeisle-blocks-sharing-icons[class*=align]{float:unset}.wp-block-themeisle-blocks-sharing-icons.aligncenter .social-icons-wrap{justify-content:center}.wp-block-themeisle-blocks-sharing-icons.alignleft .social-icons-wrap{justify-content:flex-start}.wp-block-themeisle-blocks-sharing-icons.alignright .social-icons-wrap{justify-content:flex-end}.wp-block-themeisle-blocks-sharing-icons .social-icons-wrap{display:flex;column-gap:var(--icons-gap, 5px);flex-wrap:wrap}.wp-block-themeisle-blocks-sharing-icons .social-icon{font-size:14px;padding:12px;border-radius:var(--border-radius, 3px);white-space:nowrap;display:inline-block;text-align:center;touch-action:manipulation;line-height:20px;margin:10px 0;text-decoration:none;display:flex;align-items:center;background-color:var(--icon-bg-color, var(--default-icon-bg-color, #000));color:var(--text-color, #fff);fill:var(--text-color, #fff)}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-facebook{--default-icon-bg-color: #3b5998}.wp-block-themeisle-blocks-sharing-icons .social-icon:is(.is-twitter,.is-threads){--default-icon-bg-color: black}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-linkedin{--default-icon-bg-color: #0976b4}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-pinterest{--default-icon-bg-color: #cc2127}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-tumblr{--default-icon-bg-color: #35465c}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-reddit{--default-icon-bg-color: #ff4500}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-telegram{--default-icon-bg-color: #0088cc}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-whatsapp{--default-icon-bg-color: #25d366}.wp-block-themeisle-blocks-sharing-icons .social-icon.is-mastodon{--default-icon-bg-color: #2b90d9}.wp-block-themeisle-blocks-sharing-icons .social-icon:is(.is-email,.is-comments){--default-icon-bg-color: #dd4b39}.wp-block-themeisle-blocks-sharing-icons .social-icon:hover{box-shadow:0 14px 26px -12px rgba(59,89,152,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(59,89,152,.2)}.wp-block-themeisle-blocks-sharing-icons .social-icon svg{width:15px;height:15px}.wp-block-themeisle-blocks-sharing-icons:not(.is-style-icons) .v-line{width:1px;height:20px;background-color:var(--text-color, #fff);opacity:.5;display:inline-block;vertical-align:top;margin:0 10px}/*# sourceMappingURL=style.css.map */
