.sr-only {position: absolute;width: 1px;height: 1px;padding: 0;margin: -1px;overflow: hidden;clip: rect(0, 0, 0, 0);white-space: nowrap;border-width: 0
}.\!pointer-events-none {pointer-events: none !important
}.pointer-events-none {pointer-events: none
}.visible {visibility: visible
}.static {position: static
}.fixed {position: fixed
}.\!absolute {position: absolute !important
}.absolute {position: absolute
}.relative {position: relative
}.-bottom-1 {bottom: -0.25rem
}.bottom-0 {bottom: 0px
}.bottom-4 {bottom: 1rem
}.left-0 {left: 0px
}.right-1 {right: 0.25rem
}.right-2 {right: 0.5rem
}.right-3 {right: 0.75rem
}.top-1 {top: 0.25rem
}.top-2 {top: 0.5rem
}.top-3 {top: 0.75rem
}.z-10 {z-index: 10
}.z-50 {z-index: 50
}.col-start-1 {grid-column-start: 1
}.row-start-1 {grid-row-start: 1
}.\!m-0 {margin: 0px !important
}.m-0 {margin: 0px
}.m-12 {margin: 3rem
}.mx-0 {margin-left: 0px;margin-right: 0px
}.mx-1 {margin-left: 0.25rem;margin-right: 0.25rem
}.mx-1\.5 {margin-left: 0.375rem;margin-right: 0.375rem
}.mx-auto {margin-left: auto;margin-right: auto
}.my-0 {margin-top: 0px;margin-bottom: 0px
}.my-2 {margin-top: 0.5rem;margin-bottom: 0.5rem
}.my-3 {margin-top: 0.75rem;margin-bottom: 0.75rem
}.my-4 {margin-top: 1rem;margin-bottom: 1rem
}.my-5 {margin-top: 1.25rem;margin-bottom: 1.25rem
}.my-6 {margin-top: 1.5rem;margin-bottom: 1.5rem
}.my-8 {margin-top: 2rem;margin-bottom: 2rem
}.mb-0 {margin-bottom: 0px
}.mb-1 {margin-bottom: 0.25rem
}.mb-1\.5 {margin-bottom: 0.375rem
}.mb-10 {margin-bottom: 2.5rem
}.mb-2 {margin-bottom: 0.5rem
}.mb-20 {margin-bottom: 5rem
}.mb-4 {margin-bottom: 1rem
}.mb-5 {margin-bottom: 1.25rem
}.mb-6 {margin-bottom: 1.5rem
}.ml-2 {margin-left: 0.5rem
}.ml-3 {margin-left: 0.75rem
}.ml-4 {margin-left: 1rem
}.ml-auto {margin-left: auto
}.mr-1 {margin-right: 0.25rem
}.mr-1\.5 {margin-right: 0.375rem
}.mr-2 {margin-right: 0.5rem
}.mr-3 {margin-right: 0.75rem
}.mt-0 {margin-top: 0px
}.mt-0\.5 {margin-top: 0.125rem
}.mt-1 {margin-top: 0.25rem
}.mt-2 {margin-top: 0.5rem
}.mt-2\.5 {margin-top: 0.625rem
}.mt-3 {margin-top: 0.75rem
}.mt-4 {margin-top: 1rem
}.mt-5 {margin-top: 1.25rem
}.mt-8 {margin-top: 2rem
}.box-border {box-sizing: border-box
}.block {display: block
}.inline-block {display: inline-block
}.flex {display: flex
}.inline-flex {display: inline-flex
}.grid {display: grid
}.contents {display: contents
}.hidden {display: none
}.\!h-0 {height: 0px !important
}.h-12 {height: 3rem
}.h-16 {height: 4rem
}.h-2 {height: 0.5rem
}.h-2\.5 {height: 0.625rem
}.h-3 {height: 0.75rem
}.h-4 {height: 1rem
}.h-5 {height: 1.25rem
}.h-6 {height: 1.5rem
}.h-8 {height: 2rem
}.h-\[12px\] {height: 12px
}.h-\[24px\] {height: 24px
}.h-auto {height: auto
}.h-full {height: 100%
}.max-h-\[200px\] {max-height: 200px
}.min-h-40 {min-height: 40px
}.min-h-\[200px\] {min-height: 200px
}.\!w-0 {width: 0px !important
}.w-10 {width: 2.5rem
}.w-12 {width: 3rem
}.w-16 {width: 4rem
}.w-2 {width: 0.5rem
}.w-20 {width: 5rem
}.w-24 {width: 6rem
}.w-32 {width: 8rem
}.w-36 {width: 9rem
}.w-4 {width: 1rem
}.w-4\/6 {width: 66.666667%
}.w-40 {width: 10rem
}.w-5 {width: 1.25rem
}.w-6 {width: 1.5rem
}.w-8 {width: 2rem
}.w-\[12px\] {width: 12px
}.w-\[24px\] {width: 24px
}.w-auto {width: auto
}.w-full {width: 100%
}.max-w-\[150px\] {max-width: 150px
}.max-w-full {max-width: 100%
}.max-w-lg {max-width: 32rem
}.max-w-screen-xl {max-width: min( 1320px, 90%)
}.max-w-xl {max-width: 36rem
}.flex-shrink-0 {flex-shrink: 0
}.shrink-0 {flex-shrink: 0
}.grow {flex-grow: 1
}.basis-1\/2 {flex-basis: 50%
}.basis-1\/3 {flex-basis: 33.333333%
}.basis-1\/4 {flex-basis: 25%
}.basis-1\/5 {flex-basis: 20%
}.basis-4\/12 {flex-basis: 33.333333%
}.basis-4\/5 {flex-basis: 80%
}.basis-8\/12 {flex-basis: 66.666667%
}.basis-full {flex-basis: 100%
}.-scale-y-100 {--tw-scale-y: -1;transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))
}.transform {transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))
}@keyframes pulse {50% {opacity: .5
    }
}.animate-pulse {animation: pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite
}@keyframes spin {to {transform: rotate(360deg)
    }
}.animate-spin {animation: spin 1s linear infinite
}.cursor-default {cursor: default
}.cursor-pointer {cursor: pointer
}.resize {resize: both
}.list-disc {list-style-type: disc
}.appearance-none {appearance: none
}.grid-cols-1 {grid-template-columns: repeat(1, minmax(0, 1fr))
}.grid-cols-2 {grid-template-columns: repeat(2, minmax(0, 1fr))
}.flex-col {flex-direction: column
}.flex-wrap {flex-wrap: wrap
}.items-start {align-items: flex-start
}.items-end {align-items: flex-end
}.items-center {align-items: center
}.items-stretch {align-items: stretch
}.justify-start {justify-content: flex-start
}.justify-end {justify-content: flex-end
}.justify-center {justify-content: center
}.justify-between {justify-content: space-between
}.gap-0 {gap: 0px
}.gap-1 {gap: 0.25rem
}.gap-2 {gap: 0.5rem
}.gap-3 {gap: 0.75rem
}.gap-4 {gap: 1rem
}.gap-5 {gap: 1.25rem
}.gap-6 {gap: 1.5rem
}.gap-8 {gap: 2rem
}.space-x-2 > :not([hidden]) ~ :not([hidden]) {--tw-space-x-reverse: 0;margin-right: calc(0.5rem * var(--tw-space-x-reverse));margin-left: calc(0.5rem * calc(1 - var(--tw-space-x-reverse)))
}.space-y-2 > :not([hidden]) ~ :not([hidden]) {--tw-space-y-reverse: 0;margin-top: calc(0.5rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom: calc(0.5rem * var(--tw-space-y-reverse))
}.space-y-4 > :not([hidden]) ~ :not([hidden]) {--tw-space-y-reverse: 0;margin-top: calc(1rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom: calc(1rem * var(--tw-space-y-reverse))
}.self-center {align-self: center
}.justify-self-start {justify-self: start
}.\!overflow-hidden {overflow: hidden !important
}.overflow-hidden {overflow: hidden
}.overflow-y-scroll {overflow-y: scroll
}.\!rounded {border-radius: 0.25rem !important
}.rounded {border-radius: 0.25rem
}.rounded-full {border-radius: 9999px
}.rounded-lg {border-radius: 0.5rem
}.rounded-md {border-radius: 0.375rem
}.rounded-sm {border-radius: 0.125rem
}.\!border-0 {border-width: 0px !important
}.border {border-width: 1px
}.border-0 {border-width: 0px
}.border-2 {border-width: 2px
}.border-\[1px\] {border-width: 1px
}.border-b {border-bottom-width: 1px
}.border-b-4 {border-bottom-width: 4px
}.border-t {border-top-width: 1px
}.border-solid {border-style: solid
}.border-dashed {border-style: dashed
}.border-none {border-style: none
}.border-blue-300 {--tw-border-opacity: 1;border-color: rgb(147 197 253 / var(--tw-border-opacity))
}.border-blue-500 {--tw-border-opacity: 1;border-color: rgb(59 130 246 / var(--tw-border-opacity))
}.border-danger {--tw-border-opacity: 1;border-color: rgb(231 119 119 / var(--tw-border-opacity))
}.border-emerald-200 {--tw-border-opacity: 1;border-color: rgb(167 243 208 / var(--tw-border-opacity))
}.border-gray-200 {--tw-border-opacity: 1;border-color: rgb(229 231 235 / var(--tw-border-opacity))
}.border-gray-300 {--tw-border-opacity: 1;border-color: rgb(209 213 219 / var(--tw-border-opacity))
}.border-gray-400 {--tw-border-opacity: 1;border-color: rgb(156 163 175 / var(--tw-border-opacity))
}.border-grayish-blue {--tw-border-opacity: 1;border-color: rgb(246 246 250 / var(--tw-border-opacity))
}.border-info {--tw-border-opacity: 1;border-color: rgb(87 123 249 / var(--tw-border-opacity))
}.border-light-gray {border-color: rgba(87, 123, 249, 0.36)
}.border-red-200 {--tw-border-opacity: 1;border-color: rgb(254 202 202 / var(--tw-border-opacity))
}.border-slate-200 {--tw-border-opacity: 1;border-color: rgb(226 232 240 / var(--tw-border-opacity))
}.border-white {--tw-border-opacity: 1;border-color: rgb(255 255 255 / var(--tw-border-opacity))
}.\!border-b-info {--tw-border-opacity: 1 !important;border-bottom-color: rgb(87 123 249 / var(--tw-border-opacity)) !important
}.border-b-white {--tw-border-opacity: 1;border-bottom-color: rgb(255 255 255 / var(--tw-border-opacity))
}.border-t-grayish-blue {--tw-border-opacity: 1;border-top-color: rgb(246 246 250 / var(--tw-border-opacity))
}.\!bg-light-blue {--tw-bg-opacity: 1 !important;background-color: rgb(238 242 254 / var(--tw-bg-opacity)) !important
}.\!bg-opaque-black {background-color: #0000006E !important
}.bg-amber-500 {--tw-bg-opacity: 1;background-color: rgb(245 158 11 / var(--tw-bg-opacity))
}.bg-black {--tw-bg-opacity: 1;background-color: rgb(0 0 0 / var(--tw-bg-opacity))
}.bg-blue-100 {--tw-bg-opacity: 1;background-color: rgb(219 234 254 / var(--tw-bg-opacity))
}.bg-blue-50 {--tw-bg-opacity: 1;background-color: rgb(239 246 255 / var(--tw-bg-opacity))
}.bg-blue-500 {--tw-bg-opacity: 1;background-color: rgb(59 130 246 / var(--tw-bg-opacity))
}.bg-danger {--tw-bg-opacity: 1;background-color: rgb(231 119 119 / var(--tw-bg-opacity))
}.bg-danger\/20 {background-color: rgb(231 119 119 / 0.2)
}.bg-emerald-100 {--tw-bg-opacity: 1;background-color: rgb(209 250 229 / var(--tw-bg-opacity))
}.bg-gray-100 {--tw-bg-opacity: 1;background-color: rgb(243 244 246 / var(--tw-bg-opacity))
}.bg-gray-200 {--tw-bg-opacity: 1;background-color: rgb(229 231 235 / var(--tw-bg-opacity))
}.bg-gray-300 {--tw-bg-opacity: 1;background-color: rgb(209 213 219 / var(--tw-bg-opacity))
}.bg-gray-50 {--tw-bg-opacity: 1;background-color: rgb(249 250 251 / var(--tw-bg-opacity))
}.bg-gray-800 {--tw-bg-opacity: 1;background-color: rgb(31 41 55 / var(--tw-bg-opacity))
}.bg-green-50 {--tw-bg-opacity: 1;background-color: rgb(240 253 244 / var(--tw-bg-opacity))
}.bg-info {--tw-bg-opacity: 1;background-color: rgb(87 123 249 / var(--tw-bg-opacity))
}.bg-info\/20 {background-color: rgb(87 123 249 / 0.2)
}.bg-info\/30 {background-color: rgb(87 123 249 / 0.3)
}.bg-light-blue {--tw-bg-opacity: 1;background-color: rgb(238 242 254 / var(--tw-bg-opacity))
}.bg-mango-yellow {--tw-bg-opacity: 1;background-color: rgb(251 191 36 / var(--tw-bg-opacity))
}.bg-promo-orange {--tw-bg-opacity: 1;background-color: rgb(255 136 17 / var(--tw-bg-opacity))
}.bg-red-100 {--tw-bg-opacity: 1;background-color: rgb(254 226 226 / var(--tw-bg-opacity))
}.bg-red-50 {--tw-bg-opacity: 1;background-color: rgb(254 242 242 / var(--tw-bg-opacity))
}.bg-red-500 {--tw-bg-opacity: 1;background-color: rgb(239 68 68 / var(--tw-bg-opacity))
}.bg-stale-yellow {--tw-bg-opacity: 1;background-color: rgb(255 240 201 / var(--tw-bg-opacity))
}.bg-success {--tw-bg-opacity: 1;background-color: rgb(95 157 97 / var(--tw-bg-opacity))
}.bg-success\/20 {background-color: rgb(95 157 97 / 0.2)
}.bg-transparent {background-color: transparent
}.bg-warning {--tw-bg-opacity: 1;background-color: rgb(255 235 235 / var(--tw-bg-opacity))
}.bg-white {--tw-bg-opacity: 1;background-color: rgb(255 255 255 / var(--tw-bg-opacity))
}.bg-yellow-50 {--tw-bg-opacity: 1;background-color: rgb(254 252 232 / var(--tw-bg-opacity))
}.bg-promo {background-position: 90% 70%
}.bg-no-repeat {background-repeat: no-repeat
}.fill-blue-500 {fill: #3b82f6
}.fill-current {fill: currentColor
}.fill-danger {fill: #E77777
}.fill-green-500 {fill: #22c55e
}.fill-info {fill: #577BF9
}.fill-red-500 {fill: #ef4444
}.fill-success {fill: #5F9D61
}.fill-white {fill: #fff
}.fill-yellow-500 {fill: #eab308
}.p-0 {padding: 0px
}.p-1 {padding: 0.25rem
}.p-2 {padding: 0.5rem
}.p-3 {padding: 0.75rem
}.p-4 {padding: 1rem
}.p-5 {padding: 1.25rem
}.p-6 {padding: 1.5rem
}.p-8 {padding: 2rem
}.\!py-0 {padding-top: 0px !important;padding-bottom: 0px !important
}.\!py-0\.5 {padding-top: 0.125rem !important;padding-bottom: 0.125rem !important
}.px-0 {padding-left: 0px;padding-right: 0px
}.px-2 {padding-left: 0.5rem;padding-right: 0.5rem
}.px-2\.5 {padding-left: 0.625rem;padding-right: 0.625rem
}.px-3 {padding-left: 0.75rem;padding-right: 0.75rem
}.px-4 {padding-left: 1rem;padding-right: 1rem
}.px-5 {padding-left: 1.25rem;padding-right: 1.25rem
}.px-6 {padding-left: 1.5rem;padding-right: 1.5rem
}.px-7 {padding-left: 1.75rem;padding-right: 1.75rem
}.px-8 {padding-left: 2rem;padding-right: 2rem
}.py-1 {padding-top: 0.25rem;padding-bottom: 0.25rem
}.py-1\.5 {padding-top: 0.375rem;padding-bottom: 0.375rem
}.py-12 {padding-top: 3rem;padding-bottom: 3rem
}.py-2 {padding-top: 0.5rem;padding-bottom: 0.5rem
}.py-24 {padding-top: 6rem;padding-bottom: 6rem
}.py-3 {padding-top: 0.75rem;padding-bottom: 0.75rem
}.py-4 {padding-top: 1rem;padding-bottom: 1rem
}.py-5 {padding-top: 1.25rem;padding-bottom: 1.25rem
}.\!pl-9 {padding-left: 2.25rem !important
}.pb-0 {padding-bottom: 0px
}.pb-1 {padding-bottom: 0.25rem
}.pb-5 {padding-bottom: 1.25rem
}.pb-6 {padding-bottom: 1.5rem
}.pb-8 {padding-bottom: 2rem
}.pl-2 {padding-left: 0.5rem
}.pl-4 {padding-left: 1rem
}.pr-3 {padding-right: 0.75rem
}.pr-7 {padding-right: 1.75rem
}.pt-2 {padding-top: 0.5rem
}.pt-4 {padding-top: 1rem
}.pt-5 {padding-top: 1.25rem
}.pt-8 {padding-top: 2rem
}.text-left {text-align: left
}.text-center {text-align: center
}.font-serif {font-family: -apple-system, BlinkMacSystemFont, sans-serif
}.text-2 {font-size: 2rem
}.text-2xl {font-size: 1.5rem;line-height: 2rem
}.text-4xl {font-size: 2.25rem;line-height: 2.5rem
}.text-\[11px\] {font-size: 11px
}.text-\[17px\] {font-size: 17px
}.text-base {font-size: 1rem;line-height: 1.5rem
}.text-lg {font-size: 1.125rem;line-height: 1.75rem
}.text-s {font-size: 13px
}.text-sm {font-size: 0.875rem;line-height: 1.25rem
}.text-xl {font-size: 1.25rem;line-height: 1.75rem
}.text-xs {font-size: 0.75rem;line-height: 1rem
}.font-bold {font-weight: 700
}.font-extrabold {font-weight: 800
}.font-medium {font-weight: 500
}.font-normal {font-weight: 400
}.font-semibold {font-weight: 600
}.uppercase {text-transform: uppercase
}.italic {font-style: italic
}.not-italic {font-style: normal
}.leading-7 {line-height: 1.75rem
}.leading-normal {line-height: 1.5
}.\!text-gray-500 {--tw-text-opacity: 1 !important;color: rgb(107 114 128 / var(--tw-text-opacity)) !important
}.\!text-info {--tw-text-opacity: 1 !important;color: rgb(87 123 249 / var(--tw-text-opacity)) !important
}.\!text-white {--tw-text-opacity: 1 !important;color: rgb(255 255 255 / var(--tw-text-opacity)) !important
}.text-black {--tw-text-opacity: 1;color: rgb(0 0 0 / var(--tw-text-opacity))
}.text-blue-500 {--tw-text-opacity: 1;color: rgb(59 130 246 / var(--tw-text-opacity))
}.text-blue-700 {--tw-text-opacity: 1;color: rgb(29 78 216 / var(--tw-text-opacity))
}.text-blue-800 {--tw-text-opacity: 1;color: rgb(30 64 175 / var(--tw-text-opacity))
}.text-current {color: currentColor
}.text-danger {--tw-text-opacity: 1;color: rgb(231 119 119 / var(--tw-text-opacity))
}.text-emerald-700 {--tw-text-opacity: 1;color: rgb(4 120 87 / var(--tw-text-opacity))
}.text-gray-500 {--tw-text-opacity: 1;color: rgb(107 114 128 / var(--tw-text-opacity))
}.text-gray-600 {--tw-text-opacity: 1;color: rgb(75 85 99 / var(--tw-text-opacity))
}.text-gray-700 {--tw-text-opacity: 1;color: rgb(55 65 81 / var(--tw-text-opacity))
}.text-gray-800 {--tw-text-opacity: 1;color: rgb(31 41 55 / var(--tw-text-opacity))
}.text-gray-950 {--tw-text-opacity: 1;color: rgb(3 7 18 / var(--tw-text-opacity))
}.text-green-700 {--tw-text-opacity: 1;color: rgb(21 128 61 / var(--tw-text-opacity))
}.text-green-800 {--tw-text-opacity: 1;color: rgb(22 101 52 / var(--tw-text-opacity))
}.text-info {--tw-text-opacity: 1;color: rgb(87 123 249 / var(--tw-text-opacity))
}.text-inherit {color: inherit
}.text-light-black {--tw-text-opacity: 1;color: rgb(98 98 98 / var(--tw-text-opacity))
}.text-promo-orange {--tw-text-opacity: 1;color: rgb(255 136 17 / var(--tw-text-opacity))
}.text-purple-gray {--tw-text-opacity: 1;color: rgb(117 114 150 / var(--tw-text-opacity))
}.text-red-500 {--tw-text-opacity: 1;color: rgb(239 68 68 / var(--tw-text-opacity))
}.text-red-700 {--tw-text-opacity: 1;color: rgb(185 28 28 / var(--tw-text-opacity))
}.text-red-800 {--tw-text-opacity: 1;color: rgb(153 27 27 / var(--tw-text-opacity))
}.text-success {--tw-text-opacity: 1;color: rgb(95 157 97 / var(--tw-text-opacity))
}.text-white {--tw-text-opacity: 1;color: rgb(255 255 255 / var(--tw-text-opacity))
}.text-yellow-700 {--tw-text-opacity: 1;color: rgb(161 98 7 / var(--tw-text-opacity))
}.text-yellow-800 {--tw-text-opacity: 1;color: rgb(133 77 14 / var(--tw-text-opacity))
}.underline {text-decoration-line: underline
}.\!no-underline {text-decoration-line: none !important
}.no-underline {text-decoration-line: none
}.antialiased {-webkit-font-smoothing: antialiased;-moz-osx-font-smoothing: grayscale
}.\!opacity-0 {opacity: 0 !important
}.opacity-0 {opacity: 0
}.opacity-100 {opacity: 1
}.opacity-50 {opacity: 0.5
}.shadow-lg {--tw-shadow: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.shadow-md {--tw-shadow: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.shadow-none {--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.shadow-sm {--tw-shadow: 0 1px 2px 0 rgb(0 0 0 / 0.05);--tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.outline-none {outline: 2px solid transparent;outline-offset: 2px
}.outline {outline-style: solid
}.outline-3 {outline-width: 3px
}.-outline-offset-3 {outline-offset: -3px
}.outline-info {outline-color: #577BF9
}.outline-transparent {outline-color: transparent
}.blur {--tw-blur: blur(8px);filter: var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)
}.filter {filter: var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)
}.transition {transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.transition-all {transition-property: all;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.transition-colors {transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.transition-opacity {transition-property: opacity;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.duration-200 {transition-duration: 200ms
}.duration-300 {transition-duration: 300ms
}.duration-700 {transition-duration: 700ms
}.ease-in-out {transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1)
}#optml-dashboard-widget .inside {margin: 0px;padding: 0px
}.hover\:border-info:hover {--tw-border-opacity: 1;border-color: rgb(87 123 249 / var(--tw-border-opacity))
}.hover\:border-red-500:hover {--tw-border-opacity: 1;border-color: rgb(239 68 68 / var(--tw-border-opacity))
}.hover\:bg-info:hover {--tw-bg-opacity: 1;background-color: rgb(87 123 249 / var(--tw-bg-opacity))
}.hover\:bg-light-blue:hover {--tw-bg-opacity: 1;background-color: rgb(238 242 254 / var(--tw-bg-opacity))
}.hover\:bg-red-500:hover {--tw-bg-opacity: 1;background-color: rgb(239 68 68 / var(--tw-bg-opacity))
}.hover\:bg-white:hover {--tw-bg-opacity: 1;background-color: rgb(255 255 255 / var(--tw-bg-opacity))
}.hover\:text-dark-blue:hover {--tw-text-opacity: 1;color: rgb(53 87 166 / var(--tw-text-opacity))
}.hover\:text-info:hover {--tw-text-opacity: 1;color: rgb(87 123 249 / var(--tw-text-opacity))
}.hover\:text-orange-400:hover {--tw-text-opacity: 1;color: rgb(251 146 60 / var(--tw-text-opacity))
}.hover\:text-promo-orange:hover {--tw-text-opacity: 1;color: rgb(255 136 17 / var(--tw-text-opacity))
}.hover\:text-purple-gray:hover {--tw-text-opacity: 1;color: rgb(117 114 150 / var(--tw-text-opacity))
}.hover\:text-success:hover {--tw-text-opacity: 1;color: rgb(95 157 97 / var(--tw-text-opacity))
}.hover\:text-white:hover {--tw-text-opacity: 1;color: rgb(255 255 255 / var(--tw-text-opacity))
}.hover\:opacity-75:hover {opacity: 0.75
}.hover\:opacity-90:hover {opacity: 0.9
}.focus\:text-success:focus {--tw-text-opacity: 1;color: rgb(95 157 97 / var(--tw-text-opacity))
}.active\:text-success:active {--tw-text-opacity: 1;color: rgb(95 157 97 / var(--tw-text-opacity))
}.group:hover .group-hover\:text-dark-blue {--tw-text-opacity: 1;color: rgb(53 87 166 / var(--tw-text-opacity))
}@media (min-width: 640px) {.sm\:left-auto {left: auto
    }.sm\:right-0 {right: 0px
    }.sm\:w-full {width: 100%
    }.sm\:basis-1\/4 {flex-basis: 25%
    }.sm\:basis-2\/5 {flex-basis: 40%
    }.sm\:basis-auto {flex-basis: auto
    }.sm\:flex-row {flex-direction: row
    }.sm\:items-end {align-items: flex-end
    }.sm\:items-center {align-items: center
    }.sm\:justify-normal {justify-content: normal
    }.sm\:gap-3 {gap: 0.75rem
    }.sm\:px-0 {padding-left: 0px;padding-right: 0px
    }
}@media (min-width: 768px) {.md\:w-20 {width: 5rem
    }.md\:grow-0 {flex-grow: 0
    }.md\:basis-1\/3 {flex-basis: 33.333333%
    }.md\:grid-cols-2 {grid-template-columns: repeat(2, minmax(0, 1fr))
    }.md\:flex-row {flex-direction: row
    }.md\:flex-nowrap {flex-wrap: nowrap
    }.md\:gap-0 {gap: 0px
    }.md\:text-left {text-align: left
    }
}@media (min-width: 1024px) {.lg\:block {display: block
    }.lg\:text-5xl {font-size: 3rem;line-height: 1
    }.lg\:text-base {font-size: 1rem;line-height: 1.5rem
    }
}@media (min-width: 1280px) {.xl\:mb-5 {margin-bottom: 1.25rem
    }.xl\:mt-8 {margin-top: 2rem
    }.xl\:flex {display: flex
    }.xl\:w-\[350px\] {width: 350px
    }.xl\:flex-row {flex-direction: row
    }.xl\:flex-col {flex-direction: column
    }.xl\:items-start {align-items: flex-start
    }.xl\:items-center {align-items: center
    }
}@media (min-width: 1536px) {.\32xl\:max-w-screen-xl {max-width: min( 1320px, 90%)
    }
}
