/*--------------------------------------------------------------
## Elementor Styles Basic
--------------------------------------------------------------*/
.elementor-widget .elementor-slick-slider .slick-slider .slick-next, .elementor-widget .elementor-slick-slider .slick-slider .slick-prev {
  box-shadow: none;
}
.elementor-widget .elementor-slick-slider .slick-slider .slick-next:before, .elementor-widget .elementor-slick-slider .slick-slider .slick-prev:before {
  color: rgba(0, 0, 0, 0.5);
}
.elementor-widget .elementor-slick-slider .slick-dots button {
  box-shadow: none;
}
.elementor-widget .elementor-slick-slider .slick-dots button:before {
  color: rgba(0, 0, 0, 0.5);
}
.elementor-widget .elementor-button {
  box-shadow: none;
  background-color: #e91e63;
}
.elementor-widget .elementor-icon {
  color: #e91e63;
}
.elementor-widget .elementor-icon:hover {
  color: rgba(233, 30, 99, 0.65);
}
.elementor-widget.elementor-view-stacked .elementor-icon {
  color: #fff;
  background-color: #e91e63;
}
.elementor-widget.elementor-view-stacked .elementor-icon:hover {
  background-color: rgba(233, 30, 99, 0.65);
  color: #fff;
}
.elementor-widget.elementor-view-framed .elementor-icon {
  color: #e91e63;
  border-color: #e91e63;
}
.elementor-widget.elementor-view-framed .elementor-icon:hover {
  border-color: rgba(233, 30, 99, 0.65);
  color: rgba(233, 30, 99, 0.65);
}
.elementor-widget .elementor-divider-separator {
  border-color: #3C4858;
}
.elementor-widget .elementor-icon-box-title, .elementor-widget .elementor-image-box-title {
  font-weight: 700;
  font-size: 1.2em;
  font-family: "Roboto Slab", "Times New Roman", serif;
  color: #3C4858;
}
.elementor-widget .elementor-icon-box-description, .elementor-widget .elementor-image-box-description {
  color: #a5a5a5;
  font-size: 16px;
}
.elementor-widget .elementor-counter .elementor-counter-number-wrapper {
  font-family: "Roboto", "Helvetica", "Arial", sans-serif;
  font-weight: 700;
}
.elementor-widget .elementor-counter .elementor-counter-title,
.elementor-widget .elementor-testimonial-wrapper .elementor-testimonial-name {
  font-family: "Roboto Slab", "Times New Roman", serif;
  font-weight: 700;
  color: #3C4858;
}
.elementor-widget .elementor-testimonial-wrapper .elementor-testimonial-content {
  font-size: 17px;
}
.elementor-widget .elementor-tab-title,
.elementor-widget .elementor-accordion-title,
.elementor-widget .elementor-toggle-title {
  font-family: "Roboto Slab", "Times New Roman", serif;
}
.elementor-widget .elementor-tab-title.active,
.elementor-widget .elementor-accordion-title.active,
.elementor-widget .elementor-toggle-title.active {
  color: #e91e63;
}

.elementor-widget-progress .elementor-progress-bar {
  background-color: #e91e63;
}
.elementor-widget-progress .elementor-title {
  font-family: "Roboto Slab", "Times New Roman", serif;
  font-weight: 700;
  line-height: 2.5em;
}