a {background-position: 0 0 0 0;}
b {background-position: 0 0 0}
c {BACKGROUND-POSITION: 0 0;}
d {
    background-position: 0% 50%;
    background-position: 0% 0em;
    background-position: 0px 0rem;
    background-position: center top 0px;
    background-position: left 0em bottom 0px;
}