/*
  Although it's tempting to compress the value "none" to "0" for border property, it's not 100% safe to do so.
  @See:
    - http://stackoverflow.com/a/2948616/1273027
    - http://stackoverflow.com/a/24834322/1273027

*/

a {
    border: none;
    border-top: none;
    border-right: none;
    border-bottom:none;
    border-left: none
}