.om-dam-modal .om-dam-wrap{background:#f6f6fa;height:100%}.om-dam-modal .media-toolbar-secondary{display:none}.om-dam-modal [aria-labelledby=menu-item-optimole]{overflow:hidden}.om-dam-modal #om-dam,.om-dam-modal .om-dam-loader{width:100%;height:100%;border:none;position:relative}.om-dam-modal .media-frame-content{bottom:0}.om-dam-modal .media-frame-toolbar,.om-dam-modal .media-toolbar-secondary{bottom:100px;display:none}.om-dam-modal .om-dam-loader{display:flex;flex-direction:column;align-items:center;justify-content:center;width:100%}.om-dam-modal .om-dam-loader p{margin-top:20px;font-size:1.2rem;font-weight:500;color:#333}.om-dam-modal .om-dam-loader img{max-width:150px;animation:animate-opacity 1.5s infinite}@keyframes animate-opacity{0%{opacity:.75}50%{opacity:1}100%{opacity:.75}}
