.components-tools-panel-item .components-base-control:not(.components-input-control){margin:24px 0}.otter-masonry .blocks-gallery-grid .blocks-gallery-item img{width:100%}[id^=inspector-box-control]{max-width:none!important}svg.o-block-icon{fill:url(#o-icon-fill)!important}.block-editor-list-view-leaf.is-selected svg.o-block-icon{fill:#fff!important}.o-is-new.components-panel__body .components-panel__body-title .components-button{display:flex;flex-direction:row-reverse;justify-content:flex-end}.o-is-new.components-panel__body .components-panel__body-title span:after{background:#1e7db3;border-radius:2px;color:#fff;content:"New";font-size:8px;margin-right:5px;padding:4px 6px;position:relative;text-transform:uppercase;top:-1px}.o-fp-wrap{align-items:center;display:flex;justify-content:space-between}.o-fp-wrap #o-feedback{font-size:10px;margin-top:10px;padding:0}.o-is-powered{align-items:center;display:flex;font-size:10px;justify-content:flex-end;margin-right:auto;margin-top:10px;text-align:left;text-transform:uppercase}.o-is-powered svg{height:14px;margin-right:10px;width:14px}.o-disabled{opacity:.5}.media-modal{z-index:9999999}.o-position-picker .component-alignment-matrix-control{grid-template-rows:repeat(3,35.6667px);width:245px}.o-position-picker .component-alignment-matrix-control span[role=presentation]{height:23px;width:60px}#o-border-raduis-box{max-width:100%}#o-border-raduis-box>.component-box-control__header-control-wrapper>.components-flex-item:first-child{transform:rotate(-315deg);width:24px}.o-autoresponder-margin{margin-top:10px}.o-webhook-headers{display:flex;flex-direction:column;gap:8px}.o-webhook-headers .o-webhook-header{align-items:center;display:grid;gap:10px;grid-template-columns:1fr 1fr 35px}.o-webhook-headers .o-webhook-header .components-base-control__field{margin:0}.o-webhook-headers button{display:flex;justify-content:center}.o-webhook-actions{display:flex;flex-direction:row;justify-content:space-between}.o-webhook-actions .o-webhook-actions__left{display:flex;flex-direction:row;gap:10px}.o-webhooks{display:flex;flex-direction:column}.o-webhooks>.o-options-global-defaults{max-height:500px;overflow-y:auto}.o-webhooks>.o-options-global-defaults .o-options-block-item .o-options-block-item-label{flex-grow:1;margin-right:10px}.o-webhooks .o-webhook-add{display:flex;justify-content:center;margin-top:10px}.o-license-warning.components-placeholder.is-medium legend.components-placeholder__instructions{display:block}.w-full{width:100%}
.o-notice{align-items:center;background:#f3f3f3;border-radius:4px;display:flex;justify-content:space-between;margin:10px 0;padding:10px 20px}.o-notice.is-upsell{background:transparent;border:1px solid gray;font-size:12px}.o-notice.is-upsell .components-external-link{color:gray}.o-notice.is-help{color:#50575e;font-size:12px;padding:10px}.o-notice .components-external-link{display:flex;flex-direction:row-reverse;text-decoration:unset}.o-notice .components-external-link .components-external-link__icon{margin:0 0 0 5px}.o-notice svg{height:18px;width:18px}
.block-editor-block-inspector .o-background-selector-control{margin:0}.block-editor-block-inspector .o-background-selector-control .o-background-image-manage .components-dropdown{width:100%}.block-editor-block-inspector .o-background-selector-control .o-background-image-manage .components-dropdown .components-toolbar__control{box-shadow:inset 0 0 0 1px var(--wp-admin-theme-color);color:var(--wp-admin-theme-color);justify-content:center;outline:1px solid transparent;width:100%}
.o-control-panel-control{padding:10px 0}.o-control-panel-control .components-base-control__title{align-items:center;display:flex;justify-content:space-between}.o-control-panel-control .components-base-control__title label{padding:5px 0}.o-control-panel-control .components-base-control__title .floating-controls .components-dropdown{display:flex}.o-control-panel-control .components-base-control__title .floating-controls .components-dropdown button.is-tertiary{border:none;box-shadow:none;color:#1e1e1e}.o-control-panel-control .components-base-control__title .floating-controls .components-dropdown button.is-active,.o-control-panel-control .components-base-control__title .floating-controls .components-dropdown button.is-tertiary:hover{color:var(--wp-admin-theme-color)}.o-control-panel-control .components-base-control__title .floating-controls .components-dropdown button .dashicon{margin:2px}.otter-popover-settings{min-width:300px;overflow:hidden;padding:10px}.otter-popover-settings .components-button-group:not(.o-toggle-group-control){padding-bottom:10px}
.o-toggle-group-control{background:#fff none repeat scroll 100% 0;border:1px solid #757575;border-radius:2px;display:flex;min-height:36px;min-width:0;padding:2px}.o-toggle-group-control.has-icon{margin-right:0;margin-left:0}.o-toggle-group-control .o-toggle-option{align-items:center;display:flex;flex:1;flex-direction:column}.o-toggle-group-control .o-toggle-option .components-button{box-shadow:none;flex:1;height:30px;justify-content:center;width:100%}.o-toggle-group-control .o-toggle-option .components-button:hover{box-shadow:none}.o-toggle-group-control .o-toggle-option .components-button .dashicon{color:#2f2f2f}.o-toggle-group-control .o-toggle-option .components-button svg{fill:#2f2f2f}.o-toggle-group-control .o-toggle-option .components-button.is-primary{background-color:#000;border-radius:0;box-shadow:none;color:#fff}.o-toggle-group-control .o-toggle-option .components-button.is-primary .dashicon{color:#fff}.o-toggle-group-control .o-toggle-option .components-button.is-primary svg{fill:#fff}.o-toggle-group-control .o-toggle-option .components-button.is-secondary{border-radius:0;box-shadow:none;color:#000}
.o-button-dropdown-control{border:1px solid rgba(0,0,0,.1);display:block;padding:0}.o-button-dropdown-control .o-button-dropdown-control-button{-webkit-appearance:none;appearance:none;background:none;border:1px solid transparent;color:inherit;cursor:pointer;display:flex;height:46px;margin:0;padding:9.2px 12px;text-align:right;width:100%}.o-button-dropdown-control .o-button-dropdown-control-button.is-open{background:#f0f0f0;color:var(--wp-admin-theme-color)}.o-button-dropdown-control .o-button-dropdown-control-button .component-color-indicator{background:linear-gradient(45deg,transparent 48%,#ddd 0,#ddd 52%,transparent 0);background-size:cover!important;margin-left:8px}.o-button-dropdown-control-content .components-popover__content{width:280px}@media(min-width:782px){.o-button-dropdown-control-content .components-popover__content{margin-top:-60px!important}}.o-button-dropdown-control-content .components-popover__content .block-editor-color-gradient-control__color-indicator{display:none}.o-button-dropdown-control-content .components-popover__content .block-editor-block-inspector{padding:10px}@media(min-width:782px){body:is([class*=branch-5-],[class*=version-6-0]) .o-button-dropdown-control-content .components-popover__content{margin-left:156px!important}}
.o-button-toggle{display:flex;flex-wrap:wrap;gap:8px;justify-content:space-between}.o-button-toggle .o-button-toggle__item{box-shadow:inset 0 0 0 1px #ccc;color:#2f2f2f;justify-content:center;width:calc(50% - 4px)}.o-button-toggle .o-button-toggle__item.is-active{background-color:#2f2f2f;box-shadow:none;color:#fff}.o-button-toggle .o-button-toggle__item.is-active:hover{color:#fff}
.o-clear-button{display:flex;justify-content:flex-end;margin:5px 0;width:100%}
.o-color-dropdown-control{border:1px solid rgba(0,0,0,.1);display:block;padding:0}.o-color-dropdown-control.is-list{border-top-width:0}.o-color-dropdown-control.is-list.is-first{border-top-width:1px}.o-color-dropdown-control:not(.is-list){margin:20px 0}.o-color-dropdown-control .o-color-dropdown-control-button{-webkit-appearance:none;appearance:none;background:none;border:1px solid transparent;color:inherit;cursor:pointer;display:flex;height:46px;margin:0;padding:9.2px 12px;text-align:right;width:100%}.o-color-dropdown-control .o-color-dropdown-control-button.is-open{background:#f0f0f0;color:var(--wp-admin-theme-color)}.o-color-dropdown-control .o-color-dropdown-control-button .component-color-indicator{background:linear-gradient(45deg,transparent 48%,#ddd 0,#ddd 52%,transparent 0);margin-left:8px}.o-color-dropdown-control-content .components-popover__content{width:280px}@media(min-width:782px){.o-color-dropdown-control-content .components-popover__content{margin-top:-60px!important}}.o-color-dropdown-control-content .components-popover__content .block-editor-color-gradient-control__color-indicator{display:none}@media(min-width:782px){body:is([class*=branch-5-],[class*=version-6-0]) .o-color-dropdown-control-content .components-popover__content{margin-left:156px!important}}
.o-gfont-popover:not(.is-mobile).is-bottom{z-index:9999999}.o-gfont-popover .components-popover__content{overflow-y:hidden}.o-gfont-popover .components-popover__content .components-menu-group{padding:7px}.o-gfont-popover .components-popover__content .components-popover__items{max-height:300px;overflow-y:auto}.o-gfont-popover .components-popover__content .components-popover__items button.is-selected{background:#f8f9f9}.o-gfont-popover .components-popover__content .components-popover__items button i{margin-left:5px}.o-gfont-control .components-dropdown{display:flex}.o-gfont-control .o-gfont-button{background:transparent;border:1px solid #8d96a0;border-radius:4px;box-shadow:0 0 0 transparent;height:auto;line-height:28px;padding:0 12px 2px;position:relative;transition:box-shadow .1s linear;width:100%}.o-gfont-control .o-gfont-button.is-button{background:transparent}.o-gfont-control .o-gfont-button:hover{background:#fafafa;border-color:#999;box-shadow:inset 0 -1px 0 #999;color:#23282d;text-decoration:none}.o-gfont-control .o-gfont-button:focus{border:1px solid #000}.o-gfont-control .o-gfont-button:after{border-right:3px solid transparent;border-left:3px solid transparent;border-top:5px solid;content:"";display:block;height:0;margin-right:4px;margin-left:2px;pointer-events:none;position:absolute;left:8px;top:12px;width:0}.o-gfont-control .o-control-panel-control{padding:0}@media(max-width:782px){.o-gfont-control .o-gfont-button{padding:5px 8px 5px 24px}.o-gfont-control .o-gfont-button:after{top:16px}}
.o-html-anchor-control{display:grid;grid-template-columns:80% 20%;padding:6px 0}.o-html-anchor-control input[type=text]{border-bottom-left-radius:0;border-left:none;border-top-left-radius:0;margin:0}.o-html-anchor-control input[type=text]:focus{border-color:inherit;box-shadow:none}.o-html-anchor-control button.o-html-anchor-control-button{border:1px solid #8d96a0;border-bottom-right-radius:0;border-top-right-radius:0;display:flex;height:30px;justify-content:center;padding:0;width:100%}.o-html-anchor-control button.o-html-anchor-control-button.is-saved{background:#a4afb7;border:1px solid #8d96a0;border-bottom-right-radius:0;border-top-right-radius:0;color:#fff;justify-content:center}.o-html-anchor-control button.o-html-anchor-control-button.is-saved:hover:not(:disabled):not([aria-disabled=true]):not(.is-secondary):not(.is-primary):not(.is-tertiary):not(.is-link){background:#a4afb7;box-shadow:inset 0 0 0 1px #e2e4e7,inset 0 0 0 2px #a4afb7,0 1px 1px rgba(25,30,35,.2);color:#fff}.o-html-anchor-control-notice{margin:0 0 20px}@media(max-width:782px){.o-html-anchor-control-button{min-height:40px}}
.o-icon-picker-popover:not(.is-mobile).is-bottom{z-index:9999999}.o-icon-picker-popover .components-popover__content{overflow-y:hidden}.o-icon-picker-popover .components-popover__content .components-menu-group{padding:7px}.o-icon-picker-popover .components-popover__content .components-popover__items{max-height:300px;overflow-y:auto}.o-icon-picker-popover .components-popover__content .components-popover__items button.is-selected{background:#f8f9f9}.o-icon-picker-popover .components-popover__content .components-popover__items button svg{margin-left:5px;max-width:15px;width:15px}.o-icon-picker-popover .components-popover__content .components-popover__items button i{margin-left:5px}.o-icon-picker-popover .remove-icon{color:#cc1818}.block-editor-block-inspector .o-icon-picker-control{margin:8px 0}.block-editor-block-inspector .o-icon-picker-control .components-dropdown{display:flex;flex-direction:column}.block-editor-block-inspector .o-icon-picker-control .components-dropdown .components-base-control{margin:8px 0}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button{background:transparent;border:1px solid #8d96a0;border-radius:4px;box-shadow:0 0 0 transparent;height:auto;line-height:28px;padding:0 12px 2px;position:relative;transition:box-shadow .1s linear;width:100%}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button.is-button{background:transparent}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button:hover{background:#fafafa;border-color:#999;box-shadow:inset 0 -1px 0 #999;color:#23282d;text-decoration:none}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button:focus{border:1px solid #000}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button:after{border-right:3px solid transparent;border-left:3px solid transparent;border-top:5px solid;content:"";display:block;height:0;margin-right:4px;margin-left:2px;pointer-events:none;position:absolute;left:8px;top:12px;width:0}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button i{font-size:15px;line-height:1.8;margin-left:5px}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-button svg{line-height:1.8;margin-left:5px;max-width:15px;width:15px}.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-image-control .components-base-control__field,.block-editor-block-inspector .o-icon-picker-control .o-icon-picker-image-control>div{display:flex;flex-direction:column}.o-icon-picker-toolbar-button{display:flex;justify-content:center}@media(max-width:782px){.o-icon-picker-control .o-icon-picker-button{padding:5px 8px 5px 24px}.o-icon-picker-control .o-icon-picker-button:after{top:16px}}
.o-images-grid-component{display:grid;grid-template-columns:auto auto auto;grid-column-gap:10px;grid-row-gap:10px}.o-images-grid-component.is-single{justify-content:start}.o-images-grid-component.is-single .o-images-grid-component__image{margin-left:5px}.o-images-grid-component .is-sorting{opacity:.25}.o-images-grid-component .components-button.is-primary{align-content:center;background:#d5dadf;border:none;border-radius:0;color:#fff;cursor:pointer;display:flex;height:75px;justify-content:center;width:75px}.o-images-grid-component .components-button.is-primary svg{color:#fff;height:36px;width:36px}.o-images-grid-component__image{background-position:50%;background-size:cover;box-shadow:0 0 0 1px rgba(0,0,0,.2);cursor:move;height:75px;overflow:visible;width:75px}.o-images-grid-component__image.is-selected{box-shadow:0 0 0 1px #fff,0 0 0 3px #007cba}.o-images-grid-component__image.is-selected:focus,.o-images-grid-component__image.is-selected:hover{box-shadow:0 0 0 1px #fff,0 0 0 3px #007cba!important}.o-images-grid-component__image:focus{background-blend-mode:luminosity}.o-images-grid-component__image .o-images-grid-component__image__count{align-items:center;background:#007cba;border:1px solid #fff;border-radius:100%;color:#fff;display:flex;height:25px;justify-content:center;right:50px;position:relative;top:-40px;width:25px}@media(min-width:540px)and (max-width:782px){.o-images-grid-component{grid-template-columns:auto auto auto auto auto auto}}
.block-editor-block-inspector .o-inspector-header{border-top:none;display:flex;padding:0}.block-editor-block-inspector .o-inspector-header .components-button{background:transparent;border:none;border-radius:0;box-shadow:none;cursor:pointer;flex:1 1 0px;font-weight:500;height:48px;justify-content:center;margin-right:0;padding:3px 15px}.block-editor-block-inspector .o-inspector-header .components-button:focus{box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);position:relative;z-index:1}.block-editor-block-inspector .o-inspector-header .components-button.is-active{box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) transparent,inset 0 -4px 0 0 var(--wp-admin-theme-color);position:relative;z-index:1}
.o-toolbar-icon svg{height:24px}
.o-panel-tab{z-index:999999}.o-panel-tab .o-panel-tab__header{background:#fff;border:1px solid #d5dadf;display:flex}.o-panel-tab .o-panel-tab__header .o-panel-tab__header__label{align-items:center;cursor:default;display:flex;flex-basis:60%;padding-right:15px}.o-panel-tab .o-panel-tab__header .o-panel-tab__header__label::selection{background:none}.o-panel-tab .o-panel-tab__header .components-button{border-right:1px solid #d5dadf;border-radius:0;flex-basis:20%;height:auto;justify-content:center;padding:10px 5px}.o-panel-tab .o-panel-tab__header .components-button .dashicon{margin:2px}.o-panel-tab .o-panel-tab__header:hover{background:#fafafb}.o-panel-tab .o-panel-tab__content{background:#fff;border:1px solid #d5dadf;border-top:none;padding:10px 15px}.o-panel-tab .o-panel-tab__content .components-select-control label{overflow:visible;white-space:normal}.o-panel-tab .o-panel-tab__content .components-base-control{margin:12px 0}.o-panel-tab .o-panel-tab__content .components-base-control .components-dropdown{width:100%}.o-panel-tab .o-panel-tab__content .components-base-control .components-dropdown .components-button{display:flex;justify-content:center;width:100%}.o-panel-tab .o-panel-tab__content .components-base-control .components-datetime__time-field-hours-input{min-width:60px}.o-panel-tab .o-panel-tab__content .components-base-control .components-datetime__timezone{display:inline-block}
.o-responsive-control{margin:10px 0}.o-responsive-control .components-base-control__title{align-items:center;display:flex;justify-content:space-between;margin-bottom:.5em}.o-responsive-control .o-responsive-buttons .components-button-group{display:flex;gap:10px}.o-responsive-control .o-responsive-buttons .components-button{border:0;box-shadow:none;color:#b8b8b8;min-width:unset;padding:0}.o-responsive-control .o-responsive-buttons .components-button.is-selected{color:#333}body.branch-6-1 .o-responsive-control .components-base-control__title{font-size:11px;font-weight:500;text-transform:uppercase}
.o-sizing-control .components-base-control__label{margin-bottom:4px}.o-sizing-control .o-sizing-control-wrapper{display:grid;grid-template-columns:25% 25% 25% 25%;padding:6px 0}.o-sizing-control .o-sizing-control-wrapper.linking{grid-template-columns:20% 20% 20% 20% 20%}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item .o-sizing-control-item-input{border-radius:0;min-height:30px;padding:0 5px;text-align:center;width:100%}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item .o-sizing-control-item-input[disabled]{background-color:#e6e9ec;cursor:not-allowed}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item .o-sizing-control-item-input .dashicon{margin:2px}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item .o-sizing-control-item-label{display:block;font-size:9px;padding-top:2px;text-align:center;text-transform:uppercase}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item:first-child .o-sizing-control-item-input{border-radius:0 5px 5px 0}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item:last-child .o-sizing-control-item-input{border-radius:5px 0 0 5px}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item.toggle-linking{display:flex}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item.toggle-linking .o-sizing-control-item-input{border:1px solid #8d96a0;display:flex;height:30px;justify-content:center;width:100%}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item.toggle-linking .o-sizing-control-item-input svg{height:16px;width:16px}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item.toggle-linking.is-linked .o-sizing-control-item-input{background:#a4afb7;color:#fff}.o-sizing-control .o-sizing-control-wrapper .o-sizing-control-item.toggle-linking.is-linked .o-sizing-control-item-input:hover:not(:disabled):not([aria-disabled=true]):not(.is-secondary):not(.is-primary):not(.is-tertiary):not(.is-link){background:#a4afb7;box-shadow:inset 0 0 0 1px #e2e4e7,inset 0 0 0 2px #a4afb7,0 1px 1px rgba(25,30,35,.2);color:#fff}
.o-style-switcher{display:grid;grid-template-columns:50% 50%;grid-row-gap:5px}.o-style-switcher .o-style-switcher-item{border-radius:4px;cursor:pointer;display:block;flex-basis:50%;height:auto;margin:0 4px;min-height:100px;min-width:100px;overflow:hidden;padding:5px}.o-style-switcher .o-style-switcher-item.is-active{box-shadow:0 0 0 2px #000}.o-style-switcher .o-style-switcher-item:hover{background:#f3f4f5}.o-style-switcher .o-style-switcher-item:focus{box-shadow:0 0 0 2px #00a0d2}.o-style-switcher .o-style-switcher-item .o-style-switcher-item-preview img{border:1px solid #dcddde;border-radius:5px}.o-style-switcher .o-style-switcher-item .o-style-switcher-item-label{text-align:center}.otter-styles-popover-content .components-popover__content{padding:20px}
.o-sync-manage-control{padding:10px 0}.o-sync-manage-control .components-heading{margin:0}
.prompt-placeholder .components-placeholder__fieldset,.prompt-placeholder fieldset{display:flex;flex-direction:column}.prompt-placeholder .history-display{font-size:1.2em;padding:0 20px}.prompt-placeholder .o-info-row{display:flex;flex-direction:row;gap:10px}.prompt-fields{border-radius:10px;display:grid;font-size:13px;gap:10px;grid-template-columns:1fr 1fr;margin:10px;padding:10px}.prompt-fields .prompt-column-title{text-transform:uppercase}.prompt-fields .prompt-field__label,.prompt-fields .prompt-field__type{padding:12px 16px}.prompt-fields .prompt-field__label{background:rgba(159,171,178,.2);border-radius:3px}.prompt-input__container{align-items:center;display:flex;flex-direction:row;gap:10px;justify-content:center;margin-top:10px}.prompt-input__container .prompt-input__input__container{align-items:center;border:1px solid #949494;display:flex;flex-direction:row;flex-grow:1;gap:10px;padding:6px 14px 6px 6px}.prompt-input__container .prompt-input__input{-webkit-appearance:none;appearance:none;border:unset;flex-grow:1;font-size:18px;margin:0;max-height:500px;min-height:52px;outline:unset;padding:13px;resize:none}.prompt-input__container .prompt-input__submit__container button{font-size:18px;padding:26px}.prompt-result__container{background-color:#fff;border:1px solid #1e1e1e;border-radius:2px;display:flex;flex-direction:column;gap:10px;margin:0 auto;max-width:1200px;padding:10px;width:auto}.prompt-result__container .prompt-result__header{align-items:center;display:flex;flex-direction:row;gap:10px}.prompt-result__container .prompt-result__header .prompt-result__header__title{flex-grow:1;font-size:1.2em;font-weight:700}.prompt-result__container .prompt-result__actions{align-items:center;border-top:1px solid #ddd;display:flex;flex-direction:row;gap:10px;padding-top:10px}.prompt-result__container .prompt-result__actions .prompt-result__actions__navigation{align-items:center;display:flex;flex-direction:row;flex-grow:1;gap:10px;justify-content:flex-end}.prompt-result__container .prompt-token-usage{color:#757575;font-size:14px}
.components-button.o-block-appender-button{font-size:.65em;height:31px;margin:5px 0;padding:8px}.wp-block-themeisle-blocks-tabs .o-block-appender-button{height:30px;padding:0 8px}
.o-typo-component .o-typo-header{padding:10px 0 0}.o-typo-component .o-typo-header>.components-heading{margin:0}.o-typo-component .components-font-size-picker__controls .components-base-control{margin:0 0 8px}.o-responsive-control~.o-typo-component .o-typo-header{padding-top:0}.block-editor-block-inspector :is(.o-typo-component) :is(.components-base-control).o-no-margin,.o-options-global-defaults-modal :is(.o-typo-component) :is(.components-base-control).o-no-margin{margin:0}.block-editor-block-inspector :is(.o-typo-component) :is(.components-base-control).o-no-margin>.components-base-control__field .components-base-control,.o-options-global-defaults-modal :is(.o-typo-component) :is(.components-base-control).o-no-margin>.components-base-control__field .components-base-control{margin:0 0 14px}
.wp-block-themeisle-blocks-content-generator{border-radius:10px}.wp-block-themeisle-blocks-content-generator .o-preview{background-color:#fff;border:1px solid #1e1e1e;border-radius:5px;margin:10px 0;padding:10px}.wp-block-themeisle-blocks-content-generator .prompt-result__content .wp-block-themeisle-blocks-form .wp-block-button{display:none}.wp-block-themeisle-blocks-content-generator .prompt-result__content>div:not(.prompt-input__container):last-child{padding:10px}.wp-block-themeisle-blocks-content-generator .o-actions{align-items:baseline;border:1px dashed #1e1e1e;border-radius:3px;display:flex;flex-direction:row;gap:10px;padding:10px}.o-tracking-consent-toggle{align-items:center;background-color:#f7f7f7;border-radius:2px;display:flex;flex-direction:row;font-size:12px;gap:5px;margin-top:8px;padding:4px}.o-tracking-consent-toggle__label{flex-grow:1}.o-tracking-consent-toggle__close{height:24px}.o-tracking-consent-toggle__close>button.components-button.is-tertiary.has-icon{height:24px;padding:0}.o-tracking-consent-toggle__close>button.components-button.is-tertiary.has-icon svg{fill:#1e1e1e}
.components-menu-group .otter-icon{margin-left:4px}
.o-options-general .components-toggle-control .components-base-control__field{align-items:center;display:flex;margin-bottom:0}.o-options-general .o-onboarding-button.has-icon.has-text{box-shadow:inset 0 0 0 1px #e0e0e0;color:#000;justify-content:center;width:100%}.padding-20{padding:20px}.components-button.o-navi-button{border-bottom:1px solid #e0e0e0;border-top:1px solid #e0e0e0;box-shadow:none;color:#1e1e1e;font-weight:500;height:auto;outline:none;padding:16px 16px 16px 48px;position:relative;text-align:right;transition:background .1s ease-in-out;width:100%}.components-button.o-navi-button:hover{background:#f0f0f0;color:#1e1e1e}.components-button.o-navi-button:focus{border-radius:0;box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color)}.components-button.o-navi-button svg{height:24px;position:absolute;left:16px;width:24px}.components-button.o-navi-button.o-navi-button-back{padding:12px 16px 12px 48px}.components-button.o-navi-button.o-navi-button-back svg{right:0;position:relative}.o-options-global-defaults .o-options-block-item{background:#fff;border:1px solid #d5dadf;display:flex;margin:10px 20px}.o-options-global-defaults .o-options-block-item:hover{background:#fafafb}.o-options-global-defaults .o-options-block-item.editable .o-options-block-item-label{flex-basis:40%;flex-grow:1;padding-left:5px}.o-options-global-defaults .o-options-block-item.hidden{color:#e5e5e5}.o-options-global-defaults .o-options-block-item.hidden .o-options-block-item-icon svg{fill:#e5e5e5!important}.o-options-global-defaults .o-options-block-item.hidden .o-options-block-item-label{color:#e5e5e5}.o-options-global-defaults .o-options-block-item .o-options-block-item-icon{align-self:center;display:flex;flex-basis:20%;justify-content:center;padding:15px 0}.o-options-global-defaults .o-options-block-item .o-options-block-item-icon svg{height:18px;width:18px}.o-options-global-defaults .o-options-block-item .o-options-block-item-label{align-items:center;cursor:default;display:flex;flex-basis:60%}.o-options-global-defaults .o-options-block-item .o-options-block-item-label::selection{background:none}.o-options-global-defaults .o-options-block-item .o-options-block-item-button{border-right:1px solid #d5dadf;border-radius:0;flex-basis:20%;height:auto;justify-content:center;padding:10px 5px}.o-options-global-defaults .o-options-block-item .o-options-block-item-button.components-icon-button:not(:disabled):not([aria-disabled=true]):not(.is-default):hover{background:#fafafb;border-radius:0;box-shadow:none}.o-options-global-defaults .o-options-block-item .o-options-block-item-button .dashicon,.o-options-global-defaults .o-options-block-item .o-options-block-item-button svg{margin:2px}.o-options-global-defaults .components-placeholder{box-shadow:none}.o-options-global-defaults-modal .components-panel__body-toggle{padding:15px 24px}.o-options-global-defaults-modal .components-panel__body-toggle .components-panel__arrow{left:22px}.o-options-global-defaults-modal :is(.components-unit-control-wrapper,.components-base-control,.o-responsive-control){margin:0;padding-right:10px}.o-options-global-defaults-modal div:not(.components-base-control__field)>.o-sizing-control{margin:0;padding:10px}.o-options-global-defaults-modal .components-base-control .components-base-control__label{margin-bottom:1em}.o-options-global-defaults-modal .components-base-control :is(.components-base-control,.components-font-size-picker__header){padding:0}.o-options-global-defaults-modal :is(.o-typo-header,.o-control-panel-control,.components-font-size-picker__header,.component-box-control__header,.component-box-control__header-control-wrapper){padding-right:10px}.o-options-global-defaults-modal .o-responsive-control :is(.components-base-control,.component-box-control__header,.components-font-size-picker__header,.component-box-control__header-control-wrapper){padding:0}.o-options-global-defaults-modal .components-font-size-picker__controls{margin:0}.o-options-global-defaults-modal hr{border:.1px solid #f3f3f3}.o-options-global-defaults-modal .o-options-global-defaults-actions{align-items:center;display:flex;justify-content:flex-end;padding:15px 24px}.o-options-global-defaults-modal .o-options-global-defaults-actions button{height:auto;line-height:28px;padding:0 12px 2px}.o-options-global-defaults-modal .o-options-global-defaults-actions button.is-primary{margin-right:10px}.o-sidebar-toggle:is(.components-base-control){margin-bottom:0}
.o-conditions{margin-top:10px}.o-conditions .components-button.is-small{height:28px;margin-right:10px}.o-conditions__operator-wrapper{height:45px;margin:10px 0;position:relative}.o-conditions__operator-wrapper .o-conditions__operator-line{background:#d4d4d4;bottom:5px;right:50%;position:absolute;top:5px;width:1px;z-index:1}.o-conditions__operator-wrapper .o-conditions__operator-word{height:12px;right:0;margin-top:-10px;position:absolute;left:0;text-align:center;top:50%;z-index:2}.o-conditions__operator-wrapper .o-conditions__operator-word span{background:#fff;color:#747d86;font-size:11px;letter-spacing:1px;padding:3px;text-transform:uppercase}.o-conditions__add{display:flex;justify-content:center;margin-top:15px;width:100%}.block-editor-block-list__layout .block-editor-block-list__block:not(.is-selected).otter-has-condition:after{border:1px solid var(--wp-admin-theme-color);color:var(--wp-admin-theme-color);content:"Block Conditions";display:block;font-size:10px;font-weight:700;height:20px;right:auto;line-height:20px;position:absolute;left:0;text-align:center;text-transform:uppercase;width:120px;z-index:1}
.fab.wp-block-navigation-item,.far.wp-block-navigation-item,.fas.wp-block-navigation-item{align-items:center;display:flex;font-weight:inherit;-moz-osx-font-smoothing:inherit;-webkit-font-smoothing:inherit;line-height:inherit}.fab.wp-block-navigation-item:before,.far.wp-block-navigation-item:before,.fas.wp-block-navigation-item:before{margin-left:5px}.fab.wp-block-navigation-item:before,.far.wp-block-navigation-item:before{font-weight:400}.fas.wp-block-navigation-item:before{font-weight:900}
.o-sticky-highlight{position:relative}.o-sticky-highlight .o-sticky-badge{background-color:#fff;border:1px solid var(--wp-admin-theme-color);border-radius:3px;color:var(--wp-admin-theme-color);display:none;font-size:10px;padding:3px 5px;position:absolute;left:-20px;text-align:center;top:-11px;z-index:30}.o-sticky-highlight .o-sticky-badge.active{display:inherit}.o-sticky-highlight.active{outline:1px dashed var(--wp-admin-theme-color)}.o-sticky-highlight.o-container>.o-sticky-badge{background-color:#eef2fe}.o-sticky:not(.is-selected):after{border:1px solid var(--wp-admin-theme-color);color:var(--wp-admin-theme-color);content:"Sticky";display:block;font-size:10px;font-weight:700;height:20px;right:auto;line-height:20px;position:absolute;left:0;text-align:center;text-transform:uppercase;top:0;width:120px;z-index:1}.o-sticky.o-sticky-banner-mode:not(.is-selected):after{content:"Sticky Banner"}
.o-dynamic:disabled .o-dynamic-list-item{opacity:.5}.o-dynamic:disabled .o-dynamic-list-item:after{background:#1e7db3;border-radius:2px;color:#fff;content:"Pro";font-size:8px;margin-right:5px;padding:4px 6px;position:relative;text-transform:uppercase;top:-1px}.o-dynamic .o-dynamic-list-item{display:list-item;list-style-position:inside;list-style-type:disc}o-dynamic-link{background:rgba(237,111,87,.1);border-radius:8px;color:#ed6f57;cursor:pointer;padding:2px 5px}.o-dynamic-button{opacity:1}.o-dynamic-button.is-pressed:before{background:rgba(237,111,87,.1)}.o-dynamic-button .dashicon:before{color:#ed6f57}.o-dynamic-button svg{fill:#ed6f57}.wp-block.is-selected o-dynamic,.wp-block:not(.is-selected) o-dynamic:not([data-preview]),.wp-block:not(.is-selected) o-dynamic[data-preview=""]{background:rgba(237,111,87,.1);border-radius:8px;color:#ed6f57;cursor:pointer;padding:2px 5px}.wp-block:not(.is-selected) o-dynamic[data-preview]:not([data-preview=""]):not(.hide-highlight){text-decoration-color:var(--wp-admin-theme-color);text-decoration-line:underline;text-decoration-style:dashed;text-decoration-thickness:7%}.wp-block:not(.is-selected) o-dynamic[data-preview]:not([data-preview=""]) span{display:none}.wp-block:not(.is-selected) o-dynamic[data-preview]:not([data-preview=""]):after{content:attr(data-preview)}o-dynamic-link{text-decoration:underline}.o-dynamic-modal .components-modal__content{margin:0;max-width:360px;overflow-y:hidden;overflow-y:scroll;padding:0}.o-dynamic-modal .components-modal__content:before{margin-bottom:0;min-height:60px}.o-dynamic-modal .components-modal__header{background:#fff;margin:0;padding:0 24px}@media(min-width:600px){.o-dynamic-modal .components-modal__header{position:relative}}.o-dynamic-modal__preview__content{background-color:#f3f3f3;border-radius:4px;overflow:hidden;padding:15px;text-overflow:ellipsis;white-space:nowrap}.o-dynamic-modal__preview__content.is-loading{display:flex;justify-content:center}.o-dynamic-modal__preview__content .components-spinner{margin:0}.o-dynamic-modal__preview__description{font-size:11px;font-style:italic;margin-top:5px}.o-dynamic-popover.hidden{display:none}.o-dynamic-popover .components-popover__content{width:300px}.o-dynamic-popover .components-panel__body-toggle{padding:16px 16px 16px 48px}.o-dynamic-popover .components-form-token-field__token-text{align-items:center;display:flex}.o-dynamic-popover .o-dynamic-popover-toggle{justify-content:center;width:100%}.o-dynamic-popover .o-dynamic-popover-toggle:focus{box-shadow:none}.o-dynamic-popover .o-notice{margin:10px 0 0}.media-modal.acf-expanded .attachments-browser{max-width:60%}.media-modal.acf-expanded .media-sidebar{max-width:40%}.o-media-wrapper{border:0;bottom:0;top:0}.o-media-wrapper .attachments-browser{max-width:85%}.o-media-wrapper .attachments-browser .o-is-powered{justify-content:center}.o-media-wrapper .media-sidebar{max-width:15%}.o-media-wrapper .media-sidebar .o-media-pro-upsell{align-items:center;background:#fff;display:flex;flex-direction:column;gap:12px;margin-top:20px;padding:6px 18px 18px}.o-media-wrapper .media-sidebar .o-media-pro-upsell img{max-width:80%}.o-media-wrapper .media-sidebar .o-media-pro-upsell-title{font-size:13px;font-weight:500;text-align:center}.o-media-wrapper .media-sidebar .o-media-pro-upsell-description{text-align:center}.o-media-wrapper .media-sidebar #o-feedback{bottom:0;right:0;margin:0 auto;position:absolute;left:0;width:max-content}.o-media-wrapper .o-media-list{display:flex;flex-wrap:wrap;margin:0;padding:15px}.o-media-wrapper .o-media-item{background:#f0f0f1;background-position-x:center;background-position-y:40%;background-repeat:no-repeat;box-shadow:inset 0 0 15px rgba(0,0,0,.1),inset 0 0 0 1px rgba(0,0,0,.05);cursor:pointer;display:flex;flex-basis:150px;height:150px;list-style:none;margin:5px;position:relative}.o-media-wrapper .o-media-item:focus{box-shadow:inset 0 0 0 4px #4f94d4;outline:2px solid transparent;outline-offset:-6px}.o-media-wrapper .o-media-item.selected{box-shadow:inset 0 0 0 4px #2271b1}.o-media-wrapper .o-media-item.is-disabled{cursor:default;opacity:.5}.o-media-wrapper .o-media-item .check{background-color:#2271b1;border:0;box-shadow:0 0 0 1px #fff,0 0 0 2px #2271b1;cursor:pointer;display:block;height:24px;outline:none;padding:0;position:absolute;left:0;top:0;width:24px;z-index:10}.o-media-wrapper .o-media-item .check:hover .media-modal-icon{background-position:right -61px top 0}.o-media-wrapper .o-media-item .check .media-modal-icon{background-position:right -21px top 0;background-size:134px 15px;display:block;height:15px;margin:5px;width:15px}.o-media-wrapper .o-media-item-title{align-self:flex-end;font-weight:700;padding:10px;text-align:center;text-transform:uppercase;width:100%}.o-media-wrapper .o-media-item-label{background:#557bdf;border-radius:3px;color:#fff;font-size:10px;font-weight:700;height:16px;line-height:160%;padding:2px 8px;position:absolute;left:10px;text-transform:uppercase;top:10px}#o-dynamic-select{width:100%}
.components-modal__frame.components-guide.o-welcome-guide{border-radius:8px;max-height:620px;width:340px}.components-modal__frame.components-guide.o-welcome-guide img{background:#eee8e5;margin:0 0 16px;max-height:240px}.components-modal__frame.components-guide.o-welcome-guide .o-welcome-guide__heading{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;font-size:24px;line-height:1.4;margin:16px 0;padding:0 32px}.components-modal__frame.components-guide.o-welcome-guide .o-welcome-guide__text{font-size:13px;line-height:1.4;margin:0 0 24px;padding:0 32px}.components-modal__frame.components-guide.o-welcome-guide .o-welcome-guide__input{font-size:13px;padding:0 32px}.components-modal__frame.components-guide.o-welcome-guide .components-external-link{color:#ed6f57;margin-right:5px}
#o-feedback{padding:15px}#o-feedback.is-link{text-decoration:none}.o-feedback-modal-overlay{z-index:999999999}.o-feedback-form .invalid textarea{border-color:#d63638;box-shadow:0 0 0 .5px #d63638;outline:2px solid transparent}.o-feedback-form .f-error p,.o-feedback-form .invalid p{color:#d63638}.o-feedback-form .buttons-wrap{display:flex;justify-content:space-between;margin-top:14px}.o-feedback-form .f-send{min-width:112px}.o-feedback-form .f-send>svg{margin:0 auto}.o-feedback-form .toggle-info{text-decoration:none}.o-feedback-form .info{color:#757575;height:0;overflow:hidden;transition:.2s ease-out}.o-feedback-form .info .wrapper{padding-bottom:3px}.o-feedback-form .info .wrapper>p{margin-top:0}.o-feedback-form .info-row{border-bottom:1px solid #cbcbcb;display:flex;justify-content:space-between}.o-feedback-form .info-row p{margin:6px 0!important}.o-feedback-modal{border-radius:10px;overflow:visible;width:490px}.o-feedback-modal.no-header .components-modal__content{margin-top:0;padding-top:24px}.o-feedback-modal.no-header .components-modal__content:before,.o-feedback-modal.no-header .components-modal__header{display:none}.o-feedback-modal .components-modal__header{border:none}.o-feedback-modal .components-modal__header-heading{font-size:20px;font-weight:400}.finish-feedback{text-align:center}.finish-feedback .f-title{font-size:23px;line-height:28px;margin:.5em 0}.finish-feedback .f-description{margin:0 auto 20px!important;width:60%}.finish-feedback button.f-done{padding:0 30px}
.o-block-tools.components-tools-panel{display:block;padding:0}.o-block-tools.components-tools-panel .components-tools-panel-header{padding:16px}
.o-live-search .o-notice.is-upsell{margin-top:20px}.o-live-search img.otter-live-search-thumbnail-image{margin-top:16px}.o-live-search__doc{display:flex;justify-content:center;width:100%}
.o-block-patterns-upsell{align-items:center;background:#ed6f57;display:flex;height:56px;justify-content:space-between;max-width:none!important;padding:0 24px}.o-block-patterns-upsell.is-neve{margin:-8px -8px -28px}.o-block-patterns-upsell h3{font-size:14px!important}.o-block-patterns-upsell a,.o-block-patterns-upsell h3{color:#fff!important;font-weight:600!important;margin:0}.o-block-patterns-upsell a{background:#f07d66;border-radius:2px;font-size:14px;font-weight:700;padding:8px 12px;text-decoration:none!important}.o-block-patterns-upsell .components-button{color:#fff}.o-block-patterns-upsell .o-block-patterns-upsell__actions{align-items:center;display:flex}.block-editor-block-preview__content-iframe .o-block-patterns-upsell{display:none}
.o-menu-item-alignment{color:var(--wp-components-color-foreground,#1e1e1e);padding-right:8px;text-decoration:none}.o-menu-item-alignment :is(.components-external-link__contents){text-decoration:none}.o-menu-item-header{color:#828282;font-family:monospace;font-size:13px;text-transform:uppercase}
.o-library__button.components-button.is-secondary{box-shadow:inset 0 0 0 1px #000,0 0 0 #000;color:#000}.o-library__modal .components-modal__header{border-bottom-color:#ddd}.o-library__modal__sidebar{bottom:0;right:0;overflow-x:visible;overflow-y:scroll;padding:24px 32px 32px;position:absolute;top:72px;width:280px}.o-library__modal__sidebar__heading{font-size:12px;font-weight:700;margin-top:2em;text-transform:uppercase}.o-library__modal__sidebar .components-button{height:48px;text-align:right;width:100%}.o-library__modal__content{margin-right:280px;padding:24px 0 32px}.o-library__modal__content__actions{background:#fff;display:flex;justify-content:space-between;margin-right:-4px;padding:10px 3px 10px 0;position:sticky;top:-4px;width:calc(100% + 6px);z-index:10}.o-library__modal__content__grid{display:grid;gap:2rem;grid-template-columns:1fr 1fr 1fr}.o-library__modal__content__grid.is-2-column{grid-template-columns:1fr 1fr}.o-library__modal__content__grid.is-4-column{grid-template-columns:1fr 1fr 1fr 1fr}.o-library__modal__footer{background:#fff;border:1px solid #e0e0e0;bottom:0;box-shadow:0 0 0 1px #e0e0e0;display:flex;justify-content:flex-end;right:0;overflow-x:visible;padding:24px;position:absolute;width:100%;z-index:9}.o-library__preview .block-editor-block-preview__content,.o-library__preview .block-editor-block-preview__content iframe{max-height:none!important}.o-library__template{border:1px solid #e0e0e0;border-radius:4px;box-shadow:0 0 0 1px #e0e0e0;display:grid;gap:0;grid-template-rows:1fr 48px;overflow:hidden;position:relative}.o-library__template__preview{cursor:pointer;display:flex;flex-direction:column;justify-content:center;min-height:200px}.o-library__template__actions{align-items:center;border-top:2px solid #e0e0e0;display:grid;grid-template-columns:30px 1fr 110px;padding:6px 12px}.o-library__template__actions .components-base-control__field{margin-bottom:0}.o-library__template__actions__title{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.o-library__template__actions__button{display:flex;gap:12px}.o-library__template__actions__button .is-favorite svg{fill:#ff8787}.o-library__tc-placeholder{align-items:center;border:2px dashed #e5e7eb;border-radius:8px;display:flex;flex-direction:column;padding:20px 15px}.o-library__tc-placeholder svg{fill:#9ca3af;margin-bottom:16px}.o-library__tc-placeholder h2{font-size:18px;margin:0 0 12px}.o-library__tc-placeholder p{font-size:14px;margin:0;text-align:center}.o-library__tc-placeholder a{font-size:14px;text-decoration:none!important}
