.elementor-animation-grow {
	transition-duration: 0.3s;
	transition-property: transform;
}
.elementor-animation-grow:active,
.elementor-animation-grow:focus,
.elementor-animation-grow:hover {
	transform: scale(1.1);
}
