#o-feedback{padding:15px}#o-feedback.is-link{text-decoration:none}.o-feedback-modal-overlay{z-index:999999999}.o-feedback-form .invalid textarea{border-color:#d63638;box-shadow:0 0 0 .5px #d63638;outline:2px solid transparent}.o-feedback-form .f-error p,.o-feedback-form .invalid p{color:#d63638}.o-feedback-form .buttons-wrap{display:flex;justify-content:space-between;margin-top:14px}.o-feedback-form .f-send{min-width:112px}.o-feedback-form .f-send>svg{margin:0 auto}.o-feedback-form .toggle-info{text-decoration:none}.o-feedback-form .info{color:#757575;height:0;overflow:hidden;transition:.2s ease-out}.o-feedback-form .info .wrapper{padding-bottom:3px}.o-feedback-form .info .wrapper>p{margin-top:0}.o-feedback-form .info-row{border-bottom:1px solid #cbcbcb;display:flex;justify-content:space-between}.o-feedback-form .info-row p{margin:6px 0!important}.o-feedback-modal{border-radius:10px;overflow:visible;width:490px}.o-feedback-modal.no-header .components-modal__content{margin-top:0;padding-top:24px}.o-feedback-modal.no-header .components-modal__content:before,.o-feedback-modal.no-header .components-modal__header{display:none}.o-feedback-modal .components-modal__header{border:none}.o-feedback-modal .components-modal__header-heading{font-size:20px;font-weight:400}.finish-feedback{text-align:center}.finish-feedback .f-title{font-size:23px;line-height:28px;margin:.5em 0}.finish-feedback .f-description{margin:0 auto 20px!important;width:60%}.finish-feedback button.f-done{padding:0 30px}
