.obfx-image-list {
	overflow: auto;
	position: absolute;
	top: 50px;
	right: 300px;
	bottom: 0;
	left: 0;
	width: 95%;
	margin: 0;
	padding: 2px 8px 8px;
	outline: 0;
	opacity: 1;

	-webkit-overflow-scrolling: touch;
}

.obfx-preview {
	position: relative;
	background: #eee;
	box-shadow: inset 0 0 15px rgba(0,0,0,0.1), inset 0 0 0 1px rgba(0,0,0,0.05);
	cursor: pointer;
}

.obfx-preview:before {
	display: block;
	padding-top: 100%;
	content: "";
}

.obfx-preview .thumbnail {
	overflow: hidden;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	opacity: 1;
	-webkit-transition: opacity 0.1s;
	transition: opacity 0.1s;
}

.obfx-preview .thumbnail:after {
	display: block;
	overflow: hidden;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	box-shadow: inset 0 0 0 1px rgba(0,0,0,0.1);
	content: "";
}

.obfx-preview .thumbnail .centered {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	-webkit-transform: translate(50%,50%);
	-ms-transform: translate(50%,50%);
	transform: translate(50%,50%);
}

.obfx-preview .thumbnail .centered img {
	-webkit-transform: translate(-50%,-50%);
	-ms-transform: translate(-50%,-50%);
	transform: translate(-50%,-50%);
}

.obfx-image {
	float: left;
	position: relative;
	box-sizing: border-box;
	width: 20%;
	margin: 0;
	padding: 8px;
	color: #444;
	text-align: center;
	list-style: none;
	cursor: pointer;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}

.obfx-image-list .obfx-image.details {
	box-shadow: inset 0 0 0 3px #fff, inset 0 0 0 7px #0073aa;
}

.obfx-image-list .obfx-image.details .check,
.obfx-image-list .obfx-image.selected .check:focus {
	display: block;
	background-color: #0073aa;
	box-shadow: 0 0 0 1px #fff, 0 0 0 2px #0073aa;
}

.obfx-image-list .obfx-image .check {
	display: none;
	position: absolute;
	z-index: 10;
	top: 0;
	right: 0;
	width: 24px;
	height: 24px;
	padding: 0;
	border: 0;
	outline: 0;
	background: #eee;
	box-shadow: 0 0 0 1px #fff, 0 0 0 2px rgba(0, 0, 0, 0.15);
	cursor: pointer;
}

.obfx-image-list .obfx-image.details .check:hover .media-modal-icon,
.obfx-image-list .obfx-image.selected .check:focus .media-modal-icon {
	background-position: -60px 0;
}

.obfx-image-list .obfx-image.details .check .media-modal-icon {
	background-position: -21px 0;
}

.obfx-image-list .obfx-image .check:hover .media-modal-icon {
	background-position: -40px 0;
}

.obfx-image-list .obfx-image .check .media-modal-icon {
	display: block;
	width: 15px;
	height: 15px;
	margin: 5px;
	background-position: -1px 0;
}

.obfx-image-list .media-modal-icon {
	background-image: url(../../../../../../wp-includes/images/uploader-icons.png);
	background-repeat: no-repeat;
}

.wp-core-ui .button.obfx-import-media {
	float: right;
	margin-top: 10px;
}

.attachement-settings {
	float: right;
	width: 100%;
}

.attachement-settings .name {
	padding-right: 10px;
}

.attachement-loading {
	float: left;
	width: 100%;
	text-align: center;
}

.attachement-loading .spinner {
	float: none;
	width: auto;
	height: auto;
	padding: 10px;
}

.obfx_spinner {
	display: none;
	width: 32px;
	height: 32px;
	margin: 25% auto 0;
	opacity: 0.9;
	background: url("/wp-admin/images/wpspin_light-2x.gif") no-repeat;
	background-size: 32px 32px;

	filter: alpha(opacity=70);
}

.obfx-image-list.obfx_loading {
	opacity: 0.5;

	filter: alpha(opacity=50);
}
