.customize-control-interface-tabs {
	display: list-item !important;
}

.hestia-tabs-control {
	border-bottom: 1px solid #ddd;
	width: calc(100% + 28px);
	margin: -15px 0 0 -12px;
	table-layout: fixed;
	display: table;
}

.hestia-tabs-control .hestia-customizer-tab {
	border-right: 1px solid #ddd;
	display: table-cell;
	text-align: center;
	width: 100%;
}

.hestia-tabs-control .hestia-customizer-tab:last-child {
	border-right: none;
}

.hestia-tabs-control .hestia-customizer-tab label{
	text-transform: capitalize;
	background: #fff;
	box-shadow: inset 0 0 0 0 #0085ba;
	transition: all .3s ease;
	display: block;
	width: 100%;
	padding: 10px 0;
	text-decoration: none;
	font-weight: 600;
	color: #333;
	display: flex;
    align-items: center;
    font-size: inherit;
    line-height: 1;
    justify-content: center;
}

.hestia-tabs-control .hestia-customizer-tab label i {
	color: #333;
	margin-right: 4px;
}

.hestia-tabs-control .hestia-customizer-tab label:hover {
	color: #0085ba;
	background: #f3f3f5;
}

.hestia-tabs-control .hestia-customizer-tab label:hover i {
	color: #333;
}

.hestia-tabs-control .hestia-customizer-tab.active label{
	box-shadow: inset 0 -3px 0 0 #0085ba;
	color: #0085ba;
	background-color: #fff;
}

.hestia-tabs-control input[type="radio"] {
	display: none !important;
}

.hestia-tabs-control span.dashicons-lock {
    font-size: 12px;
    color: #a3a3a3;
    width: 12px;
    height: 12px;
    vertical-align: middle;
}
.hestia-customizer-tab label span:last-child {
    margin-left: 5px;
}

.hestia-customizer-tab label span:first-child {
    margin-right: 3px;
}

#customize-control-hestia_pricing_upsell_notice ~ li {
    opacity: .4;
    pointer-events: none;
}
.customize-control.customize-control-checkbox .dashicons-lock,
.customize-control.customize-control-text .dashicons-lock,
.customize-control.customize-control-media .dashicons-lock,
.customize-control.customize-control-textarea .dashicons-lock,
.customize-control.customize-control-radio-image .dashicons-lock {
	font-size: 16px;
	color: #A3A3A3;
	margin-top: 3px;
}
select + span.dashicons-lock:not(.is-pro-option) {
	opacity: 0;
}
select.is-pro-option + span.dashicons-lock {
	position: absolute;
    bottom: -5px;
    left: 50px;
    font-size: 16px;
    color: #A3A3A3;
    opacity: 1;
}
#customize-control-hestia_slider_type label {
	position: relative;
}
#sub-accordion-section-hestia_big_title:not(.hestia-locked-icon) span.dashicons-lock {
	display: none;
}
#sub-accordion-section-hestia_big_title.hestia-locked-icon li#customize-control-hestia_slider_type ~ li {
	opacity: .4;
    pointer-events: none;
}
#sub-accordion-section-hestia_big_title.hestia-locked-icon #customize-control-hestia_big_title_upsell_notice {
    display: block !important;
}
.customize-locked-control {
    opacity: .4;
    pointer-events: none;
}
#customize-control-hestia_cart_custom_icon:not(.hestia-show-custom-icon) {
	display: none;
}
.customize-control-checkbox#customize-control-hestia_cart_icon_status .dashicons-lock {
	margin-top: 1px;
}
#customize-control-hestia_cart_icon {
	display: none;
}