<?php return array(
    'root' => array(
        'name' => 'codeinwp/themeisle-companion',
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'reference' => '7b1544d867e400e9dba8969a275e2797d8fda3fc',
        'type' => 'wordpress-plugin',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'clue/stream-filter' => array(
            'pretty_version' => 'v1.7.0',
            'version' => '1.7.0.0',
            'reference' => '049509fef80032cb3f051595029ab75b49a3c2f7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/stream-filter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/full-width-page-templates' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => 'ac15bbb1295d39baf28978c7d9c04fed21ea3429',
            'type' => 'library',
            'install_path' => __DIR__ . '/../codeinwp/full-width-page-templates',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/themeisle-companion' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '7b1544d867e400e9dba8969a275e2797d8fda3fc',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/themeisle-sdk' => array(
            'pretty_version' => '3.3.48',
            'version' => '3.3.48.0',
            'reference' => '0727d2cf2fc9bfb81b42968aeaf2bf4e340f021e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../codeinwp/themeisle-sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'enshrined/svg-sanitize' => array(
            'pretty_version' => '0.19.0',
            'version' => '0.19.0.0',
            'reference' => 'e95cd17be68e45f523cbfb0fe50cdd891b0cf20e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../enshrined/svg-sanitize',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => 'e4490cabc77465aaee90b20cfc9a770f8c04be6b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mailerlite/mailerlite-api-v2-php-sdk' => array(
            'pretty_version' => '0.2.3',
            'version' => '0.2.3.0',
            'reference' => '2bae0aac12c4588bc0197d2e2dde5a55429b9e44',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mailerlite/mailerlite-api-v2-php-sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/async-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'php-http/client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'php-http/curl-client' => array(
            'pretty_version' => 'v1.7.1',
            'version' => '1.7.1.0',
            'reference' => '6341a93d00e5d953fc868a3928b5167e6513f2b6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/curl-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/discovery' => array(
            'pretty_version' => '1.6.1',
            'version' => '1.6.1.0',
            'reference' => '684855f2c2e9d0a61868b8f8d6bd0295c8a4b651',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/discovery',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/httplug' => array(
            'pretty_version' => 'v1.1.0',
            'version' => '1.1.0.0',
            'reference' => '1c6381726c18579c4ca2ef1ec1498fdae8bdf018',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/httplug',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/message' => array(
            'pretty_version' => '1.7.2',
            'version' => '1.7.2.0',
            'reference' => 'b159ffe570dffd335e22ef0b91a946eacb182fa1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/message-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '4d8778e1c7d405cbb471574821c1ff5b68cc8f57',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/message-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/message-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'php-http/promise' => array(
            'pretty_version' => 'v1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'dc494cdc9d7160b9a09bd5573272195242ce7980',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'f6561bf28d520154e4b0ec72be95418abe6d9363',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
