.editor-styles-wrapper .editor-post-title__block .editor-post-title__input {
  font-family: "Roboto Slab", "Times New Roman", serif;
  font-weight: 700;
  font-size: 42px;
  color: #3C4858;
}

.editor-styles-wrapper .editor-default-block-appender textarea.editor-default-block-appender__content {
  font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
  font-size: 18px;
  font-weight: 300;
}
.editor-styles-wrapper .editor-writing-flow {
  font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
  color: #3C4858;
  font-size: 18px;
  font-weight: 300;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.editor-styles-wrapper .editor-writing-flow p {
  font-size: 18px;
}
.editor-styles-wrapper .editor-writing-flow h1, .editor-styles-wrapper .editor-writing-flow h2, .editor-styles-wrapper .editor-writing-flow h3, .editor-styles-wrapper .editor-writing-flow h4, .editor-styles-wrapper .editor-writing-flow h5, .editor-styles-wrapper .editor-writing-flow h6 {
  font-weight: 500;
  line-height: 1.618;
}
.editor-styles-wrapper .editor-writing-flow a {
  color: #e91e63;
  text-decoration: none;
}
.editor-styles-wrapper .editor-writing-flow a:hover {
  opacity: 0.75;
}
.editor-styles-wrapper .editor-writing-flow h1 {
  font-size: 42px;
}
.editor-styles-wrapper .editor-writing-flow h2 {
  font-size: 37px;
}
.editor-styles-wrapper .editor-writing-flow h3 {
  font-size: 32px;
}
.editor-styles-wrapper .editor-writing-flow h4 {
  font-size: 27px;
}
.editor-styles-wrapper .editor-writing-flow h5 {
  font-size: 23px;
}
.editor-styles-wrapper .editor-writing-flow h6 {
  font-size: 18px;
}
.editor-styles-wrapper .editor-writing-flow pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 1.42857143;
  word-break: break-all;
  word-wrap: break-word;
  color: #333;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border-radius: 4px;
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
}
.editor-styles-wrapper .wp-block-cover {
  font-size: inherit;
}
.editor-styles-wrapper .wp-block-cover p.wp-block-cover-text {
  font-size: 2em;
}
.editor-styles-wrapper .wp-block-quote p {
  font-style: italic;
}
.editor-styles-wrapper .wp-block-quote.has-text-align-right {
  border-right: 5px solid #eee;
}
.editor-styles-wrapper .wp-block-quote:not(.has-text-align-right) {
  border-left: 5px solid #eee;
}
.editor-styles-wrapper .wp-block-quote:not(.is-large):not(.is-style-large) {
  padding: 10px 20px;
}
.editor-styles-wrapper .wp-block-quote:not(.is-large):not(.is-style-large) .wp-block-quote__citation {
  font-size: 0.8em;
  color: #777;
  font-style: normal;
  font-weight: 400;
}
.editor-styles-wrapper .wp-block-quote.is-style-large p {
  font-size: 24px;
}
.editor-styles-wrapper .wp-block-quote.is-style-large .wp-block-quote__citation {
  font-size: 18px;
  color: #777;
  font-style: normal;
  font-weight: 400;
}
.editor-styles-wrapper .wp-block-table td {
  border: none;
}
.editor-styles-wrapper .wp-block-table tr {
  border-bottom: 1px solid #eee;
}
.editor-styles-wrapper .wp-block-separator {
  color: #eee;
  background-color: #eee;
  border: none;
}
.editor-styles-wrapper .wp-block-separator:not(.is-style-wide):not(.is-style-dots) {
  height: 2px;
  max-width: 150px;
}
.editor-styles-wrapper .wp-block-separator .is-style-default {
  height: 1px;
}
.editor-styles-wrapper .wp-block-separator.is-style-wide {
  max-width: 100%;
  height: 1px;
}

.wp-block-image.is-style-rounded img,
.wp-block-media-text.is-image-fill .wp-block-media-text__media,
.wp-block-post-featured-image,
.wp-block-image-shadow img,
.wp-block-media-text .wp-block-media-text__media img {
  -webkit-box-shadow: 0 16px 38px -12px rgba(0, 0, 0, 0.56), 0 4px 25px 0 rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.2);
  -moz-box-shadow: 0 16px 38px -12px rgba(0, 0, 0, 0.56), 0 4px 25px 0 rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.2);
  box-shadow: 0 16px 38px -12px rgba(0, 0, 0, 0.56), 0 4px 25px 0 rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.2);
}

.hestia-3-cols-team .has-text-align-center,
.hestia-3-cols-team .has-text-align-left,
.hestia-3-cols-team .has-text-align-right {
  max-width: 486px;
}