/* Box model hack: http://tantek.com/CSS/Examples/boxmodelhack.html */

#elem {
    width: 100px;
    voice-family: "\"}\"";
    voice-family:inherit;
    width: 200px;
}
html>body #elem {
    width: 200px;
}

/* preserving newlines in strings */
#sel-o {
    content: "on\"ce upon \
a time";
    content: 'once upon \
a ti\'me';
}


/* preserving strings */
.sele {
    content: "\"keep  \"    me";
    something: '\\\' .     . ';
    else: 'empty{}';
    content: "/* test */"; /* <---- this is not a comment, should be be kept */
}