.wp-block-themeisle-blocks-google-map{--height: 400px;--height-tablet: var( --height );--height-mobile: var( --height-tablet );margin:20px 0}.wp-block-themeisle-blocks-google-map .wp-block-themeisle-blocks-google-map-container{height:var(--height)}@media(min-width: 600px)and (max-width: 960px){.wp-block-themeisle-blocks-google-map .wp-block-themeisle-blocks-google-map-container{height:var(--height-tablet) !important}}@media(max-width: 600px){.wp-block-themeisle-blocks-google-map .wp-block-themeisle-blocks-google-map-container{height:var(--height-mobile) !important}}.wp-block-themeisle-blocks-map{margin:20px 0;animation:load 4s 4}@keyframes load{0%,100%{background-color:inherit}50%{background-color:#d8d8d8}}.wp-block-themeisle-blocks-map-overview h6.wp-block-themeisle-blocks-map-overview-title{font-size:14px;margin:10px 0}.wp-block-themeisle-blocks-map-overview .wp-block-themeisle-blocks-map-overview-content p{font-size:12px}.wp-block-themeisle-blocks-map-overview .wp-block-themeisle-blocks-map-overview-delete{cursor:pointer}/*# sourceMappingURL=style.css.map */
