:root{--om-admin-bar-height: 32px}@media screen and (max-width: 782px){:root{--om-admin-bar-height: 46px}}#om-dam{height:calc(100vh - var(--om-admin-bar-height));width:100%;border:none;z-index:1;position:relative}#wpcontent,#wpbody-content{padding:0}#wpbody-content{background:#f6f6fa}#wpfooter{display:none}.om-dam-loader{height:calc(100vh - var(--om-admin-bar-height));display:flex;flex-direction:column;align-items:center;justify-content:center;width:100%}.om-dam-loader p{margin-top:20px;font-size:1.2rem;font-weight:500;color:#333}.om-dam-loader img{max-width:150px;animation:animate-opacity 1.5s infinite}@keyframes animate-opacity{0%{opacity:.75}50%{opacity:1}100%{opacity:.75}}
