.sidebar__sale_banner_container .sidebar__sale_banner{box-shadow:0 -1px 4px 0 #fcd34d,0 1px 4px 0 #fcd34d,0 -1px 0 0 #fcd34d,0 1px 0 0 #fcd34d;color:#fcd34d;letter-spacing:.5px;line-height:30px;margin-bottom:10px;margin-right:-30px;margin-top:2.5rem;width:calc(100% + 60px);--tw-bg-opacity:1;background-color:rgb(0 0 0/var(--tw-bg-opacity,1));font-size:1.125rem;font-weight:700;padding:.25rem 0;text-align:center}.sidebar__sale_banner_container .sidebar__sale_banner .banner_text{display:inline-block;margin:0 35px}.sidebar__sale_banner_container{margin-bottom:-25px;margin-right:-24px;margin-top:-25px;overflow:hidden;padding-bottom:10px;width:calc(100% + 48px)}