.wp-block-themeisle-blocks-lottie .components-placeholder__fieldset .components-button{margin-bottom:0}.wp-block[data-align=center] lottie-player{display:block;margin:0 auto}.otter-lottie-background-control fieldset>.components-v-stack>:nth-child(2){margin-top:0}/*# sourceMappingURL=editor.css.map */
