/* unquotable */
input[type = "button"   ], span[ lang |= "en-"], div[ class ~=    '-hey']  {
    color: white;
}
input[
type
=
"-_2test"
],
input[ TYPE $= '_2tEst_'],
a[alt],span[lang  ^= "PT" ],
a[href  *="example2-test-"] {
    color: white
}
a[aria-hidden="false"], [data-toggle="buttons"] {
    color:blue
}

/* non unquotable */
input[ type = "" ],
input[type="-"], input[type="--test"],
input[type="-2test"],
input[type="2test"],
a[href ^= "http:"],
a[href   $='#'],
img[src^="http://"] {
    color: black;
}
a[href*='a%a'],
a[href   *='b/b'],
a[href*="asd$sdd!"] {
    color: black
}
