<?php
/**
 * Author Box
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Author Box', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'featured' ),
	'content'    => '<!-- wp:themeisle-blocks/patterns-upsell /--><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-07f9e39b","columns":1,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"64px","right":"24px","bottom":"64px","left":"24px"},"paddingTablet":{"top":"64px","right":"24px","bottom":"64px","left":"24px"},"paddingMobile":{"top":"40px","bottom":"40px"},"margin":{"top":"0px","bottom":"0px"},"columnsWidth":1140,"horizontalAlign":"center","verticalAlign":"center","align":"full","className":"ticss-c00aadba","hasCustomCSS":true,"customCSS":""} --><div id="wp-block-themeisle-blocks-advanced-columns-07f9e39b" class="wp-block-themeisle-blocks-advanced-columns alignfull has-1-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-center ticss-c00aadba"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-9bce96d7","padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"paddingMobile":{"top":"0px","right":"0px","bottom":"0px","left":"0px"},"margin":{"top":"0px","right":"12px","bottom":"0px","left":"12px"},"marginMobile":{"right":"0px","bottom":"24px","left":"0px"},"columnWidth":"100"} --><div id="wp-block-themeisle-blocks-advanced-column-9bce96d7" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:image {"align":"center","id":260,"width":180,"height":181,"sizeSlug":"full","linkDestination":"none","className":"is-style-rounded"} --><figure class="wp-block-image aligncenter size-full is-resized is-style-rounded"><img src="https://api.themeisle.com/sites/images/cb:otter/q:auto/wp-content/uploads/sites/664/2022/09/Screenshot-2022-09-12-at-15.15.51.png" alt="" class="wp-image-260" width="180" height="181"/></figure><!-- /wp:image --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-63134771","tag":"p","align":"center","alignTablet":"center","alignMobile":"center","fontSize":12,"fontSizeTablet":12,"fontSizeMobile":12,"textTransform":"uppercase"} --><p id="wp-block-themeisle-blocks-advanced-heading-63134771" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-63134771"><strong>About the Author</strong></p><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-bbda2e30","align":"center","alignTablet":"center","alignMobile":"center"} --><h2 id="wp-block-themeisle-blocks-advanced-heading-bbda2e30" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-bbda2e30">John Peterson</h2><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:paragraph {"align":"center"} --><p class="has-text-align-center">Tousled letterpre tote bag bicycle rights cliche twee hashtag pokpo demos tanero lamina sime voti. Quinoa ramps hashtag yuccie, selfies af wolf. Thundercats brunch gastropub whatever poutine tattooed godard bespoke blog seitan flannel jianbing bitters cloud.. Sed ut perspiciatis unde omnis natus error sit voluptatem accusantium doloremque.</p><!-- /wp:paragraph --><!-- wp:social-links {"align":"center","className":"is-style-default","layout":{"type":"flex","justifyContent":"center"}} --><ul class="wp-block-social-links aligncenter is-style-default"><!-- wp:social-link {"url":"#","service":"twitter"} /--><!-- wp:social-link {"url":"#","service":"linkedin"} /--><!-- wp:social-link {"url":"#","service":"instagram"} /--><!-- wp:social-link {"url":"#","service":"wordpress"} /--></ul><!-- /wp:social-links --></div><!-- /wp:themeisle-blocks/advanced-column --></div></div><!-- /wp:themeisle-blocks/advanced-columns -->',
);
