@CHARSET "UTF-8";

@FONT-FACE {
    FONT-FAMILY: "YOUR FACE";
}

#MY\@SUPPORTS-DIV{
    border: none
}

@SUPPORTS only SCREEN {
    @KEYFRAMES test{ color:blue }
}

@IMPORT "HTTP://DOMAIN.TLD/OTHER.CSS";

@MEDIA PRINT {
    BACKGROUND: NONE;
    BACKGROUND-POSITION: 0 0;
}

@PAGE {
    CONTENT: ATTR(HREF);
    FILTER: BRIGHTNESS(0.4);
    WIDTH: CALC(50% - 10PX);
}

@NAMESPACE XHTML "HTTP://WWW.W3.ORG/1999/XHTML";

/* not pseudos */
.a\:LINK {
    color: blue;
}

/* pseudos */
a:ACTIVE,
a:AFTER,
a:BEFORE,
a:CHECKED,
a:DISABLED,
a:DEFAULT,
a:EMPTY,
a:ENABLED,
a:FIRST-CHILD,
a:FIRST-LETTER,
a:FIRST-LINE,
a:FIRST-OF-TYPE,
a:FOCUS,
a:HOVER,
a:LAST-CHILD,
a:LAST-OF-TYPE,
a:LINK,
a:ONLY-CHILD,
a:ONLY-OF-TYPE,
a:ROOT,
a::SELECTION,
a:TARGET,
a:VISITED,

/* pseudo functions */
a:LANG(FR),
a:NOT([HIDDEN]),
a:NTH-CHILD(2),
a:NTH-LAST-CHILD(2),
a:NTH-LAST-OF-TYPE(2),
a:NTH-OF-TYPE(2) {
    TRANSITION-TIMING-FUNCTION: CUBIC-BEZIER(-1.9, 0.3, -0.2, 2.1);
    BACKGROUND: URL(PROTO://DOMAIN.TLD/PATH),
                REPEATING-LINEAR-GRADIENT(20DEG, GRAY, GREEN, 20PX, WHITE 40PX),
                -ATSC-LINEAR-GRADIENT(LEFT, BLACK, WHITE),
                -KHTML-RADIAL-GRADIENT(CENTER 50DEG, CIRCLE CLOSEST-SIDE, BLACK 0, GREEN 100%),
                -MOZ-RADIAL-GRADIENT(CENTER 45DEG, CIRCLE CLOSEST-SIDE, ORANGE 0%, RED 100%),
                -MS-LINEAR-GRaDiEnT(LEFT, BLUE, BLACK),
                -O-REPEATING-RADIAL-GRADIENT(CENTER, CIRCLE CLOSEST-SIDE, PAPAYAWHIP, RED 50%, GAINSBORO),
                -WAP-LINEAR-GRADIENT(LEFT, BLACK, WHITE),
                -WEBKIT-GRADIENT(LINEAR, LEFT, FROM(WHITE), TO(RGBA(1,2,3,.4)));
}
