#wpcontent {
  padding-left: 0;
}

.error, .notice:not(.themeisle-sale) {
  display: none;
}

.about-loaded .loading-screen {
  display: none;
}
.about-loaded .ti-about-wrap {
  display: block;
}

.loading-screen {
  height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
}

.ti-about-wrap {
  display: none;
  position: relative;
  font-size: 15px;
  max-width: 100%;
}
.ti-about-wrap .main-content {
  padding: 30px 40px;
  width: 100%;
  display: flex;
  box-sizing: border-box;
}
.ti-about-wrap p {
  line-height: 1.5;
  font-size: 16px;
}
.ti-about-wrap h2 {
  margin: 40px 0 0.6em;
  font-size: 2.7em;
  line-height: 1.3;
  font-weight: 300;
  text-align: center;
}
.ti-about-wrap img {
  max-width: 100%;
}
.ti-about-wrap .header {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  background-color: #fff;
}
.ti-about-wrap .header .header-info {
  width: 100%;
  display: flex;
  align-items: center;
  padding: 5px 40px;
}
.ti-about-wrap .header .header-info h1 {
  margin: 0;
  font-weight: 300;
  font-size: 30px;
  line-height: normal;
}
.ti-about-wrap .header .header-info .ti-logo {
  margin-left: auto;
}
.ti-about-wrap .header .header-info img {
  height: 75px;
}
.ti-about-wrap .header ul {
  width: 100%;
}
.ti-about-wrap .ti-about-tablist {
  display: flex;
  padding-left: 40px;
  margin: 0;
  border-bottom: 3px solid #ccc;
  background: #fff;
  top: 32px !important;
  z-index: 1000;
}
.ti-about-wrap .ti-about-tablist li {
  margin-bottom: 0;
}
.ti-about-wrap .ti-about-tablist li:first-child a {
  margin-left: 0;
}
.ti-about-wrap .ti-about-tablist a {
  display: block;
  padding: 10px 0;
  text-decoration: none;
  font-size: 15px;
  border: none;
  margin: 0 12px;
  font-weight: 300;
  color: #555;
  line-height: 1.33333333;
}
.ti-about-wrap .ti-about-tablist a.active {
  border-bottom: 3px solid #01a3e7;
  color: #01a3e7;
  margin-bottom: -3px;
  position: relative;
}
.ti-about-wrap .ti-about-tablist .badge-action-count {
  display: inline-block;
  z-index: 26;
  margin-left: 5px;
  padding: 0 6px;
  border-radius: 10px;
  color: #fff;
  background-color: #d54e21;
  font-size: 9px;
  font-weight: 600;
  line-height: 17px;
  vertical-align: top;
}
.ti-about-wrap .about-sidebar {
  background-color: #fff;
  box-shadow: 0 0 10px -5px rgba(0, 0, 0, 0.5);
  padding: 20px;
  width: 20%;
}
.ti-about-wrap .about-sidebar .about-sidebar-item {
  margin-bottom: 20px;
  padding-bottom: 20px;
}
.ti-about-wrap .about-sidebar h4 {
  margin: 0;
  color: #797979;
  font-weight: 500;
  font-size: 16px;
}
.ti-about-wrap .about-sidebar a {
  text-decoration: none;
  font-weight: 500;
  color: #01a3e7;
}
.ti-about-wrap .about-sidebar a svg {
  vertical-align: bottom;
  fill: #01a3e7;
}
.ti-about-wrap #about-tabs {
  box-shadow: 0 0 10px -5px rgba(0, 0, 0, 0.5);
  background-color: #fff;
  width: 80%;
  margin-right: 20px;
}
.ti-about-wrap #about-tabs .tab-content:not(.active) {
  display: none;
}
.ti-about-wrap #about-tabs > div {
  display: flex;
  flex-wrap: wrap;
  max-width: 100%;
  padding: 20px;
}
.ti-about-wrap #about-tabs > div.columns-2 > .about-col {
  width: calc(50% - 30px);
}
.ti-about-wrap #about-tabs > div.columns-3 > .about-col {
  width: calc(33.3333333% - 30px);
}
.ti-about-wrap .ti-customizer-item i {
  position: relative;
  top: 5px;
}
.ti-about-wrap .about-col {
  padding-bottom: 30px;
  margin-left: 15px;
  margin-right: 15px;
  padding-top: 10px;
}
.ti-about-wrap .about-col i.dashicons {
  color: #666;
  margin-right: 15px;
}
.ti-about-wrap .about-col .external-link svg {
  vertical-align: bottom;
  fill: #2271b1;
}
.ti-about-wrap .action-required span.red {
  color: #a00;
}
.ti-about-wrap .ti-about-page-action-required-box {
  display: block;
  position: relative;
  margin-bottom: 15px;
  padding: 10px 30px;
  border-left: 4px solid #f8800c;
  background: #fff;
  box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.1);
  width: 100%;
}
.ti-about-wrap .action-required .ti-about-page-action-required-box:last-of-type {
  margin-bottom: 0;
}
.ti-about-wrap .ti-about-page-action-required-box h3 {
  margin: 0 0 30px;
}
.ti-about-wrap .ti-about-page-action-required-box h4 {
  display: block;
  margin-top: 0;
  margin-bottom: 0;
}
.ti-about-wrap .ti-about-page-action-required-box p {
  display: block;
  width: 100%;
  max-width: 100%;
  margin-top: 0;
}
.ti-about-wrap .ti-about-page-dismiss-required-action {
  position: absolute;
  top: 10px;
  right: 10px;
  border-radius: 50%;
  color: #d54e21;
  text-decoration: none;
  cursor: pointer;
}
.ti-about-wrap .ti-about-page-required-action-button {
  position: absolute;
  top: 10px;
  right: 10px;
  border-radius: 50%;
  color: #b4b9be;
  text-decoration: none;
  cursor: pointer;
}
.ti-about-wrap .ti-about-page-required-action-button:hover:before {
  color: #c00;
}
.ti-about-wrap #demo-import {
  margin: 0 auto;
}
.ti-about-wrap .recommended-plugins {
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
}
.ti-about-wrap .recommended-plugins .plugin-banner {
  border-bottom: 1px solid #ccc;
  width: 100%;
}
.ti-about-wrap .recommended-plugins .plugin_box {
  border: 1px solid #ccc;
  margin-bottom: 20px;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  width: 49%;
  position: relative;
}
.ti-about-wrap .recommended-plugins .external-link {
  vertical-align: middle;
  padding: 10px 0;
  display: block;
}
.ti-about-wrap .recommended-plugins .external-link svg {
  vertical-align: bottom;
  fill: #2271b1;
}
.ti-about-wrap .recommended-plugins .premium-label {
  position: absolute;
  top: 0;
  right: 0;
  padding: 10px 20px;
  background: #01a3e7;
  color: #fff;
  font-weight: 700;
  text-transform: uppercase;
}
.ti-about-wrap .recommended-plugins .title-action-wrapper {
  padding: 15px 20px 5px 20px;
}
.ti-about-wrap .recommended-plugins .plugin-name {
  font-size: 18px;
  display: block;
  white-space: nowrap;
  text-overflow: ellipsis;
  margin-bottom: 10px;
  overflow: hidden;
  line-height: normal;
}
.ti-about-wrap .recommended-plugins .version-wrapper {
  text-align: right;
  font-size: 13px;
  color: #aaa;
  margin-left: auto;
  padding-top: 5px;
}
.ti-about-wrap .recommended-plugins .plugin-desc {
  display: block;
  margin-bottom: 10px;
  font-size: 13px;
  color: #777;
  line-height: 1.6;
}
.ti-about-wrap .recommended-plugins .button-wrap > div {
  padding: 0;
  margin: 0;
}
.ti-about-wrap .plugin-box-footer {
  display: flex;
  justify-content: space-around;
  vertical-align: middle;
  align-items: center;
  padding: 0px 20px 5px;
  border-top: 1px solid #ccc;
  flex: 1;
  margin-top: auto;
}
.ti-about-wrap #free_pro {
  padding: 0 !important;
}
.ti-about-wrap #free_pro .free-pro-table {
  width: 100%;
  border-spacing: 0;
}
.ti-about-wrap #free_pro .free-pro-table thead {
  background-color: #fafafa;
}
.ti-about-wrap #free_pro .free-pro-table th {
  border-bottom: 1px solid #eaeaea;
  padding: 20px 0;
  font-weight: 600;
  text-transform: uppercase;
  text-align: center;
}
.ti-about-wrap #free_pro .free-pro-table tr:nth-child(even) {
  background-color: #fafafa;
}
.ti-about-wrap #free_pro .free-pro-table td {
  border-bottom: 1px solid #eaeaea;
  padding: 25px 20px 20px;
}
.ti-about-wrap #free_pro .free-pro-table h3 {
  font-weight: 400;
  color: #000;
  margin-top: 0;
  font-size: 21px;
}
.ti-about-wrap #free_pro .free-pro-table p {
  margin: 0;
  color: #454545;
  font-weight: 300;
  line-height: 1.6;
}
.ti-about-wrap #free_pro .free-pro-table .only-lite,
.ti-about-wrap #free_pro .free-pro-table .only-pro {
  width: 15%;
  text-align: center;
}
.ti-about-wrap #free_pro .free-pro-table .only-lite .dashicons-before:before {
  color: #8fc622;
}
.ti-about-wrap #free_pro .free-pro-table .only-pro .dashicons-before:before {
  color: #f2433f;
}
.ti-about-wrap #free_pro .free-pro-table .only-lite .dashicons-before:before,
.ti-about-wrap #free_pro .free-pro-table .only-pro .dashicons-before:before {
  width: 35px;
  height: 35px;
  font-size: 35px;
}
.ti-about-wrap #free_pro .ti-about-page-text-right {
  text-align: right;
}
.ti-about-wrap #free_pro .ti-about-page-text-center {
  text-align: center;
}
.ti-about-wrap #free_pro .free_vs_pro_banner {
  padding: 20px;
  background: #fff;
  width: auto;
}
.ti-about-wrap .featured-section.changelog {
  width: 100%;
}
.ti-about-wrap .featured-section.changelog .release-wrap {
  box-shadow: inset 0 0 20px -11px rgba(0, 0, 0, 0.25);
  padding: 20px;
  border: 1px solid #cecece;
  border-radius: 3px;
}
.ti-about-wrap .featured-section.changelog .release-wrap:not(:last-child) {
  margin-bottom: 20px;
}
.ti-about-wrap .featured-section.changelog h3 {
  font-size: 18px;
  color: #fff;
  background: #01a3e7;
  border: 1px solid #0081e7;
  width: auto;
  display: inline-block;
  margin: 0;
  padding: 5px 10px;
  border-radius: 3px;
}
.ti-about-wrap .featured-section.changelog ul {
  list-style: disc;
  padding-left: 15px;
  margin-bottom: 0;
}
.ti-about-wrap .featured-section.changelog li {
  line-height: 1.6;
  font-size: 14px;
}
.ti-about-wrap .featured-section.changelog li:last-child {
  margin-bottom: 0;
}
@media (max-width: 1200px) {
  .ti-about-wrap .header .header-info {
    padding: 10px 15px 5px;
  }
  .ti-about-wrap .header .header-info h1 {
    font-size: 24px;
  }
  .ti-about-wrap .header .header-info img {
    height: 65px;
  }
  .ti-about-wrap .ti-about-tablist {
    padding-left: 15px;
  }
  .ti-about-wrap .ti-about-tablist a {
    margin: 0 8px;
  }
  .ti-about-wrap .main-content {
    flex-direction: column;
    padding: 15px;
  }
  .ti-about-wrap #about-tabs, .ti-about-wrap .about-sidebar {
    width: 100%;
    margin-bottom: 20px;
    margin-right: 0;
    box-sizing: border-box;
  }
  .ti-about-wrap .about-sidebar-item:not(:last-child) {
    border-bottom: 1px solid #ccc;
  }
  .ti-about-wrap .about-sidebar-item:last-child {
    margin-bottom: 0;
    padding-bottom: 0;
  }
}

@media screen and (max-width: 782px) {
  .auto-fold #wpcontent {
    padding-left: 0;
  }
  .ti-about-wrap .ti-about-tablist {
    padding: 0;
    flex-wrap: wrap;
    z-index: unset;
    border-top: 1px solid #ccc;
    border-bottom: none;
  }
  .ti-about-wrap .ti-about-tablist li {
    width: 50%;
    text-align: center;
    border-bottom: 3px solid #ccc;
  }
  .ti-about-wrap .ti-about-tablist li a {
    margin: 0;
  }
  .ti-about-wrap #about-tabs .columns-2 > .about-col, .ti-about-wrap #about-tabs .columns-3 > .about-col {
    width: 100%;
  }
}
div.ti-about-banner .themeisle-sale {
  margin: 0 40px;
  margin-top: 10px;
}
div.ti-about-banner .themeisle-sale-content p {
  font-size: small;
}