.a {
    filter: progid:DXImageTransform.Microsoft.Matrix(M11=0.9914448613738104, M12=-0.13052619222005157, M21=0.13052619222005157, M22=0.9914448613738104, sizingMethod='auto expand');
}
.b {
    display: none;
    filter:
            progid:DXImageTransform.Microsoft.Matrix(M11=0.9914448613738104, M12=-0.13052619222005157, M21=0.13052619222005157, M22=0.9914448613738104, sizingMethod='auto expand');
    vertical-align: bottom;
}

.shadow {
    -ms-filter: "progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=0, Color='#DDDDDD')progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=90, Color='#DDDDDD')progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=180, Color='#DDDDDD')progid:DXImageTransform.Microsoft.Shadow(Strength=5, Direction=270, Color='#DDDDDD')";
}

/*  example from https://developer.mozilla.org/en/CSS/opacity */
pre {                               /* make the box translucent (80% opaque) */
    border: solid red;
    opacity: 0.8;                    /* Firefox, Safari(WebKit), Opera */
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)"; /* IE 8 */
    filter: PROGID:DXImageTransform.Microsoft.Alpha(Opacity=80);       /* IE 4-7 */
    zoom: 1;       /* set "zoom", "width" or "height" to trigger "hasLayout" in IE 7 and lower */
}

/** and again */
code {
    -ms-filter: "PROGID:DXImageTransform.Microsoft.Alpha(Opacity=80)"; /* IE 8 */
    filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=80);       /* IE 4-7 */
}