.obfx-custom-fonts-file-wrap.form-field{
    position: relative;
    margin: 1.5em 0;
}
.obfx-custom-fonts-upload.button {
    float: right;
    margin-right: 5%;
    margin-top: 2px;
}

.obfx-custom-font-select-field {
    width: 95%;
}
