*:before,*:after{color:red}.test:before{margin:3px}p:first-letter ,p:first-line {foo:1}::selection{width:0}p:first-letter {buh:hum}p:first-line {baa:1}p:first-line ,a,p:first-letter ,b{color:red}:before,p :after{margin:0}.foo :after{color:red}