/*! test */
/*! $LastChangedRevision: 81 $ $LastChangedDate: 2009-05-27 17:41:02 +0100 (Wed, 27 May 2009) $ */
/*!
$Header: /temp/dirname/filename.css 3 2/02/08 3:37p JSmith $
*/
/*! special */
/*! special */
a{color:blue;width:5px;height:5px;margin:0}
/*!************88****
 Preserving comments
    as they are
 ********************
 Keep the initial !
 *******************/
#yo{ma:"ma"}
/*!
I said
pre-
serve! */
a{color:red}
/*! imp*/
b{test:foo}
/*! imp */
html>/**/body p{color:blue;*width:auto;height:2%}a{a:1}
/*!"preserve" me*/
b{content:"/**/"}c{c:3}
/*! imp */
/* unclosed comment at EOF issue