@charset "UTF-8";@import "HTTP://DOMAIN.TLD/OTHER.CSS";@namespace XHTML "HTTP://WWW.W3.ORG/1999/XHTML";@font-face{font-family:"YOUR FACE"}#MY\@SUPPORTS-DIV{border:none}@supports only screen{@keyframes test{color:blue}}@media print{background:0 0;background-position:0 0}@page{content:attr(HREF);filter:brightness(.4);width:calc(50% - 10PX)}.a\:LINK{color:blue}a:active,a:after,a:before,a:checked,a:disabled,a:default,a:empty,a:enabled,a:first-child,a:first-letter ,a:first-line ,a:first-of-type,a:focus,a:hover,a:last-child,a:last-of-type,a:link,a:only-child,a:only-of-type,a:root,a::selection,a:target,a:visited,a:lang(FR),a:not([HIDDEN]),a:nth-child(2),a:nth-last-child(2),a:nth-last-of-type(2),a:nth-of-type(2){transition-timing-function:cubic-bezier(-1.9,.3,-.2,2.1);background:url(PROTO://DOMAIN.TLD/PATH),repeating-linear-gradient(20DEG,GRAY,GREEN,20PX,#fff 40PX),-atsc-linear-gradient(LEFT,#000,#fff),-khtml-radial-gradient(CENTER 50DEG,CIRCLE CLOSEST-SIDE,#000 0,GREEN 100%),-moz-radial-gradient(CENTER 45DEG,CIRCLE CLOSEST-SIDE,ORANGE 0%,RED 100%),-ms-linear-gradient(LEFT,BLUE,#000),-o-repeating-radial-gradient(CENTER,CIRCLE CLOSEST-SIDE,#ffefd5,RED 50%,#dcdcdc),-wap-linear-gradient(LEFT,#000,#fff),-webkit-gradient(LINEAR,LEFT,from(#fff),to(rgba(1,2,3,.4)))}