.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder){display:flex;flex-direction:column;min-width:400px;border-radius:6px;justify-content:center}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) .o-stripe-checkout{display:flex;padding:10px}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) .o-stripe-checkout img{border-radius:4px;margin:10px;width:56px;height:56px;border:0}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) .o-stripe-checkout .o-stripe-checkout-description{display:flex;flex-direction:column;justify-content:center}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) .o-stripe-checkout .o-stripe-checkout-description h3{font-style:normal;font-weight:500;font-size:14px;line-height:20px;letter-spacing:-0.154px;margin:0;padding-top:0}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) .o-stripe-checkout .o-stripe-checkout-description h5{opacity:.5;margin-top:0;padding-top:0;font-style:normal;font-weight:500;font-size:14px;line-height:20px;letter-spacing:-0.154px;margin:0}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) a:not(.wp-block-button__link){background:#ed6f57;border-radius:0 0 4px 4px;color:#fff;border:0;font-weight:600;text-align:center;cursor:pointer;transition:all .2s ease;padding:10px;text-decoration:none;box-shadow:0px 4px 5.5px 0px rgba(0,0,0,.07)}.wp-block-themeisle-blocks-stripe-checkout:not(.is-placeholder) a:not(.wp-block-button__link):hover{opacity:.8}/*# sourceMappingURL=style.css.map */
