.yst-root button.yst-replacevar__use-ai-button{align-items:center;background:linear-gradient(-97.38deg,#faf3f7,#eef2ff);border-image-source:linear-gradient(97.38deg,#cd82ab,#a5b4fc);border-radius:3px;box-shadow:0 1px 0 0 #ccccccb3;color:#303030;cursor:pointer;display:flex;font-size:.8125rem;height:2rem;padding-inline-end:.625rem;padding-inline-start:.5rem;transition:var(--yoast-transition-default)}.yst-root button.yst-replacevar__use-ai-button:disabled{cursor:default}.yst-root button.yst-replacevar__use-ai-button:hover{background:linear-gradient(-96.67deg,#f3e5ed 1.02%,#e0e7ff)}.yst-root button.yst-replacevar__use-ai-button svg{margin-inline-end:.375rem;margin-inline-start:0}.yst-root .yst-logo-icon{background-color:var(--yoast-color-primary);display:inline-block;mask-image:var(--yoast-svg-icon-yoast);-webkit-mask-image:var(--yoast-svg-icon-yoast);mask-size:100% 100%;-webkit-mask-size:100% 100%}.yst-root .yst-ai-mode .yst-radio-group__options{flex-direction:row;gap:1.5rem}.yst-root .yst-length-progress-bar.yst-score-good .yst-progress-bar__progress{background-color:#7ad03a}.yst-root .yst-length-progress-bar.yst-score-ok .yst-progress-bar__progress{background-color:#ee7c1b}.yst-root .yst-length-progress-bar.yst-score-bad .yst-progress-bar__progress{background-color:#dc3232}.yst-root .yst-suggestions-radio-group .yst-radio-group__options{gap:0}.yst-root .yst-suggestions-radio-group .yst-radio-group__options>:not([hidden])~:not([hidden]){--tw-space-y-reverse:0;margin-bottom:calc(-1px*var(--tw-space-y-reverse));margin-top:calc(-1px*(1 - var(--tw-space-y-reverse)))}.yst-root .yst-introduction-modal .yst-modal__close-button{background-color:initial;--tw-text-opacity:1;color:rgb(107 114 128/var(--tw-text-opacity,1))}.yst-root .yst-introduction-modal .yst-modal__close-button:focus{outline:2px solid #0000;outline-offset:2px;--tw-ring-offset-width:0px}.yst-root .yst-ai-modal .yst-modal__panel{overflow:visible}.yst-root .yst-revoke-button .yst-animate-spin{--tw-text-opacity:1;color:rgb(252 165 165/var(--tw-text-opacity,1))}.yst-root #facebookPreview,.yst-root #twitterPreview,.yst-root #yoast-snippet-preview-container{margin-right:auto;margin-left:auto;--tw-bg-opacity:1;background-color:rgb(255 255 255/var(--tw-bg-opacity,1))}.yst-root #yoast-snippet-preview-container{border-bottom:1px hidden #fff;border-radius:8px;box-shadow:0 1px 6px #20212447}.yst-root .yoast-snippet-preview-section{padding:.5rem}.yst-root .yoast-snippet-preview-container__wrapper{background-color:initial}.yst-root .desktop #yoast-snippet-preview-container{padding:12px 16px}.yst-root .desktop.yst-user-agent__mobile .yoast-snippet-preview-section{padding:0}.yst-root .desktop.yst-user-agent__mobile .yoast-snippet-preview-container__wrapper{position:relative}.yst-root .desktop.yst-user-agent__mobile #yoast-snippet-preview-container{--yst-padding-bottom:12px}.yst-root .desktop.yst-user-agent__mobile #yoast-snippet-preview-container:has(+div){--yst-padding-bottom:calc(2rem + 22px)}.yst-root .desktop.yst-user-agent__mobile #yoast-snippet-preview-container{background-color:initial;border-bottom:none;border-radius:0;box-shadow:none;display:grid;padding-bottom:var(--yst-padding-bottom);padding-right:.5rem;padding-left:.5rem;padding-top:.5rem}.yst-root .desktop.yst-user-agent__mobile #yoast-snippet-preview-container>div:first-child{margin-right:auto;margin-left:auto;--tw-bg-opacity:1;background-color:rgb(255 255 255/var(--tw-bg-opacity,1));border-bottom:1px hidden #fff;border-radius:8px;box-shadow:0 1px 6px #20212447;padding:12px 16px;width:inherit}.yst-root .desktop.yst-user-agent__mobile #yoast-snippet-preview-container+div{align-items:center;bottom:0;display:flex;height:calc(2rem + 22px);justify-content:center;right:.5rem;margin:0;pointer-events:none;position:absolute;left:.5rem}.yst-root .yst-border-gradient{border-image:linear-gradient(to bottom right,#cd82ab,#a5b4fc) 1;position:relative;z-index:0}.yst-root .yst-border-gradient:before{background:linear-gradient(to bottom left,#cd82ab,#a5b4fc);border-radius:inherit;bottom:0;content:"";right:0;mask:linear-gradient(#fff,#fff) content-box,linear-gradient(#fff,#fff) border-box;mask-composite:exclude;padding:1px;position:absolute;left:0;top:0;z-index:-1}.yst-root svg.yst-ai-counter-badge__sparkles-icon path{stroke-width:1.3!important}.yst-root .yst-ai-counter-badge__skeleton{border-radius:9999px!important}