:fullscreen .optml-player-container,:fullscreen .optml-player-container video{max-width:100%;max-height:100%}optimole-video-player{--scrubber-size: 12px;aspect-ratio:var(--om-aspect-ratio, auto);overflow:hidden;position:relative;display:block;background-color:#000;width:100%}optimole-video-player .optml-vp-hide{display:none !important}optimole-video-player .optml-vp-opacity-0{opacity:0 !important}optimole-video-player .optml-vp-sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0, 0, 0, 0);white-space:nowrap;border-width:0}optimole-video-player .optml-player-container{height:100%}optimole-video-player .optml-spinner{display:flex;align-items:center;justify-content:center;position:absolute;width:100%;top:0;bottom:0;z-index:0}optimole-video-player .optml-spinner .optml-ic{width:20px;height:20px;--optml-ctrl-ico-col: var(--om-primary-color);animation:optmlSpin 1.5s linear infinite}optimole-video-player .optml-video-lg-play{position:absolute;top:0;left:0;right:0;bottom:0;z-index:10;padding:0;cursor:pointer}optimole-video-player .optml-video-lg-play svg{--optml-ctrl-ico-col: #fff;background-color:rgba(0,0,0,.7);padding:10px;border-radius:100%;opacity:1;transition:scale .3s ease;box-sizing:content-box}optimole-video-player .optml-video-lg-play:hover svg{scale:1.1}optimole-video-player .optml-controls{box-sizing:border-box;color:#fff;display:flex;align-items:center;justify-content:space-between;background:rgba(0,0,0,.9);padding:5px 7px;bottom:0;opacity:0;transition:opacity .3s ease;position:absolute;width:100%;z-index:30}optimole-video-player:hover .optml-controls{opacity:1}optimole-video-player button{background:rgba(0,0,0,0) !important;border:none !important;cursor:pointer !important;display:flex !important;align-items:center !important;justify-content:center !important;transition:color .3s ease !important;padding:0 5px !important}optimole-video-player button:hover{--optml-ctrl-ico-col: var(--om-primary-color)}optimole-video-player button:focus{outline:none}optimole-video-player button svg{width:20px;height:20px}optimole-video-player video{display:block;width:100%;height:100%;object-fit:contain;flex-grow:1}optimole-video-player .optml-progress-container{flex-grow:1;height:8px;background:rgba(255,255,255,.2);border-radius:4px;margin:0 10px;position:relative;cursor:pointer}optimole-video-player .optml-progress-container .optml-progress-bar{height:100%;background:var(--om-primary-color);border-radius:4px;width:0%}optimole-video-player .optml-progress-container .optml-scrubber{position:absolute;width:var(--scrubber-size);height:var(--scrubber-size);background-color:var(--om-primary-color);border-radius:50%;top:50%;transform:translate(-50%, -50%);z-index:2;left:0%;cursor:pointer}optimole-video-player .optml-progress-container .optml-time-tooltip{position:absolute;background-color:rgba(0,0,0,.7);color:#fff;padding:2px 6px;border-radius:4px;font-size:12px;bottom:25px;transform:translateX(-50%);display:none;pointer-events:none;align-items:center;justify-content:center}optimole-video-player .optml-progress-container:hover .optml-time-tooltip{display:flex}optimole-video-player .optml-time-display{color:#fff;font-size:14px;margin-left:10px;min-width:80px}optimole-video-player .optml-volume-container{display:flex;align-items:center}optimole-video-player .optml-volume-container .optml-volume-slider{width:60px;margin-left:5px;-webkit-appearance:none;height:4px;background:rgba(255,255,255,.2);border-radius:2px}optimole-video-player .optml-volume-container .optml-volume-slider::-webkit-slider-thumb{-webkit-appearance:none;width:12px;height:12px;border-radius:50%;background:var(--om-primary-color);cursor:pointer}optimole-video-player .optml-volume-container .optml-volume-slider:focus{outline:none}@keyframes optmlSpin{0%{transform:translate(-50%, -50%) rotate(0deg)}100%{transform:translate(-50%, -50%) rotate(360deg)}}
