a{margin:4px;padding:4px;border-radius:4px;border-width:4px !important;border-style:dashed;border-style:dashed}b{margin:4px -.2em;border-width:2px 0;border-style:dashed solid}c{border-radius:1em 2px 3% !important;border-style:dashed dotted solid}d{margin:4px 4px 4px 4pc;padding:23rem 1.2em 23em 1.2rem;border-width:calc(1px + 2px) 3.44em calc(1px + 2px) 3.44em}e{border-color:#fff;border-color:#fff;border-color:#fff;border-color:#fff #000;border-color:#fff red #000}