.o-live-search .wp-block-search__inside-wrapper{position:relative}.o-live-search .container-wrap{border:1px solid rgba(49,50,51,.12);margin-bottom:10px;margin-top:10px;overflow-y:auto;position:absolute;z-index:30}.o-live-search .search-results{display:grid;grid-auto-rows:1fr;padding:15px 0;width:100%}.o-live-search .search-results__row{display:flex;min-width:0}.o-live-search .search-results__row>*{color:inherit}.o-live-search .search-results__row a,.o-live-search .search-results__row.no-results{display:flex;padding:8px 12px;text-decoration:none}.o-live-search .search-results__row a{gap:12px;width:100%}.o-live-search .search-results__row-left{align-items:center;display:flex}.o-live-search .search-results__row-left svg{height:45px;margin:1px;opacity:.24;width:45px}.o-live-search .search-results__row-left svg path{fill:currentColor}.o-live-search .search-results__row-left img{height:45px;margin:1px;-o-object-fit:cover;object-fit:cover;width:45px}.o-live-search .search-results__row-right{display:flex;flex-direction:column;justify-content:center;line-height:1.7;overflow:hidden;text-align:right}.o-live-search .search-results__row-right .meta{margin-left:auto;opacity:.65}.o-live-search .search-results__row-right .post-title{margin:0;min-width:0;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.o-live-search .spinner-container{text-align:center}.o-live-search .spinner{color:#007cba;display:flex;height:16px;margin:5px auto;overflow:visible;position:relative;width:16px}.o-live-search .spinner .main-circle{fill:transparent;stroke-width:1.5px;stroke:#ddd}.o-live-search .spinner .moving-circle{fill:transparent;stroke-width:1.5px;stroke:currentcolor;stroke-linecap:round;animation:o-animation-rotate 1.4s linear 0s infinite normal both running;transform-origin:50% 50%}@keyframes o-animation-rotate{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}
