@keyframes elementor-animation-push {
	50% {
		transform: scale(0.8);
	}
	100% {
		transform: scale(1);
	}
}
.elementor-animation-push:active,
.elementor-animation-push:focus,
.elementor-animation-push:hover {
	animation-name: elementor-animation-push;
	animation-duration: 0.3s;
	animation-timing-function: linear;
	animation-iteration-count: 1;
}
