<?php

// File generated from our OpenAPI spec

namespace Stripe;

/**
 * @property string $id Unique identifier for the object.
 * @property string $object String representing the object's type. Objects of the same type share the same value.
 * @property null|string $name The name of the application.
 */
class Application extends ApiResource
{
    const OBJECT_NAME = 'application';
}
