#customize-control-header_video, #customize-control-external_header_video{
    display: none;
}

/**
 * Tab styling
 */
.customizer-tab:not(.customizer-subtab){
    display: table;
    width: calc(100% + 28px);
    margin: -15px 0 0 -12px;
}
.customizer-tab:not(.customizer-subtab) label{
    border-right: 1px solid #ddd;
    display: inherit;
    width: 50%;
    vertical-align: top;
    max-width: 100%;
    text-transform: capitalize;
    background: #fff;
    padding: 10px 0;
    text-decoration: none;
    font-weight: 600;
    transition: all .3s ease;
    color: #333;
}
.customizer-tab:not(.customizer-subtab) label i{
    color: #333;
    margin-right: 4px;
}
.customizer-tab:not(.customizer-subtab) label.ui-state-active{
    box-shadow: inset 0 -3px 0 0 #0085ba;
    color: #0085ba;
    background-color: #fff;
}

.customizer-tab:not(.customizer-subtab) label:last-child{
    border:none;
}

.pro-feature{
    position: relative;
}

.pro-feature img{
    opacity: 0.5;
}
