.wp-block-themeisle-leaflet-blocks-map{--height: 400px;--height-tablet: var( --height );--height-mobile: var( --height-tablet );margin:20px 0;height:var(--height)}@media(min-width: 600px)and (max-width: 960px){.wp-block-themeisle-leaflet-blocks-map{height:var(--height-tablet) !important}}@media(max-width: 600px){.wp-block-themeisle-leaflet-blocks-map{height:var(--height-mobile) !important}}.wp-block-themeisle-leaflet-blocks-map .leaflet-bar a{text-decoration:none !important}.wp-block-themeisle-blocks-leaflet-map-overview h6.wp-block-themeisle-blocks-leaflet-map-overview-title{font-size:14px;margin:10px 0}.wp-block-themeisle-blocks-leaflet-map-overview .wp-block-themeisle-blocks-leaflet-map-overview-content p{font-size:12px;margin-top:0px;margin-bottom:0px}.wp-block-themeisle-blocks-leaflet-map-overview .wp-block-themeisle-blocks-leaflet-map-overview-delete{cursor:pointer;margin-top:8px}/*# sourceMappingURL=style.css.map */
