.otter-animation-welcome-notice{padding-bottom:0;position:relative}.otter-animation-welcome-notice .notice-content{display:flex;gap:20px;width:100%}@media(max-width:1200px){.otter-animation-welcome-notice .notice-content{flex-direction:column-reverse;gap:0;text-align:center}}.otter-animation-welcome-notice .notice-copy{display:flex;flex-direction:column;justify-content:center;padding:30px 0}@media(max-width:1200px){.otter-animation-welcome-notice .notice-copy{align-items:center;padding:20px 0}}.otter-animation-welcome-notice .notice-title{line-height:1.5}.otter-animation-welcome-notice .notice-title span{color:#e57451;font-weight:600}.otter-animation-welcome-notice .actions{align-items:center;display:flex;flex-wrap:wrap;gap:20px;margin-top:40px}@media(max-width:1200px){.otter-animation-welcome-notice .actions{gap:10px;justify-content:center;margin-top:20px}}.otter-animation-welcome-notice .button{align-items:center;display:flex;justify-content:center;justify-items:center}.otter-animation-welcome-notice .dashicons-update{animation:rotation 2s linear infinite;margin-right:5px}.otter-animation-welcome-notice .dashicons-external{margin-left:5px}.otter-animation-welcome-notice p{font-size:15px;line-height:1.6;max-width:700px}.otter-animation-welcome-notice .otter-preview{align-self:flex-end;display:block;flex-shrink:1;max-height:300px;max-width:60%;width:auto}@media(max-width:1200px){.otter-animation-welcome-notice .otter-preview{margin:0 auto;max-width:80%}}.otter-animation-welcome-notice .otter-logo{bottom:30px;max-width:75px;opacity:.75;right:30px}
