#\:white a[black=":white;"]{background-image:url(assets/images/white.png);color:#fff;white-space:normal;color:#f5f5f5;background:#fff;background:border-box #f0f;background:linear-gradient(to left top,#000,pink 60%,#8a2be2);background-color:#000;text-shadow:1px 1px 2px #000;text-shadow:#fff 2px 5px;box-shadow:3px 3px #ff0,-1em 0 .4em #f0f;outline:1px solid #fff;outline-color:#ff0;box:#000 #fff,#ff0;utline-color:#000 #fff,#ff0;border:1px dotted #663399;border-color:#9acd32;border-bottom:3px solid #ffffe0;border-right-color:#f8f8ff}b{color:ivory;color:red}.color{impressed:#fed;again:#abcdef;andagain:#a6c;background-color:#aa66ccc;filter:chroma(color="#FFFFFF");color:#12a}.foo,#AABBCC{background-color:#abc;border-color:#e6a #abcdef #feab2c;filter:chroma(color=#FFFFFF);filter:chroma(color="#AABBCC");filter:chroma(color='#BBDDEE');color:#123}#AABBCC,#ffffff,#f0f0f0,#f00{background-color:#fe1;filter:chroma(color=#FFFFFF);color:#412;foo:#0f1 #abc #abc #123344;border-color:#aa66ccC}.foo #AABBCC{background-color:#fe1;color:#412;border-color:#abc;filter:chroma(color=#FFFFFF)}.bar,#AABBCC{background-color:#fe1;border-color:#0f1 #abcdef;filter:chroma(color=#11FFFFFF);color:#412}.foo,#AABBCC.foobar{background-color:#fe1;border-color:#0f1 #abcdef #abc;color:#412}@media screen{.bar,#AABBCC{background-color:#fe1;color:#412}}a{background:none repeat scroll 0 0 red;alpha:rgba(1,2,3,4);background-image:linear-gradient(to bottom,tan 10%,red 90%);background-image:linear-gradient(to bottom,red 10%,red 90%);background:linear-gradient(to bottom,red,red);color:#e6ccc3;color:red;color:red;test-overflow:#fff}d{alpha:rgba(1,2,3,4);border-color:rgba(1,2,3,4)}*{color:red;color:#03ff03;color:#1c1c24;color:#e4e4f1;color:#212121}