.wp-block-themeisle-blocks-slider{--height: 400px;--height-tablet: var( --height );--height-mobile: var( --height-tablet );--arrows-color: #333;--arrows-background-color: #fff;--pagination-color: rgba(255,255,255,0.5);--pagination-active-color: #fff;--border-color: black;--border-width: 0;--border-radius: 0;--width: auto;width:var(--width);display:grid}.wp-block-themeisle-blocks-slider .glide__track{border:var(--border-width) solid var(--border-color);border-radius:var(--border-radius);overflow:hidden}.wp-block-themeisle-blocks-slider .glide__slides{height:var(--height)}@media(min-width: 600px)and (max-width: 960px){.wp-block-themeisle-blocks-slider .glide__slides{height:var(--height-tablet) !important}}@media(max-width: 600px){.wp-block-themeisle-blocks-slider .glide__slides{height:var(--height-mobile) !important}}.wp-block-themeisle-blocks-slider .wp-block-themeisle-blocks-slider-item-wrapper{position:relative}.wp-block-themeisle-blocks-slider .wp-block-themeisle-blocks-slider-item-wrapper figure{height:100%;margin:0}.wp-block-themeisle-blocks-slider .wp-block-themeisle-blocks-slider-item-wrapper figure img{width:100%;height:100%;object-fit:cover}.wp-block-themeisle-blocks-slider .wp-block-themeisle-blocks-slider-item-wrapper figcaption{position:absolute;bottom:0;margin-bottom:0px;width:100%;max-height:100%;overflow-y:auto;z-index:20;white-space:pre-wrap;overflow:auto;padding:40px 10px 9px;color:#fff;text-align:center;font-size:16px;background:linear-gradient(0deg, rgba(0, 0, 0, 0.7), rgba(0, 0, 0, 0.3) 70%, transparent);cursor:text}.wp-block-themeisle-blocks-slider .glide__arrows .glide__arrow{background:var(--arrows-background-color);border:none;color:var(--arrows-color);padding:12px;opacity:.75}.wp-block-themeisle-blocks-slider .glide__arrows .glide__arrow:hover{opacity:1}.wp-block-themeisle-blocks-slider .glide__arrows .glide__arrow.glide__arrow--right path{transform:translate(100px, 100px) rotate(180deg)}.wp-block-themeisle-blocks-slider .glide__arrows .glide__arrow svg{display:block;fill:var(--arrows-color)}.wp-block-themeisle-blocks-slider .glide__track .glide__bullet{background-color:var(--pagination-color)}.wp-block-themeisle-blocks-slider .glide__track .glide__bullet--active{background-color:var(--pagination-active-color)}.wp-block-themeisle-blocks-slider .amp-carousel-slide .wp-block-themeisle-blocks-slider-item{width:100%;height:100%;-o-object-fit:cover;object-fit:cover}.wp-block-themeisle-blocks-slider .amp-carousel-slide figcaption{position:absolute;bottom:0;width:100%;max-height:100%;overflow-y:auto;z-index:20;white-space:pre-wrap;overflow:auto;padding:40px 10px 9px;color:#fff;text-align:center;font-size:16px;background:linear-gradient(0deg, rgba(0, 0, 0, 0.7), rgba(0, 0, 0, 0.3) 70%, transparent);cursor:text}/*# sourceMappingURL=style.css.map */
