a{background-position:0 0}b{background-position:0 0}c{background-position:0 0}d{background-position:0 50%;background-position:0 0;background-position:0 0;background-position:center top 0;background-position:left 0 bottom 0}