<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Attribute' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/Attribute.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'OptimoleWP\\BgOptimizer\\Lazyload' => $baseDir . '/inc/v2/BgOptimizer/Lazyload.php',
    'OptimoleWP\\Offload\\ImageEditor' => $baseDir . '/inc/v2/Offload/ImageEditor.php',
    'OptimoleWP\\Offload\\Loader' => $baseDir . '/inc/v2/Offload/Loader.php',
    'OptimoleWP\\PageProfiler\\Profile' => $baseDir . '/inc/v2/PageProfiler/Profile.php',
    'OptimoleWP\\PageProfiler\\Storage\\Base' => $baseDir . '/inc/v2/PageProfiler/Storage/Base.php',
    'OptimoleWP\\PageProfiler\\Storage\\ObjectCache' => $baseDir . '/inc/v2/PageProfiler/Storage/ObjectCache.php',
    'OptimoleWP\\PageProfiler\\Storage\\Transients' => $baseDir . '/inc/v2/PageProfiler/Storage/Transients.php',
    'OptimoleWP\\Preload\\Links' => $baseDir . '/inc/v2/Preload/Links.php',
    'Optimole\\Sdk\\Exception\\BadMethodCallException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/BadMethodCallException.php',
    'Optimole\\Sdk\\Exception\\BadResponseException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/BadResponseException.php',
    'Optimole\\Sdk\\Exception\\DashboardApiException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/DashboardApiException.php',
    'Optimole\\Sdk\\Exception\\ExceptionInterface' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/ExceptionInterface.php',
    'Optimole\\Sdk\\Exception\\InvalidArgumentException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/InvalidArgumentException.php',
    'Optimole\\Sdk\\Exception\\InvalidDashboardApiResponseException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/InvalidDashboardApiResponseException.php',
    'Optimole\\Sdk\\Exception\\InvalidUploadApiResponseException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/InvalidUploadApiResponseException.php',
    'Optimole\\Sdk\\Exception\\RuntimeException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/RuntimeException.php',
    'Optimole\\Sdk\\Exception\\UploadApiException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/UploadApiException.php',
    'Optimole\\Sdk\\Exception\\UploadFailedException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/UploadFailedException.php',
    'Optimole\\Sdk\\Exception\\UploadLimitException' => $vendorDir . '/codeinwp/optimole-sdk/src/Exception/UploadLimitException.php',
    'Optimole\\Sdk\\Http\\ClientInterface' => $vendorDir . '/codeinwp/optimole-sdk/src/Http/ClientInterface.php',
    'Optimole\\Sdk\\Http\\GuzzleClient' => $vendorDir . '/codeinwp/optimole-sdk/src/Http/GuzzleClient.php',
    'Optimole\\Sdk\\Http\\WordPressClient' => $vendorDir . '/codeinwp/optimole-sdk/src/Http/WordPressClient.php',
    'Optimole\\Sdk\\Offload\\Manager' => $vendorDir . '/codeinwp/optimole-sdk/src/Offload/Manager.php',
    'Optimole\\Sdk\\Optimole' => $vendorDir . '/codeinwp/optimole-sdk/src/Optimole.php',
    'Optimole\\Sdk\\Resource\\AbstractResource' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/AbstractResource.php',
    'Optimole\\Sdk\\Resource\\Asset' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/Asset.php',
    'Optimole\\Sdk\\Resource\\AssetProperty\\MinifyProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/AssetProperty/MinifyProperty.php',
    'Optimole\\Sdk\\Resource\\AssetProperty\\TypeProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/AssetProperty/TypeProperty.php',
    'Optimole\\Sdk\\Resource\\CacheBusterProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/CacheBusterProperty.php',
    'Optimole\\Sdk\\Resource\\Image' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/Image.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\DprProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/DprProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\EnlargeProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/EnlargeProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\FormatProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/FormatProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\GravityProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/GravityProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\HeightProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/HeightProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\IgnoreAvifProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/IgnoreAvifProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\KeepCopyrightProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/KeepCopyrightProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\QualityProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/QualityProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\ResizeTypeProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/ResizeTypeProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\StripMetadataProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/StripMetadataProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\WatermarkProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/WatermarkProperty.php',
    'Optimole\\Sdk\\Resource\\ImageProperty\\WidthProperty' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/ImageProperty/WidthProperty.php',
    'Optimole\\Sdk\\Resource\\PropertyInterface' => $vendorDir . '/codeinwp/optimole-sdk/src/Resource/PropertyInterface.php',
    'Optimole\\Sdk\\ValueObject\\OffloadUsage' => $vendorDir . '/codeinwp/optimole-sdk/src/ValueObject/OffloadUsage.php',
    'Optimole\\Sdk\\ValueObject\\Position' => $vendorDir . '/codeinwp/optimole-sdk/src/ValueObject/Position.php',
    'PhpToken' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/PhpToken.php',
    'Stringable' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/Stringable.php',
    'Symfony\\Polyfill\\Php80\\Php80' => $vendorDir . '/symfony/polyfill-php80/Php80.php',
    'Symfony\\Polyfill\\Php80\\PhpToken' => $vendorDir . '/symfony/polyfill-php80/PhpToken.php',
    'UnhandledMatchError' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/UnhandledMatchError.php',
    'ValueError' => $vendorDir . '/symfony/polyfill-php80/Resources/stubs/ValueError.php',
    'enshrined\\svgSanitize\\ElementReference\\Resolver' => $vendorDir . '/enshrined/svg-sanitize/src/ElementReference/Resolver.php',
    'enshrined\\svgSanitize\\ElementReference\\Subject' => $vendorDir . '/enshrined/svg-sanitize/src/ElementReference/Subject.php',
    'enshrined\\svgSanitize\\ElementReference\\Usage' => $vendorDir . '/enshrined/svg-sanitize/src/ElementReference/Usage.php',
    'enshrined\\svgSanitize\\Exceptions\\NestingException' => $vendorDir . '/enshrined/svg-sanitize/src/Exceptions/NestingException.php',
    'enshrined\\svgSanitize\\Helper' => $vendorDir . '/enshrined/svg-sanitize/src/Helper.php',
    'enshrined\\svgSanitize\\Sanitizer' => $vendorDir . '/enshrined/svg-sanitize/src/Sanitizer.php',
    'enshrined\\svgSanitize\\data\\AllowedAttributes' => $vendorDir . '/enshrined/svg-sanitize/src/data/AllowedAttributes.php',
    'enshrined\\svgSanitize\\data\\AllowedTags' => $vendorDir . '/enshrined/svg-sanitize/src/data/AllowedTags.php',
    'enshrined\\svgSanitize\\data\\AttributeInterface' => $vendorDir . '/enshrined/svg-sanitize/src/data/AttributeInterface.php',
    'enshrined\\svgSanitize\\data\\TagInterface' => $vendorDir . '/enshrined/svg-sanitize/src/data/TagInterface.php',
    'enshrined\\svgSanitize\\data\\XPath' => $vendorDir . '/enshrined/svg-sanitize/src/data/XPath.php',
);
