<?php
/**
 * Business - Contact
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Business - Contact', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'pages', 'business-pack' ),
	'content'    => '<!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-546fa8db","columns":2,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"80px","bottom":"80px","left":"20px","right":"20px"},"paddingTablet":{"top":"40px","bottom":"40px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px"},"marginTablet":{"top":"0px","bottom":"0px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1170,"horizontalAlign":"center","verticalAlign":"center","backgroundColor":"#f0ede6","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"columnsHTMLTag":"section","align":"full","className":"has-light-bg","hasCustomCSS":true} --><section id="wp-block-themeisle-blocks-advanced-columns-546fa8db" class="wp-block-themeisle-blocks-advanced-columns alignfull has-2-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-center has-light-bg"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-a03592cc","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundColor":"#f0ede6","backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","className":"has-light-bg"} --><div id="wp-block-themeisle-blocks-advanced-column-a03592cc" class="wp-block-themeisle-blocks-advanced-column has-light-bg"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-db071afb","tag":"div","headingColor":"#080808","fontSize":14,"textTransform":"uppercase","marginType":"linked","className":""} --><div id="wp-block-themeisle-blocks-advanced-heading-db071afb" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-db071afb"><strong>Have a Question?</strong></div><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:heading {"textAlign":"left","style":{"color":{"text":"#080808"},"elements":{"link":{"color":{"text":"#080808"}}}}} --><h2 class="wp-block-heading has-text-align-left has-text-color has-link-color" style="color:#080808">Send a direct message</h2><!-- /wp:heading --><!-- wp:paragraph {"align":"left","style":{"color":{"text":"#080808"},"elements":{"link":{"color":{"text":"#080808"}}}}} --><p class="has-text-align-left has-text-color has-link-color" style="color:#080808">Bring to the table win-win survival strategies to ensure proactive domination. At the end of the day, going forward, a new normal that has evolved from generation X is on the runway heading towards a streamlined cloud solution. </p><!-- /wp:paragraph --><!-- wp:heading {"level":3,"style":{"color":{"text":"#080808"},"elements":{"link":{"color":{"text":"#080808"}}}}} --><h3 class="wp-block-heading has-text-color has-link-color" style="color:#080808">Follow on Social</h3><!-- /wp:heading --><!-- wp:paragraph {"align":"left","style":{"color":{"text":"#080808"},"elements":{"link":{"color":{"text":"#080808"}}}}} --><p class="has-text-align-left has-text-color has-link-color" style="color:#080808">User generated content in real-time will have multiple touchpoints for offshoring.</p><!-- /wp:paragraph --><!-- wp:social-links --><ul class="wp-block-social-links"><!-- wp:social-link {"url":"#","service":"facebook"} /--><!-- wp:social-link {"url":"#","service":"twitter"} /--><!-- wp:social-link {"url":"#","service":"instagram"} /--><!-- wp:social-link {"url":"#","service":"youtube"} /--></ul><!-- /wp:social-links --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-5b750788","padding":{"top":"40px","bottom":"40px","left":"40px","right":"40px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundColor":"#ffffff","backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","className":"has-light-bg"} --><div id="wp-block-themeisle-blocks-advanced-column-5b750788" class="wp-block-themeisle-blocks-advanced-column has-light-bg"><!-- wp:themeisle-blocks/form {"id":"wp-block-themeisle-blocks-form-fcc82e44","optionName":"1675009503e227cf028e7b282a731f32510ba3df_fcc82e44","submitLabel":"Send Message","labelColor":"#080808","inputRequiredColor":"#ff0000","inputBorderRadius":{"top":"4px","left":"4px","right":"4px","bottom":"4px"},"inputBorderColor":"#080808","submitBackgroundColor":"#f0a733","submitBackgroundColorHover":"#35a6b1","submitColor":"#080808","submitColorHover":"#ffffff","inputColor":"#080808","inputBackgroundColor":"#ffffff"} --><div id="wp-block-themeisle-blocks-form-fcc82e44" class="wp-block-themeisle-blocks-form" data-option-name="1675009503e227cf028e7b282a731f32510ba3df_fcc82e44"><form class="otter-form__container"><!-- wp:themeisle-blocks/form-input {"id":"wp-block-themeisle-blocks-form-input-06ca67eb","label":"Name","isRequired":true,"labelColor":"#080808","className":"ticss-06ca67eb","hasCustomCSS":true} --><div id="wp-block-themeisle-blocks-form-input-06ca67eb" class="wp-block-themeisle-blocks-form-input ticss-06ca67eb"><label for="wp-block-themeisle-blocks-form-input-06ca67eb-input" class="otter-form-input-label"><span class="otter-form-input-label__label">Name</span><span class="required">*</span></label><input type="text" id="wp-block-themeisle-blocks-form-input-06ca67eb-input" required class="otter-form-input"/></div><!-- /wp:themeisle-blocks/form-input --><!-- wp:themeisle-blocks/form-input {"id":"wp-block-themeisle-blocks-form-input-87be824d","type":"email","label":"Email","isRequired":true,"labelColor":"#080808"} --><div id="wp-block-themeisle-blocks-form-input-87be824d" class="wp-block-themeisle-blocks-form-input"><label for="wp-block-themeisle-blocks-form-input-87be824d-input" class="otter-form-input-label"><span class="otter-form-input-label__label">Email</span><span class="required">*</span></label><input type="email" id="wp-block-themeisle-blocks-form-input-87be824d-input" required class="otter-form-input"/></div><!-- /wp:themeisle-blocks/form-input --><!-- wp:themeisle-blocks/form-textarea {"id":"wp-block-themeisle-blocks-form-textarea-919679a3","label":"Comment or Message"} --><div id="wp-block-themeisle-blocks-form-textarea-919679a3" class="wp-block-themeisle-blocks-form-textarea"><label for="wp-block-themeisle-blocks-form-textarea-919679a3-input" class="otter-form-textarea-label"><span class="otter-form-textarea-label__label">Comment or Message</span></label><textarea id="wp-block-themeisle-blocks-form-textarea-919679a3-input" rows="10" class="otter-form-textarea-input"></textarea></div><!-- /wp:themeisle-blocks/form-textarea --><!-- wp:themeisle-blocks/form-nonce {"formId":"wp-block-themeisle-blocks-form-fcc82e44"} /--><div class="wp-block-button"><button class="wp-block-button__link" type="submit">Send Message</button></div></form></div><!-- /wp:themeisle-blocks/form --></div><!-- /wp:themeisle-blocks/advanced-column --></div></section><!-- /wp:themeisle-blocks/advanced-columns --><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-990a718e","columns":2,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"80px","bottom":"80px","left":"20px","right":"20px"},"paddingTablet":{"top":"40px","bottom":"40px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px"},"marginTablet":{"top":"0px","bottom":"0px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1170,"horizontalAlign":"center","verticalAlign":"center","backgroundColor":"#0e1937","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"dividerTopWidth":100,"dividerTopWidthTablet":100,"dividerTopWidthMobile":100,"dividerTopHeight":100,"dividerTopHeightTablet":100,"dividerTopHeightMobile":100,"dividerBottomWidth":100,"dividerBottomWidthTablet":100,"dividerBottomWidthMobile":100,"dividerBottomHeight":100,"dividerBottomHeightTablet":100,"dividerBottomHeightMobile":100,"columnsHTMLTag":"section","align":"full","className":"has-dark-bg","hasCustomCSS":true} --><section id="wp-block-themeisle-blocks-advanced-columns-990a718e" class="wp-block-themeisle-blocks-advanced-columns alignfull has-2-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-center has-dark-bg"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-73e5b683","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","className":""} --><div id="wp-block-themeisle-blocks-advanced-column-73e5b683" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:image {"id":109,"sizeSlug":"large"} --><figure class="wp-block-image size-large"><img src="https://api.themeisle.com/templates-data/2023/02/ebf0233ced7259cf0838b7ba6d3aee07vd50gkmjeu9clljkfjl1/images/Screenshot-2020-06-15-at-12.48.12.png" alt="" class="wp-image-109"/></figure><!-- /wp:image --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-d2ab60f9","padding":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"marginTablet":{"top":null,"bottom":null,"left":null,"right":null},"marginMobile":{"top":null,"bottom":null,"left":null,"right":null},"backgroundColor":"#0e1937","backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"columnWidth":"50","className":"has-dark-bg"} --><div id="wp-block-themeisle-blocks-advanced-column-d2ab60f9" class="wp-block-themeisle-blocks-advanced-column has-dark-bg"><!-- wp:heading {"textAlign":"left","style":{"color":{"text":"#ffffff"}}} --><h2 class="wp-block-heading has-text-align-left has-text-color" style="color:#ffffff">Visit our Office</h2><!-- /wp:heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-60814737","tag":"div","headingColor":"#ffffff","fontSize":14,"textTransform":"uppercase","marginType":"linked","className":""} --><div id="wp-block-themeisle-blocks-advanced-heading-60814737" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-60814737"><strong>Our Address</strong></div><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:paragraph {"style":{"color":{"text":"#ffffff"}}} --><p class="has-text-color" style="color:#ffffff">4814 Hewes Avenue<br>Salisbury, Maryland<br>21875</p><!-- /wp:paragraph --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-13fcfd84","tag":"div","headingColor":"#ffffff","fontSize":14,"textTransform":"uppercase","marginType":"linked","className":""} --><div id="wp-block-themeisle-blocks-advanced-heading-13fcfd84" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-13fcfd84"><strong>Call Us</strong></div><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:paragraph {"style":{"color":{"text":"#ffffff"}}} --><p class="has-text-color" style="color:#ffffff">Phone number: 443-669-4259</p><!-- /wp:paragraph --></div><!-- /wp:themeisle-blocks/advanced-column --></div></section><!-- /wp:themeisle-blocks/advanced-columns -->', // phpcs:ignore WordPressVIPMinimum.Security.Mustache.OutputNotation
);
