<?php return array(
    'root' => array(
        'name' => 'elementor/elementor',
        'pretty_version' => '3.32.x-dev',
        'version' => '3.32.9999999.9999999-dev',
        'reference' => '4d081530c8d114c918513495eeab3a1b4baa87ec',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'elementor/elementor' => array(
            'pretty_version' => '3.32.x-dev',
            'version' => '3.32.9999999.9999999-dev',
            'reference' => '4d081530c8d114c918513495eeab3a1b4baa87ec',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
