<?php

// autoload_files.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'a4a119a56e50fbb293281d9a48007e0e' => $vendorDir . '/symfony/polyfill-php80/bootstrap.php',
    '9fef4034ed73e26a337d9856ea126f7f' => $vendorDir . '/codeinwp/themeisle-sdk/load.php',
);
