<?php
/**
 * Border Pricing Table
 *
 * @package ThemeIsle
 */

return array(
	'title'      => __( 'Border Pricing Table', 'otter-blocks' ),
	'categories' => array( 'otter-blocks', 'columns', 'pricing' ),
	'content'    => '<!-- wp:themeisle-blocks/patterns-upsell /--><!-- wp:themeisle-blocks/advanced-columns {"id":"wp-block-themeisle-blocks-advanced-columns-e0e1ab2e","columns":3,"layout":"equal","layoutMobile":"collapsedRows","padding":{"top":"64px","bottom":"64px","left":"24px","right":"24px"},"paddingTablet":{"top":"40px","bottom":"40px"},"paddingMobile":{"left":"0px","right":"0px"},"margin":{"top":"0px","bottom":"0px"},"marginMobile":{"top":"0px","bottom":"0px"},"columnsWidth":1140,"horizontalAlign":"center","verticalAlign":"flex-start","backgroundPosition":{"x":"0.00","y":"0.00"},"backgroundOverlayPosition":{"x":"0.00","y":"0.00"},"columnsHTMLTag":"section","align":"full","className":"ticss-7b5eb70a","hasCustomCSS":true} --><section id="wp-block-themeisle-blocks-advanced-columns-e0e1ab2e" class="wp-block-themeisle-blocks-advanced-columns alignfull has-3-columns has-desktop-equal-layout has-tablet-equal-layout has-mobile-collapsedRows-layout has-vertical-flex-start ticss-7b5eb70a"><div class="wp-block-themeisle-blocks-advanced-columns-overlay"></div><div class="innerblocks-wrap"><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-2489d76c","padding":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"margin":{"top":"0px","bottom":"0px","left":"0px","right":"12px"},"marginTablet":{"top":"8px","bottom":"8px","left":"8px","right":"8px"},"marginMobile":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"2px","right":"2px","bottom":"2px","left":"2px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"boxShadowColorOpacity":10,"boxShadowBlur":80,"boxShadowVertical":2,"columnWidth":"33.33"} --><div id="wp-block-themeisle-blocks-advanced-column-2489d76c" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-e30ccf77","tag":"h3","align":"center","alignTablet":"center","alignMobile":"center","marginBottom":8} --><h3 id="wp-block-themeisle-blocks-advanced-heading-e30ccf77" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-e30ccf77">Essential</h3><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-01f7ed6b","tag":"span","align":"center","alignTablet":"center","alignMobile":"center","fontSize":48} --><span id="wp-block-themeisle-blocks-advanced-heading-01f7ed6b" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-01f7ed6b"><strong><strong>$59</strong></strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-fe18de7e","tag":"p","align":"center","alignTablet":"center","alignMobile":"center"} --><p id="wp-block-themeisle-blocks-advanced-heading-fe18de7e" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-fe18de7e"><em>Party snackwave four dollar toast tumeric cold-pressed.</em></p><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/icon-list {"id":"wp-block-themeisle-blocks-icon-list-fb8b7e9c","defaultIcon":"check","gap":16,"horizontalAlign":"center"} --><div id="wp-block-themeisle-blocks-icon-list-fb8b7e9c" class="wp-block-themeisle-blocks-icon-list"><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-78a49dfc","content":"Custom Layouts \\u0026amp; Hooks","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-78a49dfc" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Custom Layouts &amp; Hooks</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-f341b063","content":"Unlimited Website Usage","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-f341b063" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Unlimited Website Usage</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-8216d9b3","content":"Risk-Free Guarantee","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-8216d9b3" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Risk-Free Guarantee</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-1c648ab6","content":"Something else","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-1c648ab6" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Something else</p></div><!-- /wp:themeisle-blocks/icon-list-item --></div><!-- /wp:themeisle-blocks/icon-list --><!-- wp:spacer {"height":24} --><div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div><!-- /wp:spacer --><!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center","flexWrap":"wrap","orientation":"vertical"}} --><div class="wp-block-buttons"><!-- wp:button {"width":100,"className":"is-style-primary"} --><div class="wp-block-button has-custom-width wp-block-button__width-100 is-style-primary"><a class="wp-block-button__link">Get Started</a></div><!-- /wp:button --></div><!-- /wp:buttons --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-991b18b5","padding":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"margin":{"top":"0px","bottom":"0px","left":"12px","right":"12px"},"marginTablet":{"top":"8px","bottom":"8px","left":"8px","right":"8px"},"marginMobile":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"2px","right":"2px","bottom":"2px","left":"2px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"boxShadowColorOpacity":10,"boxShadowBlur":80,"boxShadowVertical":2,"columnWidth":"33.33"} --><div id="wp-block-themeisle-blocks-advanced-column-991b18b5" class="wp-block-themeisle-blocks-advanced-column"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-6b0710bb","tag":"h3","align":"center","alignTablet":"center","alignMobile":"center","marginBottom":8} --><h3 id="wp-block-themeisle-blocks-advanced-heading-6b0710bb" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-6b0710bb">Business</h3><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-0076e239","tag":"span","align":"center","alignTablet":"center","alignMobile":"center","fontSize":48} --><span id="wp-block-themeisle-blocks-advanced-heading-0076e239" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-0076e239"><strong>$129</strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-36b869e4","tag":"p","align":"center","alignTablet":"center","alignMobile":"center"} --><p id="wp-block-themeisle-blocks-advanced-heading-36b869e4" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-36b869e4"><em>Party snackwave four dollar toast tumeric cold-pressed.</em></p><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/icon-list {"id":"wp-block-themeisle-blocks-icon-list-1ce3cb83","defaultIcon":"check","gap":16,"horizontalAlign":"center"} --><div id="wp-block-themeisle-blocks-icon-list-1ce3cb83" class="wp-block-themeisle-blocks-icon-list"><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-bd6e8ccf","content":"Custom Layouts \\u0026amp; Hooks","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-bd6e8ccf" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Custom Layouts &amp; Hooks</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-532bf0a9","content":"Unlimited Website Usage","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-532bf0a9" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Unlimited Website Usage</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-91e6d201","content":"Risk-Free Guarantee","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-91e6d201" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Risk-Free Guarantee</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-0759ee69","content":"Something else","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-0759ee69" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Something else</p></div><!-- /wp:themeisle-blocks/icon-list-item --></div><!-- /wp:themeisle-blocks/icon-list --><!-- wp:spacer {"height":24} --><div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div><!-- /wp:spacer --><!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center","flexWrap":"wrap","orientation":"vertical"}} --><div class="wp-block-buttons"><!-- wp:button {"width":100,"className":"is-style-primary"} --><div class="wp-block-button has-custom-width wp-block-button__width-100 is-style-primary"><a class="wp-block-button__link">Get Started</a></div><!-- /wp:button --></div><!-- /wp:buttons --></div><!-- /wp:themeisle-blocks/advanced-column --><!-- wp:themeisle-blocks/advanced-column {"id":"wp-block-themeisle-blocks-advanced-column-09158d16","padding":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"paddingTablet":{"top":"20px","bottom":"20px","left":"20px","right":"20px"},"paddingMobile":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"margin":{"top":"0px","bottom":"0px","left":"12px","right":"0px"},"marginTablet":{"top":"8px","bottom":"8px","left":"8px","right":"8px"},"marginMobile":{"top":"24px","bottom":"24px","left":"24px","right":"24px"},"backgroundPosition":{"x":"0.00","y":"0.00"},"border":{"top":"2px","right":"2px","bottom":"2px","left":"2px"},"borderRadius":{"top":"0px","bottom":"0px","left":"0px","right":"0px"},"boxShadowColorOpacity":10,"boxShadowBlur":80,"boxShadowVertical":2,"columnWidth":"33.33","className":"ticss-3fe6b647","hasCustomCSS":true} --><div id="wp-block-themeisle-blocks-advanced-column-09158d16" class="wp-block-themeisle-blocks-advanced-column ticss-3fe6b647"><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-b3766bd8","tag":"h3","align":"center","alignTablet":"center","alignMobile":"center","marginBottom":8} --><h3 id="wp-block-themeisle-blocks-advanced-heading-b3766bd8" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-b3766bd8">VIP</h3><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-e601353c","tag":"span","align":"center","alignTablet":"center","alignMobile":"center","fontSize":48} --><span id="wp-block-themeisle-blocks-advanced-heading-e601353c" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-e601353c"><strong>$199</strong></span><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/advanced-heading {"id":"wp-block-themeisle-blocks-advanced-heading-39d2e261","tag":"p","align":"center","alignTablet":"center","alignMobile":"center"} --><p id="wp-block-themeisle-blocks-advanced-heading-39d2e261" class="wp-block-themeisle-blocks-advanced-heading wp-block-themeisle-blocks-advanced-heading-39d2e261"><em>Party snackwave four dollar toast tumeric cold-pressed.</em></p><!-- /wp:themeisle-blocks/advanced-heading --><!-- wp:themeisle-blocks/icon-list {"id":"wp-block-themeisle-blocks-icon-list-2c744428","defaultIcon":"check","gap":16,"horizontalAlign":"center"} --><div id="wp-block-themeisle-blocks-icon-list-2c744428" class="wp-block-themeisle-blocks-icon-list"><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-b78d20f0","content":"Custom Layouts \\u0026amp; Hooks","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-b78d20f0" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Custom Layouts &amp; Hooks</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-14fe631b","content":"Unlimited Website Usage","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-14fe631b" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Unlimited Website Usage</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-0ce7030d","content":"Risk-Free Guarantee","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-0ce7030d" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Risk-Free Guarantee</p></div><!-- /wp:themeisle-blocks/icon-list-item --><!-- wp:themeisle-blocks/icon-list-item {"id":"wp-block-themeisle-blocks-icon-list-item-430ea07c","content":"Something else","library":"fontawesome","iconPrefix":"fas","icon":"check"} --><div id="wp-block-themeisle-blocks-icon-list-item-430ea07c" class="wp-block-themeisle-blocks-icon-list-item"><i class="fas fa-check wp-block-themeisle-blocks-icon-list-item-icon"></i><p class="wp-block-themeisle-blocks-icon-list-item-content">Something else</p></div><!-- /wp:themeisle-blocks/icon-list-item --></div><!-- /wp:themeisle-blocks/icon-list --><!-- wp:spacer {"height":24} --><div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div><!-- /wp:spacer --><!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center","flexWrap":"wrap","orientation":"vertical"}} --><div class="wp-block-buttons"><!-- wp:button {"width":100,"className":"is-style-primary"} --><div class="wp-block-button has-custom-width wp-block-button__width-100 is-style-primary"><a class="wp-block-button__link">Get Started</a></div><!-- /wp:button --></div><!-- /wp:buttons --></div><!-- /wp:themeisle-blocks/advanced-column --></div></section><!-- /wp:themeisle-blocks/advanced-columns -->',
);
