section.wp-block-themeisle-blocks-about-author{border:0;border-radius:6px;width:100%;position:relative;display:flex;word-wrap:break-word}section.wp-block-themeisle-blocks-about-author .o-author-image{width:16.66666667%;float:left;max-width:130px;max-height:130px;margin:auto 15px}section.wp-block-themeisle-blocks-about-author .o-author-image .author-image{width:100%;height:auto;box-shadow:0 16px 38px -12px rgba(0,0,0,.56),0 4px 25px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,0,0,.2);border-radius:50%}section.wp-block-themeisle-blocks-about-author .o-author-image .author-image:hover{opacity:.8}section.wp-block-themeisle-blocks-about-author .o-author-data{width:83.33333333%;float:left;margin:0 15px;align-self:center}section.wp-block-themeisle-blocks-about-author .o-author-data h4{margin:0}section.wp-block-themeisle-blocks-about-author .o-author-data p{font-size:14px;margin:15px 0}@media(max-width: 961px){section.wp-block-themeisle-blocks-about-author{display:inline-block;text-align:center}section.wp-block-themeisle-blocks-about-author .o-author-image{width:auto;float:none;max-width:130px;max-height:130px;margin:auto}section.wp-block-themeisle-blocks-about-author .o-author-data{width:auto;float:none}}/*# sourceMappingURL=editor.css.map */
