@keyframes elementor-animation-pulse-grow {
	to {
		transform: scale(1.1);
	}
}
.elementor-animation-pulse-grow:active,
.elementor-animation-pulse-grow:focus,
.elementor-animation-pulse-grow:hover {
	animation-name: elementor-animation-pulse-grow;
	animation-duration: 0.3s;
	animation-timing-function: linear;
	animation-iteration-count: infinite;
	animation-direction: alternate;
}
