a{foo:.0001em;bar:0px;baz:.6px .011pt 10.2em 8.8cm;foobar:-.6px,-.333pt,-1.05em 50cm}b,.test-0\.400em{margin:.6px 3pt 1.2em .8cm;padding:.2em .8cm}c{margin:2.4px 0;padding:-.4px 0;margin:1px 0 0;padding:4px 0;padding:0;margin:0;transition-duration:0s;left:-20px;padding:0;margin:0;padding:10px 0 20px;margin:0;line-height:0;width:0;max-width:0}\;b\:0px{leading:50% -10.5% 1.004in -.45vw;trailing:5000% .5px 1.2001em .405;transition-duration:0ms;transform:rotate3d(0grad,0rad,0deg);pitch:0KHZ;pitch:0hz;padding:0;top:0;bottom:0;left:0;border-top:0 solid blue;border-width:0;column-gap:0;outline-width:0;border-radius:0;border-top-right-radius:0}body{margin:9px 9.8px 0 .9em;height:9.9;width:.5;z-index:.09;font-size:9;top:0;bottom:0}:lang(de)>p.lang\:0\.234500{height:.2em}#\:34\:0500{width:10.01%}.mg0px .lang\:0em{height:20%;padding-bottom:calc(.75rem - 1px);margin-right:calc(-.375em - 1px);transform:translateX(.3rem);transform:scale3d(.3,.3,.3)}