.o-css-editor{border:1px solid #e2e4e7;margin-bottom:20px}.o-css-editor-help{background:#f7f7f7;padding:20px}.o-css-errors{display:flex;flex-direction:column}.o-css-errors .span{font-family:Courier New,Courier,monospace}.o-css-errors .components-notice.is-error{margin:0}.o-css-errors pre{background:#f7f7f7;border:1px solid #e2e4e7;overflow-x:scroll;padding:5px}
