.yui3-skin-sam .yui3-scrollview-scrollbar {
    -webkit-transform: translate3d(0, 0, 0);
    -moz-transform: translate(0, 0); 
}

.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-first,
.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-middle, 
.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-last {
    border-radius:3px;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAABCAYAAAD9yd/wAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAABJJREFUeNpiZGBgSGPAAgACDAAIkABoFyloZQAAAABJRU5ErkJggg==');
}

.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-first,
.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-last {
    border-bottom-right-radius:0; 
    border-bottom-left-radius:0;

    -webkit-border-bottom-right-radius:0; 
    -webkit-border-bottom-left-radius:0;

    -moz-border-radius-bottomright:0; 
    -moz-border-radius-bottomleft:0;
}

.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-last {
    border-radius:0; 
    border-bottom-right-radius:3px; 
    border-bottom-left-radius:3px; 

    -webkit-border-radius:0; 
    -webkit-border-bottom-right-radius:3px; 
    -webkit-border-bottom-left-radius:3px; 
    -webkit-transform: translate3d(0, 0, 0);

    -moz-border-radius:0; 
    -moz-border-radius-bottomright:3px; 
    -moz-border-radius-bottomleft:3px; 
    -moz-transform: translate(0, 0);
}

.yui3-skin-sam .yui3-scrollview-scrollbar .yui3-scrollview-middle {
    border-radius:0; 
    -webkit-border-radius: 0;
    -moz-border-radius: 0; 

    -webkit-transform: translate3d(0,0,0) scaleY(1); 
    -webkit-transform-origin-y: 0;

    -moz-transform: translate(0,0) scaleY(1); 
    -moz-transform-origin: 0 0;
}

.yui3-skin-sam .yui3-scrollview-scrollbar-horiz .yui3-scrollview-first,
.yui3-skin-sam .yui3-scrollview-scrollbar-horiz .yui3-scrollview-last {
    border-top-right-radius: 0;
    border-bottom-left-radius: 3px;
 
    -webkit-border-top-right-radius: 0;
    -webkit-border-bottom-left-radius: 3px;

    -moz-border-radius-topright: 0;
    -moz-border-radius-bottomleft: 3px;
}

.yui3-skin-sam .yui3-scrollview-scrollbar-horiz .yui3-scrollview-last {
    border-bottom-left-radius: 0; 
    border-top-right-radius: 3px;

    -webkit-border-bottom-left-radius: 0; 
    -webkit-border-top-right-radius: 3px;

    -moz-border-radius-bottomleft: 0; 
    -moz-border-radius-topright: 3px; 
}

.yui3-skin-sam .yui3-scrollview-scrollbar-horiz .yui3-scrollview-middle { 
    -webkit-transform: translate3d(0,0,0) scaleX(1); 
    -webkit-transform-origin: 0 0;

    -moz-transform: translate(0,0) scaleX(1); 
    -moz-transform-origin: 0 0;
}

.yui3-skin-sam .yui3-scrollview-scrollbar-vert-basic .yui3-scrollview-child,
.yui3-skin-sam .yui3-scrollview-scrollbar-horiz-basic .yui3-scrollview-child {
    background-color: #aaa;
    background-image: none;
}